Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFinalAppUrl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A URL for deep linking into an app for the given operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonFinalAppUrl

Returns a new instance of GoogleAdsSearchads360V0CommonFinalAppUrl.



321
322
323
# File 'lib/google/apis/searchads360_v0/classes.rb', line 321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#os_typeString

The operating system targeted by this URL. Required. Corresponds to the JSON property osType

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/searchads360_v0/classes.rb', line 309

def os_type
  @os_type
end

#urlString

The app deep link URL. Deep links specify a location in an app that corresponds to the content you'd like to show, and should be of the form scheme://host_path The scheme identifies which app to open. For your app, you can use a custom scheme that starts with the app's name. The host and path specify the unique location in the app where your content exists. Example: " exampleapp://productid_1234". Required. Corresponds to the JSON property url

Returns:

  • (String)


319
320
321
# File 'lib/google/apis/searchads360_v0/classes.rb', line 319

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



326
327
328
329
# File 'lib/google/apis/searchads360_v0/classes.rb', line 326

def update!(**args)
  @os_type = args[:os_type] if args.key?(:os_type)
  @url = args[:url] if args.key?(:url)
end