Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationGroupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A radius around a list of locations specified through a feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonLocationGroupInfo

Returns a new instance of GoogleAdsSearchads360V0CommonLocationGroupInfo.



546
547
548
# File 'lib/google/apis/searchads360_v0/classes.rb', line 546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feed_item_setsArray<String>

FeedItemSets whose FeedItems are targeted. If multiple IDs are specified, then all items that appear in at least one set are targeted. This field cannot be used with geo_target_constants. This is optional and can only be set in CREATE operations. Corresponds to the JSON property feedItemSets

Returns:

  • (Array<String>)


525
526
527
# File 'lib/google/apis/searchads360_v0/classes.rb', line 525

def feed_item_sets
  @feed_item_sets
end

#geo_target_constantsArray<String>

Geo target constant(s) restricting the scope of the geographic area within the feed. Currently only one geo target constant is allowed. Corresponds to the JSON property geoTargetConstants

Returns:

  • (Array<String>)


531
532
533
# File 'lib/google/apis/searchads360_v0/classes.rb', line 531

def geo_target_constants
  @geo_target_constants
end

#radiusFixnum

Distance in units specifying the radius around targeted locations. This is required and must be set in CREATE operations. Corresponds to the JSON property radius

Returns:

  • (Fixnum)


537
538
539
# File 'lib/google/apis/searchads360_v0/classes.rb', line 537

def radius
  @radius
end

#radius_unitsString

Unit of the radius. Miles and meters are supported for geo target constants. Milli miles and meters are supported for feed item sets. This is required and must be set in CREATE operations. Corresponds to the JSON property radiusUnits

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/searchads360_v0/classes.rb', line 544

def radius_units
  @radius_units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



551
552
553
554
555
556
# File 'lib/google/apis/searchads360_v0/classes.rb', line 551

def update!(**args)
  @feed_item_sets = args[:feed_item_sets] if args.key?(:feed_item_sets)
  @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants)
  @radius = args[:radius] if args.key?(:radius)
  @radius_units = args[:radius_units] if args.key?(:radius_units)
end