Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_cpa_micros ⇒ Fixnum
The target cost-per-action (CPA) option.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonMaximizeConversions
constructor
A new instance of GoogleAdsSearchads360V0CommonMaximizeConversions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonMaximizeConversions
Returns a new instance of GoogleAdsSearchads360V0CommonMaximizeConversions.
694 695 696 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. Mutable for portfolio bidding strategies
only.
Corresponds to the JSON property cpcBidCeilingMicros
675 676 677 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 675 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. Mutable for portfolio bidding strategies
only.
Corresponds to the JSON property cpcBidFloorMicros
682 683 684 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 682 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_cpa_micros ⇒ Fixnum
The target cost-per-action (CPA) option. This is the average amount that you
would like to spend per conversion action specified in micro units of the
bidding strategy's currency. If set, the bid strategy will get as many
conversions as possible at or below the target cost-per-action. If the target
CPA is not set, the bid strategy will aim to achieve the lowest possible CPA
given the budget.
Corresponds to the JSON property targetCpaMicros
692 693 694 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 692 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
699 700 701 702 703 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 699 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |