Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetCpa

Returns a new instance of GoogleAdsSearchads360V0CommonTargetCpa.



2553
2554
2555
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Maximum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


2538
2539
2540
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2538

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#cpc_bid_floor_microsFixnum

Minimum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidFloorMicros

Returns:

  • (Fixnum)


2545
2546
2547
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2545

def cpc_bid_floor_micros
  @cpc_bid_floor_micros
end

#target_cpa_microsFixnum

Average CPA target. This target should be greater than or equal to minimum billable unit based on the currency for the account. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


2551
2552
2553
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2551

def target_cpa_micros
  @target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2558
2559
2560
2561
2562
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2558

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
end