Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetImpressionShare

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetImpressionShare

Returns a new instance of GoogleAdsSearchads360V0CommonTargetImpressionShare.



2542
2543
2544
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

The highest CPC bid the automated bidding system is permitted to specify. This is a required field entered by the advertiser that sets the ceiling and specified in local micros. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


2529
2530
2531
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2529

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#locationString

The targeted location on the search results page. Corresponds to the JSON property location

Returns:

  • (String)


2534
2535
2536
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2534

def location
  @location
end

#location_fraction_microsFixnum

The chosen fraction of ads to be shown in the targeted location in micros. For example, 1% equals 10,000. Corresponds to the JSON property locationFractionMicros

Returns:

  • (Fixnum)


2540
2541
2542
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2540

def location_fraction_micros
  @location_fraction_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2547
2548
2549
2550
2551
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2547

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @location = args[:location] if args.key?(:location)
  @location_fraction_micros = args[:location_fraction_micros] if args.key?(:location_fraction_micros)
end