Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Represents a criterion for targeting webpages of an advertiser's website.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageConditionInfo>
Conditions, or logical expressions, for webpage targeting.
-
#coverage_percentage ⇒ Float
Website criteria coverage percentage.
-
#criterion_name ⇒ String
The name of the criterion that is defined by this parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonWebpageInfo
constructor
A new instance of GoogleAdsSearchads360V0CommonWebpageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonWebpageInfo
Returns a new instance of GoogleAdsSearchads360V0CommonWebpageInfo.
3205 3206 3207 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageConditionInfo>
Conditions, or logical expressions, for webpage targeting. The list of webpage
targeting conditions are and-ed together when evaluated for targeting. An
empty list of conditions indicates all pages of the campaign's website are
targeted. This field is required for CREATE operations and is prohibited on
UPDATE operations.
Corresponds to the JSON property conditions
3187 3188 3189 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3187 def conditions @conditions end |
#coverage_percentage ⇒ Float
Website criteria coverage percentage. This is the computed percentage of
website coverage based on the website target, negative website target and
negative keywords in the ad group and campaign. For instance, when coverage
returns as 1, it indicates it has 100% coverage. This field is read-only.
Corresponds to the JSON property coveragePercentage
3195 3196 3197 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3195 def coverage_percentage @coverage_percentage end |
#criterion_name ⇒ String
The name of the criterion that is defined by this parameter. The name value
will be used for identifying, sorting and filtering criteria with this type of
parameters. This field is required for CREATE operations and is prohibited on
UPDATE operations.
Corresponds to the JSON property criterionName
3203 3204 3205 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3203 def criterion_name @criterion_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3210 3211 3212 3213 3214 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3210 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @coverage_percentage = args[:coverage_percentage] if args.key?(:coverage_percentage) @criterion_name = args[:criterion_name] if args.key?(:criterion_name) end |