Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorCode
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
The error reason represented by type and enum.
Instance Attribute Summary collapse
-
#authentication_error ⇒ String
Indicates failure to properly authenticate user.
-
#authorization_error ⇒ String
An error encountered when trying to authorize a user.
-
#conversion_custom_variable_error ⇒ String
The reasons for the conversion custom variable error Corresponds to the JSON property
conversionCustomVariableError. -
#custom_column_error ⇒ String
The reasons for the custom column error Corresponds to the JSON property
customColumnError. -
#date_error ⇒ String
The reasons for the date error Corresponds to the JSON property
dateError. -
#date_range_error ⇒ String
The reasons for the date range error Corresponds to the JSON property
dateRangeError. -
#distinct_error ⇒ String
The reasons for the distinct error Corresponds to the JSON property
distinctError. -
#header_error ⇒ String
The reasons for the header error.
-
#internal_error ⇒ String
An unexpected server-side error.
-
#invalid_parameter_error ⇒ String
The reasons for invalid parameter errors.
-
#query_error ⇒ String
An error with the query Corresponds to the JSON property
queryError. -
#quota_error ⇒ String
An error with the amount of quota remaining.
-
#request_error ⇒ String
An error caused by the request Corresponds to the JSON property
requestError. -
#size_limit_error ⇒ String
The reasons for the size limit error Corresponds to the JSON property
sizeLimitError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorCode
constructor
A new instance of GoogleAdsSearchads360V0ErrorsErrorCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorCode
Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorCode.
3282 3283 3284 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_error ⇒ String
Indicates failure to properly authenticate user.
Corresponds to the JSON property authenticationError
3215 3216 3217 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3215 def authentication_error @authentication_error end |
#authorization_error ⇒ String
An error encountered when trying to authorize a user.
Corresponds to the JSON property authorizationError
3220 3221 3222 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3220 def @authorization_error end |
#conversion_custom_variable_error ⇒ String
The reasons for the conversion custom variable error
Corresponds to the JSON property conversionCustomVariableError
3225 3226 3227 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3225 def conversion_custom_variable_error @conversion_custom_variable_error end |
#custom_column_error ⇒ String
The reasons for the custom column error
Corresponds to the JSON property customColumnError
3230 3231 3232 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3230 def custom_column_error @custom_column_error end |
#date_error ⇒ String
The reasons for the date error
Corresponds to the JSON property dateError
3235 3236 3237 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3235 def date_error @date_error end |
#date_range_error ⇒ String
The reasons for the date range error
Corresponds to the JSON property dateRangeError
3240 3241 3242 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3240 def date_range_error @date_range_error end |
#distinct_error ⇒ String
The reasons for the distinct error
Corresponds to the JSON property distinctError
3245 3246 3247 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3245 def distinct_error @distinct_error end |
#header_error ⇒ String
The reasons for the header error.
Corresponds to the JSON property headerError
3250 3251 3252 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3250 def header_error @header_error end |
#internal_error ⇒ String
An unexpected server-side error.
Corresponds to the JSON property internalError
3255 3256 3257 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3255 def internal_error @internal_error end |
#invalid_parameter_error ⇒ String
The reasons for invalid parameter errors.
Corresponds to the JSON property invalidParameterError
3260 3261 3262 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3260 def invalid_parameter_error @invalid_parameter_error end |
#query_error ⇒ String
An error with the query
Corresponds to the JSON property queryError
3265 3266 3267 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3265 def query_error @query_error end |
#quota_error ⇒ String
An error with the amount of quota remaining.
Corresponds to the JSON property quotaError
3270 3271 3272 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3270 def quota_error @quota_error end |
#request_error ⇒ String
An error caused by the request
Corresponds to the JSON property requestError
3275 3276 3277 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3275 def request_error @request_error end |
#size_limit_error ⇒ String
The reasons for the size limit error
Corresponds to the JSON property sizeLimitError
3280 3281 3282 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3280 def size_limit_error @size_limit_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3287 def update!(**args) @authentication_error = args[:authentication_error] if args.key?(:authentication_error) @authorization_error = args[:authorization_error] if args.key?(:authorization_error) @conversion_custom_variable_error = args[:conversion_custom_variable_error] if args.key?(:conversion_custom_variable_error) @custom_column_error = args[:custom_column_error] if args.key?(:custom_column_error) @date_error = args[:date_error] if args.key?(:date_error) @date_range_error = args[:date_range_error] if args.key?(:date_range_error) @distinct_error = args[:distinct_error] if args.key?(:distinct_error) @header_error = args[:header_error] if args.key?(:header_error) @internal_error = args[:internal_error] if args.key?(:internal_error) @invalid_parameter_error = args[:invalid_parameter_error] if args.key?(:invalid_parameter_error) @query_error = args[:query_error] if args.key?(:query_error) @quota_error = args[:quota_error] if args.key?(:quota_error) @request_error = args[:request_error] if args.key?(:request_error) @size_limit_error = args[:size_limit_error] if args.key?(:size_limit_error) end |