Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Additional error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorDetails

Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorDetails.



3380
3381
3382
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#quota_error_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsQuotaErrorDetails

Additional quota error details when there is QuotaError. Corresponds to the JSON property quotaErrorDetails



3372
3373
3374
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3372

def quota_error_details
  @quota_error_details
end

#unpublished_error_codeString

The error code that should have been returned, but wasn't. This is used when the error code is not published in the client specified version. Corresponds to the JSON property unpublishedErrorCode

Returns:

  • (String)


3378
3379
3380
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3378

def unpublished_error_code
  @unpublished_error_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3385
3386
3387
3388
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3385

def update!(**args)
  @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details)
  @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code)
end