Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A part of a field path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement

Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement.



3197
3198
3199
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

The name of a field or a oneof Corresponds to the JSON property fieldName

Returns:

  • (String)


3190
3191
3192
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3190

def field_name
  @field_name
end

#indexFixnum

If field_name is a repeated field, this is the element that failed Corresponds to the JSON property index

Returns:

  • (Fixnum)


3195
3196
3197
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3195

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3202
3203
3204
3205
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3202

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @index = args[:index] if args.key?(:index)
end