Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Represents a view of BiddingStrategies owned by and shared with the customer. In contrast to BiddingStrategy, this resource includes strategies owned by managers of the customer and shared with this customer - in addition to strategies owned by this customer. This resource does not provide metrics and only exposes a limited subset of the BiddingStrategy attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy.



4298
4299
4300
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the bidding strategy. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4233
4234
4235
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4233

def id
  @id
end

#maximize_conversion_valueGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



4239
4240
4241
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4239

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



4245
4246
4247
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4245

def maximize_conversions
  @maximize_conversions
end

#nameString

Output only. The name of the bidding strategy. Corresponds to the JSON property name

Returns:

  • (String)


4250
4251
4252
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4250

def name
  @name
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


4255
4256
4257
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4255

def owner_customer_id
  @owner_customer_id
end

#owner_descriptive_nameString

Output only. descriptive_name of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerDescriptiveName

Returns:

  • (String)


4260
4261
4262
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4260

def owner_descriptive_name
  @owner_descriptive_name
end

#resource_nameString

Output only. The resource name of the accessible bidding strategy. AccessibleBiddingStrategy resource names have the form: customers/ customer_id/accessibleBiddingStrategies/bidding_strategy_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4267
4268
4269
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4267

def resource_name
  @resource_name
end

#target_cpaGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



4273
4274
4275
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4273

def target_cpa
  @target_cpa
end

#target_impression_shareGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



4279
4280
4281
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4279

def target_impression_share
  @target_impression_share
end

#target_roasGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



4285
4286
4287
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4285

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



4291
4292
4293
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4291

def target_spend
  @target_spend
end

#typeString

Output only. The type of the bidding strategy. Corresponds to the JSON property type

Returns:

  • (String)


4296
4297
4298
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4296

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4303

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @owner_descriptive_name = args[:owner_descriptive_name] if args.key?(:owner_descriptive_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @type = args[:type] if args.key?(:type)
end