Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.
Instance Attribute Summary collapse
-
#target_cpa ⇒ Fixnum
Output only.
-
#target_cpa_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions.
3552 3553 3554 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_cpa ⇒ Fixnum
Output only. The target cost per acquisition (CPA) option. This is the average
amount that you would like to spend per acquisition.
Corresponds to the JSON property targetCpa
3544 3545 3546 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3544 def target_cpa @target_cpa end |
#target_cpa_micros ⇒ Fixnum
Output only. The target cost per acquisition (CPA) option. This is the average
amount that you would like to spend per acquisition.
Corresponds to the JSON property targetCpaMicros
3550 3551 3552 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3550 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3557 3558 3559 3560 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3557 def update!(**args) @target_cpa = args[:target_cpa] if args.key?(:target_cpa) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |