Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa

Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa.



3574
3575
3576
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_cpa_microsFixnum

Output only. Average CPA target. This target should be greater than or equal to minimum billable unit based on the currency for the account. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


3572
3573
3574
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3572

def target_cpa_micros
  @target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3579
3580
3581
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3579

def update!(**args)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
end