Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas

Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas.



3629
3630
3631
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_roasFloat

Output only. The chosen revenue (based on conversion data) per unit of spend. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


3627
3628
3629
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3627

def target_roas
  @target_roas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3634
3635
3636
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3634

def update!(**args)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
end