Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A relationship between an ad group ad and an effective label. An effective label is a label inherited or directly assigned to this ad group ad.
Instance Attribute Summary collapse
-
#ad_group_ad ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel.
4690 4691 4692 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad ⇒ String
Immutable. The ad group ad to which the effective label is attached.
Corresponds to the JSON property adGroupAd
4671 4672 4673 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4671 def ad_group_ad @ad_group_ad end |
#label ⇒ String
Immutable. The effective label assigned to the ad group ad.
Corresponds to the JSON property label
4676 4677 4678 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4676 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
4681 4682 4683 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4681 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group ad effective label. Ad group ad
effective label resource names have the form: customers/owner_customer_id/
adGroupAdEffectiveLabels/ad_group_id~ad_id~label_id`
Corresponds to the JSON propertyresourceName`
4688 4689 4690 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4688 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4695 def update!(**args) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |