Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A link between an ad group and an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAsset

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAsset.



4700
4701
4702
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Required. Immutable. The ad group to which the asset is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


4681
4682
4683
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4681

def ad_group
  @ad_group
end

#assetString

Required. Immutable. The asset which is linked to the ad group. Corresponds to the JSON property asset

Returns:

  • (String)


4686
4687
4688
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4686

def asset
  @asset
end

#resource_nameString

Immutable. The resource name of the ad group asset. AdGroupAsset resource names have the form: customers/customer_id/adGroupAssets/ad_group_id~ asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4693
4694
4695
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4693

def resource_name
  @resource_name
end

#statusString

Status of the ad group asset. Corresponds to the JSON property status

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4698

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4705
4706
4707
4708
4709
4710
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4705

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset = args[:asset] if args.key?(:asset)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end