Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAssetSet

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAssetSet.



4808
4809
4810
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which this asset set is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


4789
4790
4791
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4789

def ad_group
  @ad_group
end

#asset_setString

Immutable. The asset set which is linked to the ad group. Corresponds to the JSON property assetSet

Returns:

  • (String)


4794
4795
4796
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4794

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the ad group asset set. Ad group asset set resource names have the form: customers/customer_id/adGroupAssetSets/ ad_group_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4801
4802
4803
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4801

def resource_name
  @resource_name
end

#statusString

Output only. The status of the ad group asset set. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


4806
4807
4808
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4806

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4813
4814
4815
4816
4817
4818
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4813

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end