Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An ad group audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated at the audience level.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupAudienceView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAudienceView.
4834 4835 4836 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the ad group audience view. Ad group
audience view resource names have the form: customers/customer_id/
adGroupAudienceViews/ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
4832 4833 4834 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4832 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4839 4840 4841 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4839 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |