Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Represents an ad group bid modifier.
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#device ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonDeviceInfo
A device criterion.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupBidModifier.
4798 4799 4800 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches. The modifier must be in
the range: 0.1 - 10.0. Use 0 to opt out of a Device type.
Corresponds to the JSON property bidModifier
4784 4785 4786 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4784 def bid_modifier @bid_modifier end |
#device ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonDeviceInfo
A device criterion.
Corresponds to the JSON property device
4789 4790 4791 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4789 def device @device end |
#resource_name ⇒ String
Immutable. The resource name of the ad group bid modifier. Ad group bid
modifier resource names have the form: customers/customer_id/
adGroupBidModifiers/ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
4796 4797 4798 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4796 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4803 4804 4805 4806 4807 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4803 def update!(**args) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @device = args[:device] if args.key?(:device) @resource_name = args[:resource_name] if args.key?(:resource_name) end |