Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A relationship between an ad group and a label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupLabel

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupLabel.



5236
5237
5238
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which the label is attached. Corresponds to the JSON property adGroup

Returns:

  • (String)


5217
5218
5219
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5217

def ad_group
  @ad_group
end

#labelString

Immutable. The label assigned to the ad group. Corresponds to the JSON property label

Returns:

  • (String)


5222
5223
5224
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5222

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


5227
5228
5229
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5227

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group label. Ad group label resource names have the form: customers/owner_customer_id/adGroupLabels/ad_group_id ~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5234
5235
5236
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5234

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5241
5242
5243
5244
5245
5246
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5241

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end