Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupAsset

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroupAsset.



5555
5556
5557
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset group asset is linking. Corresponds to the JSON property asset

Returns:

  • (String)


5530
5531
5532
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5530

def asset
  @asset
end

#asset_groupString

Immutable. The asset group which this asset group asset is linking. Corresponds to the JSON property assetGroup

Returns:

  • (String)


5535
5536
5537
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5535

def asset_group
  @asset_group
end

#field_typeString

The description of the placement of the asset within the asset group. For example: HEADLINE, YOUTUBE_VIDEO etc Corresponds to the JSON property fieldType

Returns:

  • (String)


5541
5542
5543
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5541

def field_type
  @field_type
end

#resource_nameString

Immutable. The resource name of the asset group asset. Asset group asset resource name have the form: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5548
5549
5550
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5548

def resource_name
  @resource_name
end

#statusString

The status of the link between an asset and asset group. Corresponds to the JSON property status

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5553

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5560
5561
5562
5563
5564
5565
5566
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5560

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @field_type = args[:field_type] if args.key?(:field_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end