Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupSignal

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroupSignal.



5680
5681
5682
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_groupString

Immutable. The asset group which this asset group signal belongs to. Corresponds to the JSON property assetGroup

Returns:

  • (String)


5666
5667
5668
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5666

def asset_group
  @asset_group
end

#audienceGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAudienceInfo

An audience criterion. Corresponds to the JSON property audience



5671
5672
5673
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5671

def audience
  @audience
end

#resource_nameString

Immutable. The resource name of the asset group signal. Asset group signal resource name have the form: customers/customer_id/assetGroupSignals/ asset_group_id~signal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5678
5679
5680
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5678

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5685
5686
5687
5688
5689
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5685

def update!(**args)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @audience = args[:audience] if args.key?(:audience)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end