Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A view on the usage of asset group asset top combinations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView.



5628
5629
5630
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_group_top_combinationsArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAssetCombinationData>

Output only. The top combinations of assets that served together. Corresponds to the JSON property assetGroupTopCombinations



5618
5619
5620
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5618

def asset_group_top_combinations
  @asset_group_top_combinations
end

#resource_nameString

Output only. The resource name of the asset group top combination view. AssetGroup Top Combination view resource names have the form: "customers/ customer_id/assetGroupTopCombinationViews/asset_group_id~ asset_combination_category" Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5626
5627
5628
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5626

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5633
5634
5635
5636
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5633

def update!(**args)
  @asset_group_top_combinations = args[:asset_group_top_combinations] if args.key?(:asset_group_top_combinations)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end