Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetSetAsset

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetSetAsset.



5774
5775
5776
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset set asset is linking to. Corresponds to the JSON property asset

Returns:

  • (String)


5755
5756
5757
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5755

def asset
  @asset
end

#asset_setString

Immutable. The asset set which this asset set asset is linking to. Corresponds to the JSON property assetSet

Returns:

  • (String)


5760
5761
5762
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5760

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the asset set asset. Asset set asset resource names have the form: customers/customer_id/assetSetAssets/asset_set_id~ asset_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5767
5768
5769
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5767

def resource_name
  @resource_name
end

#statusString

Output only. The status of the asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


5772
5773
5774
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5772

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5779
5780
5781
5782
5783
5784
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5779

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end