Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAudience

Returns a new instance of GoogleAdsSearchads360V0ResourcesAudience.



5815
5816
5817
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this audience. Corresponds to the JSON property description

Returns:

  • (String)


5796
5797
5798
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5796

def description
  @description
end

#idFixnum

Output only. ID of the audience. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5801
5802
5803
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5801

def id
  @id
end

#nameString

Required. Name of the audience. It should be unique across all audiences. It must have a minimum length of 1 and maximum length of 255. Corresponds to the JSON property name

Returns:

  • (String)


5807
5808
5809
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5807

def name
  @name
end

#resource_nameString

Immutable. The resource name of the audience. Audience names have the form: customers/customer_id/audiences/audience_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5813
5814
5815
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5813

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5820
5821
5822
5823
5824
5825
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5820

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end