Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A bidding strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V0ResourcesBiddingStrategy.



5944
5945
5946
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_countFixnum

Output only. The number of campaigns attached to this bidding strategy. This field is read-only. Corresponds to the JSON property campaignCount

Returns:

  • (Fixnum)


5836
5837
5838
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5836

def campaign_count
  @campaign_count
end

#currency_codeString

Immutable. The currency used by the bidding strategy (ISO 4217 three-letter code). For bidding strategies in manager customers, this currency can be set on creation and defaults to the manager customer's currency. For serving customers, this field cannot be set; all strategies in a serving customer implicitly use the serving customer's currency. In all cases the effective_currency_code field returns the currency used by the strategy. Corresponds to the JSON property currencyCode

Returns:

  • (String)


5846
5847
5848
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5846

def currency_code
  @currency_code
end

#effective_currency_codeString

Output only. The currency used by the bidding strategy (ISO 4217 three-letter code). For bidding strategies in manager customers, this is the currency set by the advertiser when creating the strategy. For serving customers, this is the customer's currency_code. Bidding strategy metrics are reported in this currency. This field is read-only. Corresponds to the JSON property effectiveCurrencyCode

Returns:

  • (String)


5855
5856
5857
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5855

def effective_currency_code
  @effective_currency_code
end

#enhanced_cpcGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonEnhancedCpc

An automated bidding strategy that raises bids for clicks that seem more likely to lead to a conversion and lowers them for clicks where they seem less likely. This bidding strategy is deprecated and cannot be created anymore. Use ManualCpc with enhanced_cpc_enabled set to true for equivalent functionality. Corresponds to the JSON property enhancedCpc



5863
5864
5865
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5863

def enhanced_cpc
  @enhanced_cpc
end

#idFixnum

Output only. The ID of the bidding strategy. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5868
5869
5870
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5868

def id
  @id
end

#maximize_conversion_valueGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



5874
5875
5876
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5874

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



5880
5881
5882
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5880

def maximize_conversions
  @maximize_conversions
end

#nameString

The name of the bidding strategy. All bidding strategies within an account must be named distinctly. The length of this string should be between 1 and 255, inclusive, in UTF-8 bytes, (trimmed). Corresponds to the JSON property name

Returns:

  • (String)


5887
5888
5889
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5887

def name
  @name
end

#non_removed_campaign_countFixnum

Output only. The number of non-removed campaigns attached to this bidding strategy. This field is read-only. Corresponds to the JSON property nonRemovedCampaignCount

Returns:

  • (Fixnum)


5893
5894
5895
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5893

def non_removed_campaign_count
  @non_removed_campaign_count
end

#resource_nameString

Immutable. The resource name of the bidding strategy. Bidding strategy resource names have the form: customers/customer_id/biddingStrategies/ bidding_strategy_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5900
5901
5902
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5900

def resource_name
  @resource_name
end

#statusString

Output only. The status of the bidding strategy. This field is read-only. Corresponds to the JSON property status

Returns:

  • (String)


5905
5906
5907
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5905

def status
  @status
end

#target_cpaGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



5911
5912
5913
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5911

def target_cpa
  @target_cpa
end

#target_impression_shareGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



5917
5918
5919
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5917

def target_impression_share
  @target_impression_share
end

#target_outrank_shareGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetOutrankShare

An automated bidding strategy that sets bids based on the target fraction of auctions where the advertiser should outrank a specific competitor. This strategy is deprecated. Corresponds to the JSON property targetOutrankShare



5924
5925
5926
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5924

def target_outrank_share
  @target_outrank_share
end

#target_roasGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



5930
5931
5932
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5930

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



5936
5937
5938
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5936

def target_spend
  @target_spend
end

#typeString

Output only. The type of the bidding strategy. Create a bidding strategy by setting the bidding scheme. This field is read-only. Corresponds to the JSON property type

Returns:

  • (String)


5942
5943
5944
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5942

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5949
5950
5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5949

def update!(**args)
  @campaign_count = args[:campaign_count] if args.key?(:campaign_count)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @effective_currency_code = args[:effective_currency_code] if args.key?(:effective_currency_code)
  @enhanced_cpc = args[:enhanced_cpc] if args.key?(:enhanced_cpc)
  @id = args[:id] if args.key?(:id)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @non_removed_campaign_count = args[:non_removed_campaign_count] if args.key?(:non_removed_campaign_count)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_outrank_share = args[:target_outrank_share] if args.key?(:target_outrank_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @type = args[:type] if args.key?(:type)
end