Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaign

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaign.



6265
6266
6267
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessible_bidding_strategyString

Output only. Resource name of AccessibleBiddingStrategy, a read-only view of the unrestricted attributes of the attached portfolio bidding strategy identified by 'bidding_strategy'. Empty, if the campaign does not use a portfolio strategy. Unrestricted strategy attributes are available to all customers with whom the strategy is shared and are read from the AccessibleBiddingStrategy resource. In contrast, restricted attributes are only available to the owner customer of the strategy and their managers. Restricted attributes can only be read from the BiddingStrategy resource. Corresponds to the JSON property accessibleBiddingStrategy

Returns:

  • (String)


5984
5985
5986
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5984

def accessible_bidding_strategy
  @accessible_bidding_strategy
end

#ad_serving_optimization_statusString

The ad serving optimization status of the campaign. Corresponds to the JSON property adServingOptimizationStatus

Returns:

  • (String)


5989
5990
5991
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5989

def ad_serving_optimization_status
  @ad_serving_optimization_status
end

#advertising_channel_sub_typeString

Immutable. Optional refinement to advertising_channel_type. Must be a valid sub-type of the parent channel type. Can be set only when creating campaigns. After campaign is created, the field can not be changed. Corresponds to the JSON property advertisingChannelSubType

Returns:

  • (String)


5996
5997
5998
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5996

def advertising_channel_sub_type
  @advertising_channel_sub_type
end

#advertising_channel_typeString

Immutable. The primary serving target for ads within the campaign. The targeting options can be refined in network_settings. This field is required and should not be empty when creating new campaigns. Can be set only when creating campaigns. After the campaign is created, the field can not be changed. Corresponds to the JSON property advertisingChannelType

Returns:

  • (String)


6005
6006
6007
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6005

def advertising_channel_type
  @advertising_channel_type
end

#bidding_strategyString

The resource name of the portfolio bidding strategy used by the campaign. Corresponds to the JSON property biddingStrategy

Returns:

  • (String)


6010
6011
6012
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6010

def bidding_strategy
  @bidding_strategy
end

#bidding_strategy_system_statusString

Output only. The system status of the campaign's bidding strategy. Corresponds to the JSON property biddingStrategySystemStatus

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6015

def bidding_strategy_system_status
  @bidding_strategy_system_status
end

#bidding_strategy_typeString

Output only. The type of bidding strategy. A bidding strategy can be created by setting either the bidding scheme to create a standard bidding strategy or the bidding_strategy field to create a portfolio bidding strategy. This field is read-only. Corresponds to the JSON property biddingStrategyType

Returns:

  • (String)


6023
6024
6025
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6023

def bidding_strategy_type
  @bidding_strategy_type
end

#campaign_budgetString

The resource name of the campaign budget of the campaign. Corresponds to the JSON property campaignBudget

Returns:

  • (String)


6028
6029
6030
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6028

def campaign_budget
  @campaign_budget
end

#create_timeString

Output only. The timestamp when this campaign was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. create_time will be deprecated in v1. Use creation_time instead. Corresponds to the JSON property createTime

Returns:

  • (String)


6035
6036
6037
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6035

def create_time
  @create_time
end

#creation_timeString

Output only. The timestamp when this campaign was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


6041
6042
6043
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6041

def creation_time
  @creation_time
end

#dynamic_search_ads_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting

The setting for controlling Dynamic Search Ads (DSA). Corresponds to the JSON property dynamicSearchAdsSetting



6046
6047
6048
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6046

def dynamic_search_ads_setting
  @dynamic_search_ads_setting
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this campaign. An effective label is a label inherited or directly assigned to this campaign. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


6052
6053
6054
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6052

def effective_labels
  @effective_labels
end

#end_dateString

The last day of the campaign in serving customer's timezone in YYYY-MM-DD format. On create, defaults to 2037-12-30, which means the campaign will run indefinitely. To set an existing campaign to run indefinitely, set this field to 2037-12-30. Corresponds to the JSON property endDate

Returns:

  • (String)


6060
6061
6062
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6060

def end_date
  @end_date
end

#engine_idString

Output only. ID of the campaign in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "campaign.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


6067
6068
6069
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6067

def engine_id
  @engine_id
end

#excluded_parent_asset_field_typesArray<String>

The asset field types that should be excluded from this campaign. Asset links with these field types will not be inherited by this campaign from the upper level. Corresponds to the JSON property excludedParentAssetFieldTypes

Returns:

  • (Array<String>)


6074
6075
6076
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6074

def excluded_parent_asset_field_types
  @excluded_parent_asset_field_types
end

#feed_typesArray<String>

Output only. Types of feeds that are attached directly to this campaign. Corresponds to the JSON property feedTypes

Returns:

  • (Array<String>)


6079
6080
6081
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6079

def feed_types
  @feed_types
end

#final_url_suffixString

Suffix used to append query parameters to landing pages that are served with parallel tracking. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6085
6086
6087
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6085

def final_url_suffix
  @final_url_suffix
end

#frequency_capsArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFrequencyCapEntry>

A list that limits how often each user will see this campaign's ads. Corresponds to the JSON property frequencyCaps



6090
6091
6092
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6090

def frequency_caps
  @frequency_caps
end

#geo_target_type_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignGeoTargetTypeSetting

Represents a collection of settings related to ads geotargeting. Corresponds to the JSON property geoTargetTypeSetting



6095
6096
6097
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6095

def geo_target_type_setting
  @geo_target_type_setting
end

#idFixnum

Output only. The ID of the campaign. Corresponds to the JSON property id

Returns:

  • (Fixnum)


6100
6101
6102
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6100

def id
  @id
end

#labelsArray<String>

Output only. The resource names of labels attached to this campaign. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


6105
6106
6107
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6105

def labels
  @labels
end

#last_modified_timeString

Output only. The datetime when this campaign was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


6111
6112
6113
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6111

def last_modified_time
  @last_modified_time
end

#manual_cpaGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpa

Manual bidding strategy that allows advertiser to set the bid per advertiser- specified action. Corresponds to the JSON property manualCpa



6117
6118
6119
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6117

def manual_cpa
  @manual_cpa
end

#manual_cpcGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpc

Manual click-based bidding where user pays per click. Corresponds to the JSON property manualCpc



6122
6123
6124
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6122

def manual_cpc
  @manual_cpc
end

#manual_cpmGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpm

Manual impression-based bidding where user pays per thousand impressions. Corresponds to the JSON property manualCpm



6127
6128
6129
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6127

def manual_cpm
  @manual_cpm
end

#maximize_conversion_valueGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



6133
6134
6135
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6133

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



6139
6140
6141
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6139

def maximize_conversions
  @maximize_conversions
end

#nameString

The name of the campaign. This field is required and should not be empty when creating new campaigns. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


6146
6147
6148
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6146

def name
  @name
end

#network_settingsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings

The network settings for the campaign. Corresponds to the JSON property networkSettings



6151
6152
6153
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6151

def network_settings
  @network_settings
end

#optimization_goal_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignOptimizationGoalSetting

Optimization goal setting for this campaign, which includes a set of optimization goal types. Corresponds to the JSON property optimizationGoalSetting



6157
6158
6159
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6157

def optimization_goal_setting
  @optimization_goal_setting
end

#percent_cpcGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonPercentCpc

A bidding strategy where bids are a fraction of the advertised price for some good or service. Corresponds to the JSON property percentCpc



6163
6164
6165
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6163

def percent_cpc
  @percent_cpc
end

#real_time_bidding_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonRealTimeBiddingSetting

Settings for Real-Time Bidding, a feature only available for campaigns targeting the Ad Exchange network. Corresponds to the JSON property realTimeBiddingSetting



6169
6170
6171
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6169

def real_time_bidding_setting
  @real_time_bidding_setting
end

#resource_nameString

Immutable. The resource name of the campaign. Campaign resource names have the form: customers/customer_id/campaigns/campaign_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6175
6176
6177
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6175

def resource_name
  @resource_name
end

#selective_optimizationGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignSelectiveOptimization

Selective optimization setting for this campaign, which includes a set of conversion actions to optimize this campaign towards. This feature only applies to app campaigns that use MULTI_CHANNEL as AdvertisingChannelType and APP_CAMPAIGN or APP_CAMPAIGN_FOR_ENGAGEMENT as AdvertisingChannelSubType. Corresponds to the JSON property selectiveOptimization



6183
6184
6185
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6183

def selective_optimization
  @selective_optimization
end

#serving_statusString

Output only. The ad serving status of the campaign. Corresponds to the JSON property servingStatus

Returns:

  • (String)


6188
6189
6190
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6188

def serving_status
  @serving_status
end

#shopping_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting

The setting for Shopping campaigns. Defines the universe of products that can be advertised by the campaign, and how this campaign interacts with other Shopping campaigns. Corresponds to the JSON property shoppingSetting



6195
6196
6197
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6195

def shopping_setting
  @shopping_setting
end

#start_dateString

The date when campaign started in serving customer's timezone in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


6201
6202
6203
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6201

def start_date
  @start_date
end

#statusString

The status of the campaign. When a new campaign is added, the status defaults to ENABLED. Corresponds to the JSON property status

Returns:

  • (String)


6207
6208
6209
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6207

def status
  @status
end

#target_cpaGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



6213
6214
6215
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6213

def target_cpa
  @target_cpa
end

#target_cpmGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpm

Target CPM (cost per thousand impressions) is an automated bidding strategy that sets bids to optimize performance given the target CPM you set. Corresponds to the JSON property targetCpm



6219
6220
6221
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6219

def target_cpm
  @target_cpm
end

#target_impression_shareGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



6225
6226
6227
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6225

def target_impression_share
  @target_impression_share
end

#target_roasGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



6231
6232
6233
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6231

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



6237
6238
6239
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6237

def target_spend
  @target_spend
end

#tracking_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignTrackingSetting

Campaign-level settings for tracking information. Corresponds to the JSON property trackingSetting



6242
6243
6244
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6242

def tracking_setting
  @tracking_setting
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


6247
6248
6249
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6247

def tracking_url_template
  @tracking_url_template
end

#url_custom_parametersArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>

The list of mappings used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. Corresponds to the JSON property urlCustomParameters



6253
6254
6255
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6253

def url_custom_parameters
  @url_custom_parameters
end

#url_expansion_opt_outBoolean Also known as: url_expansion_opt_out?

Represents opting out of URL expansion to more targeted URLs. If opted out ( true), only the final URLs in the asset group or URLs specified in the advertiser's Google Merchant Center or business data feeds are targeted. If opted in (false), the entire domain will be targeted. This field can only be set for Performance Max campaigns, where the default value is false. Corresponds to the JSON property urlExpansionOptOut

Returns:

  • (Boolean)


6262
6263
6264
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6262

def url_expansion_opt_out
  @url_expansion_opt_out
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6270

def update!(**args)
  @accessible_bidding_strategy = args[:accessible_bidding_strategy] if args.key?(:accessible_bidding_strategy)
  @ad_serving_optimization_status = args[:ad_serving_optimization_status] if args.key?(:ad_serving_optimization_status)
  @advertising_channel_sub_type = args[:advertising_channel_sub_type] if args.key?(:advertising_channel_sub_type)
  @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type)
  @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy)
  @bidding_strategy_system_status = args[:bidding_strategy_system_status] if args.key?(:bidding_strategy_system_status)
  @bidding_strategy_type = args[:bidding_strategy_type] if args.key?(:bidding_strategy_type)
  @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @dynamic_search_ads_setting = args[:dynamic_search_ads_setting] if args.key?(:dynamic_search_ads_setting)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @end_date = args[:end_date] if args.key?(:end_date)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types)
  @feed_types = args[:feed_types] if args.key?(:feed_types)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @frequency_caps = args[:frequency_caps] if args.key?(:frequency_caps)
  @geo_target_type_setting = args[:geo_target_type_setting] if args.key?(:geo_target_type_setting)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @manual_cpa = args[:manual_cpa] if args.key?(:manual_cpa)
  @manual_cpc = args[:manual_cpc] if args.key?(:manual_cpc)
  @manual_cpm = args[:manual_cpm] if args.key?(:manual_cpm)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @network_settings = args[:network_settings] if args.key?(:network_settings)
  @optimization_goal_setting = args[:optimization_goal_setting] if args.key?(:optimization_goal_setting)
  @percent_cpc = args[:percent_cpc] if args.key?(:percent_cpc)
  @real_time_bidding_setting = args[:real_time_bidding_setting] if args.key?(:real_time_bidding_setting)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @selective_optimization = args[:selective_optimization] if args.key?(:selective_optimization)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @shopping_setting = args[:shopping_setting] if args.key?(:shopping_setting)
  @start_date = args[:start_date] if args.key?(:start_date)
  @status = args[:status] if args.key?(:status)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_cpm = args[:target_cpm] if args.key?(:target_cpm)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @tracking_setting = args[:tracking_setting] if args.key?(:tracking_setting)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @url_expansion_opt_out = args[:url_expansion_opt_out] if args.key?(:url_expansion_opt_out)
end