Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

CampaignAssetSet is the linkage between a campaign and an asset set. Adding a CampaignAssetSet links an asset set with a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignAssetSet

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignAssetSet.



6387
6388
6389
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_setString

Immutable. The asset set which is linked to the campaign. Corresponds to the JSON property assetSet

Returns:

  • (String)


6368
6369
6370
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6368

def asset_set
  @asset_set
end

#campaignString

Immutable. The campaign to which this asset set is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


6373
6374
6375
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6373

def campaign
  @campaign
end

#resource_nameString

Immutable. The resource name of the campaign asset set. Asset set asset resource names have the form: customers/customer_id/campaignAssetSets/ campaign_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6380
6381
6382
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6380

def resource_name
  @resource_name
end

#statusString

Output only. The status of the campaign asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


6385
6386
6387
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6385

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6392
6393
6394
6395
6396
6397
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6392

def update!(**args)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end