Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A campaign audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated by campaign and audience criterion. This view only includes audiences attached at the campaign level.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignAudienceView
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCampaignAudienceView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignAudienceView
Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignAudienceView.
6333 6334 6335 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the campaign audience view. Campaign
audience view resource names have the form: customers/customer_id/
campaignAudienceViews/campaign_id~criterion_id`
Corresponds to the JSON propertyresourceName`
6331 6332 6333 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6331 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6338 6339 6340 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6338 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |