Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A campaign criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignCriterion

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignCriterion.



6569
6570
6571
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



6478
6479
6480
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6478

def age_range
  @age_range
end

#bid_modifierFloat

The modifier for the bids when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Use 0 to opt out of a Device type. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


6485
6486
6487
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6485

def bid_modifier
  @bid_modifier
end

#criterion_idFixnum

Output only. The ID of the criterion. This field is ignored during mutate. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


6490
6491
6492
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6490

def criterion_id
  @criterion_id
end

#deviceGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonDeviceInfo

A device criterion. Corresponds to the JSON property device



6495
6496
6497
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6495

def device
  @device
end

#display_nameString

Output only. The display name of the criterion. This field is ignored for mutates. Corresponds to the JSON property displayName

Returns:

  • (String)


6501
6502
6503
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6501

def display_name
  @display_name
end

#genderGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



6506
6507
6508
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6506

def gender
  @gender
end

#keywordGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keyword



6511
6512
6513
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6511

def keyword
  @keyword
end

#languageGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLanguageInfo

A language criterion. Corresponds to the JSON property language



6516
6517
6518
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6516

def language
  @language
end

#last_modified_timeString

Output only. The datetime when this campaign criterion was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


6523
6524
6525
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6523

def last_modified_time
  @last_modified_time
end

#locationGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationInfo

A location criterion. Corresponds to the JSON property location



6528
6529
6530
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6528

def location
  @location
end

#location_groupGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationGroupInfo

A radius around a list of locations specified through a feed. Corresponds to the JSON property locationGroup



6533
6534
6535
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6533

def location_group
  @location_group
end

#negativeBoolean Also known as: negative?

Immutable. Whether to target (false) or exclude (true) the criterion. Corresponds to the JSON property negative

Returns:

  • (Boolean)


6538
6539
6540
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6538

def negative
  @negative
end

#resource_nameString

Immutable. The resource name of the campaign criterion. Campaign criterion resource names have the form: customers/customer_id/campaignCriteria/ campaign_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6546
6547
6548
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6546

def resource_name
  @resource_name
end

#statusString

The status of the criterion. Corresponds to the JSON property status

Returns:

  • (String)


6551
6552
6553
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6551

def status
  @status
end

#typeString

Output only. The type of the criterion. Corresponds to the JSON property type

Returns:

  • (String)


6556
6557
6558
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6556

def type
  @type
end

#user_listGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



6562
6563
6564
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6562

def user_list
  @user_list
end

#webpageGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageInfo

Represents a criterion for targeting webpages of an advertiser's website. Corresponds to the JSON property webpage



6567
6568
6569
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6567

def webpage
  @webpage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6574
6575
6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6574

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @device = args[:device] if args.key?(:device)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gender = args[:gender] if args.key?(:gender)
  @keyword = args[:keyword] if args.key?(:keyword)
  @language = args[:language] if args.key?(:language)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @location = args[:location] if args.key?(:location)
  @location_group = args[:location_group] if args.key?(:location_group)
  @negative = args[:negative] if args.key?(:negative)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @user_list = args[:user_list] if args.key?(:user_list)
  @webpage = args[:webpage] if args.key?(:webpage)
end