Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

The setting for controlling Dynamic Search Ads (DSA).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting.



3733
3734
3735
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_nameString

Required. The Internet domain name that this setting represents, for example, " google.com" or "www.google.com". Corresponds to the JSON property domainName

Returns:

  • (String)


3719
3720
3721
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3719

def domain_name
  @domain_name
end

#language_codeString

Required. The language code specifying the language of the domain, for example, "en". Corresponds to the JSON property languageCode

Returns:

  • (String)


3725
3726
3727
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3725

def language_code
  @language_code
end

#use_supplied_urls_onlyBoolean Also known as: use_supplied_urls_only?

Whether the campaign uses advertiser supplied URLs exclusively. Corresponds to the JSON property useSuppliedUrlsOnly

Returns:

  • (Boolean)


3730
3731
3732
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3730

def use_supplied_urls_only
  @use_supplied_urls_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3738
3739
3740
3741
3742
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3738

def update!(**args)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @language_code = args[:language_code] if args.key?(:language_code)
  @use_supplied_urls_only = args[:use_supplied_urls_only] if args.key?(:use_supplied_urls_only)
end