Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Represents a relationship between a campaign and an effective label. An effective label is a label inherited or directly assigned to this campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel.



6541
6542
6543
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign to which the effective label is attached. Corresponds to the JSON property campaign

Returns:

  • (String)


6522
6523
6524
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6522

def campaign
  @campaign
end

#labelString

Immutable. The effective label assigned to the campaign. Corresponds to the JSON property label

Returns:

  • (String)


6527
6528
6529
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6527

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


6532
6533
6534
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6532

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. Name of the resource. CampaignEffectivelabel resource names have the form: customers/owner_customer_id/campaignEffectiveLabels/campaign_id~ label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6539
6540
6541
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6539

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6546
6547
6548
6549
6550
6551
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6546

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end