Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCartDataSalesView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Cart data sales view. Provides information about the products which were purchased if conversions with cart data is implemented. Performance metrics like revenue, gross profit, lead/cross-sell metrics etc. and Merchant Center attributes such as brand, category etc. are available for products defined in an inventory feed and sold as a result of Google ads. For purchases attributed to clicks on Shopping ads, dimensions of both clicked and sold products can be viewed together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCartDataSalesView

Returns a new instance of GoogleAdsSearchads360V0ResourcesCartDataSalesView.



6608
6609
6610
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the Cart data sales view. Cart data sales view resource names have the form: customers/customer_id/cartDataSalesView Corresponds to the JSON property resourceName

Returns:

  • (String)


6606
6607
6608
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6606

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6613
6614
6615
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6613

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end