Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A conversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversion

Returns a new instance of GoogleAdsSearchads360V0ResourcesConversion.



6844
6845
6846
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_idFixnum

Output only. Ad ID. A value of 0 indicates that the ad is unattributed. Corresponds to the JSON property adId

Returns:

  • (Fixnum)


6706
6707
6708
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6706

def ad_id
  @ad_id
end

#advertiser_conversion_idString

Output only. For offline conversions, this is an ID provided by advertisers. If an advertiser doesn't specify such an ID, Search Ads 360 generates one. For online conversions, this is equal to the id column or the floodlight_order_id column depending on the advertiser's Floodlight instructions. Corresponds to the JSON property advertiserConversionId

Returns:

  • (String)


6714
6715
6716
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6714

def advertiser_conversion_id
  @advertiser_conversion_id
end

#asset_field_typeString

Output only. Asset field type of the conversion event. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


6719
6720
6721
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6719

def asset_field_type
  @asset_field_type
end

#asset_idFixnum

Output only. ID of the asset which was interacted with during the conversion event. Corresponds to the JSON property assetId

Returns:

  • (Fixnum)


6725
6726
6727
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6725

def asset_id
  @asset_id
end

#attribution_typeString

Output only. What the conversion is attributed to: Visit or Keyword+Ad. Corresponds to the JSON property attributionType

Returns:

  • (String)


6730
6731
6732
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6730

def attribution_type
  @attribution_type
end

#click_idString

Output only. A unique string, for the visit that the conversion is attributed to, that is passed to the landing page as the click id URL parameter. Corresponds to the JSON property clickId

Returns:

  • (String)


6736
6737
6738
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6736

def click_id
  @click_id
end

#conversion_date_timeString

Output only. The timestamp of the conversion event. Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


6741
6742
6743
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6741

def conversion_date_time
  @conversion_date_time
end

#conversion_last_modified_date_timeString

Output only. The timestamp of the last time the conversion was modified. Corresponds to the JSON property conversionLastModifiedDateTime

Returns:

  • (String)


6746
6747
6748
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6746

def conversion_last_modified_date_time
  @conversion_last_modified_date_time
end

#conversion_quantityFixnum

Output only. The quantity of items recorded by the conversion, as determined by the qty url parameter. The advertiser is responsible for dynamically populating the parameter (such as number of items sold in the conversion), otherwise it defaults to 1. Corresponds to the JSON property conversionQuantity

Returns:

  • (Fixnum)


6754
6755
6756
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6754

def conversion_quantity
  @conversion_quantity
end

#conversion_revenue_microsFixnum

Output only. The adjusted revenue in micros for the conversion event. This will always be in the currency of the serving account. Corresponds to the JSON property conversionRevenueMicros

Returns:

  • (Fixnum)


6760
6761
6762
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6760

def conversion_revenue_micros
  @conversion_revenue_micros
end

#conversion_visit_date_timeString

Output only. The timestamp of the visit that the conversion is attributed to. Corresponds to the JSON property conversionVisitDateTime

Returns:

  • (String)


6765
6766
6767
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6765

def conversion_visit_date_time
  @conversion_visit_date_time
end

#criterion_idFixnum

Output only. Search Ads 360 criterion ID. A value of 0 indicates that the criterion is unattributed. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


6771
6772
6773
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6771

def criterion_id
  @criterion_id
end

#floodlight_order_idString

Output only. The Floodlight order ID provided by the advertiser for the conversion. Corresponds to the JSON property floodlightOrderId

Returns:

  • (String)


6777
6778
6779
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6777

def floodlight_order_id
  @floodlight_order_id
end

#floodlight_original_revenueFixnum

Output only. The original, unchanged revenue associated with the Floodlight event (in the currency of the current report), before Floodlight currency instruction modifications. Corresponds to the JSON property floodlightOriginalRevenue

Returns:

  • (Fixnum)


6784
6785
6786
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6784

def floodlight_original_revenue
  @floodlight_original_revenue
end

#idFixnum

Output only. The ID of the conversion Corresponds to the JSON property id

Returns:

  • (Fixnum)


6789
6790
6791
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6789

def id
  @id
end

#merchant_idFixnum

Output only. The Search Ads 360 inventory account ID containing the product that was clicked on. Search Ads 360 generates this ID when you link an inventory account in Search Ads 360. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


6796
6797
6798
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6796

def merchant_id
  @merchant_id
end

#product_channelString

Output only. The sales channel of the product that was clicked on: Online or Local. Corresponds to the JSON property productChannel

Returns:

  • (String)


6802
6803
6804
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6802

def product_channel
  @product_channel
end

#product_country_codeString

Output only. The country (ISO-3166-format) registered for the inventory feed that contains the product clicked on. Corresponds to the JSON property productCountryCode

Returns:

  • (String)


6808
6809
6810
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6808

def product_country_code
  @product_country_code
end

#product_idString

Output only. The ID of the product clicked on. Corresponds to the JSON property productId

Returns:

  • (String)


6813
6814
6815
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6813

def product_id
  @product_id
end

#product_language_codeString

Output only. The language (ISO-639-1) that has been set for the Merchant Center feed containing data about the product. Corresponds to the JSON property productLanguageCode

Returns:

  • (String)


6819
6820
6821
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6819

def product_language_code
  @product_language_code
end

#product_store_idString

Output only. The store in the Local Inventory Ad that was clicked on. This should match the store IDs used in your local products feed. Corresponds to the JSON property productStoreId

Returns:

  • (String)


6825
6826
6827
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6825

def product_store_id
  @product_store_id
end

#resource_nameString

Output only. The resource name of the conversion. Conversion resource names have the form: customers/customer_id/conversions/ad_group_id~ criterion_id~ds_conversion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6832
6833
6834
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6832

def resource_name
  @resource_name
end

#statusString

Output only. The status of the conversion, either ENABLED or REMOVED.. Corresponds to the JSON property status

Returns:

  • (String)


6837
6838
6839
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6837

def status
  @status
end

#visit_idFixnum

Output only. The Search Ads 360 visit ID that the conversion is attributed to. Corresponds to the JSON property visitId

Returns:

  • (Fixnum)


6842
6843
6844
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6842

def visit_id
  @visit_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6849

def update!(**args)
  @ad_id = args[:ad_id] if args.key?(:ad_id)
  @advertiser_conversion_id = args[:advertiser_conversion_id] if args.key?(:advertiser_conversion_id)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
  @asset_id = args[:asset_id] if args.key?(:asset_id)
  @attribution_type = args[:attribution_type] if args.key?(:attribution_type)
  @click_id = args[:click_id] if args.key?(:click_id)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @conversion_last_modified_date_time = args[:conversion_last_modified_date_time] if args.key?(:conversion_last_modified_date_time)
  @conversion_quantity = args[:conversion_quantity] if args.key?(:conversion_quantity)
  @conversion_revenue_micros = args[:conversion_revenue_micros] if args.key?(:conversion_revenue_micros)
  @conversion_visit_date_time = args[:conversion_visit_date_time] if args.key?(:conversion_visit_date_time)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @floodlight_order_id = args[:floodlight_order_id] if args.key?(:floodlight_order_id)
  @floodlight_original_revenue = args[:floodlight_original_revenue] if args.key?(:floodlight_original_revenue)
  @id = args[:id] if args.key?(:id)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @product_channel = args[:product_channel] if args.key?(:product_channel)
  @product_country_code = args[:product_country_code] if args.key?(:product_country_code)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_language_code = args[:product_language_code] if args.key?(:product_language_code)
  @product_store_id = args[:product_store_id] if args.key?(:product_store_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @visit_id = args[:visit_id] if args.key?(:visit_id)
end