Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionCustomVariable

Returns a new instance of GoogleAdsSearchads360V0ResourcesConversionCustomVariable.



7069
7070
7071
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

Output only. Cardinality of the conversion custom variable. Corresponds to the JSON property cardinality

Returns:

  • (String)


7014
7015
7016
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7014

def cardinality
  @cardinality
end

#custom_column_idsArray<Fixnum>

Output only. The IDs of custom columns that use this conversion custom variable. Corresponds to the JSON property customColumnIds

Returns:

  • (Array<Fixnum>)


7020
7021
7022
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7020

def custom_column_ids
  @custom_column_ids
end

#familyString

Output only. Family of the conversion custom variable. Corresponds to the JSON property family

Returns:

  • (String)


7025
7026
7027
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7025

def family
  @family
end

#floodlight_conversion_custom_variable_infoGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo

Information for Search Ads 360 Floodlight Conversion Custom Variables. Corresponds to the JSON property floodlightConversionCustomVariableInfo



7030
7031
7032
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7030

def floodlight_conversion_custom_variable_info
  @floodlight_conversion_custom_variable_info
end

#idFixnum

Output only. The ID of the conversion custom variable. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7035
7036
7037
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7035

def id
  @id
end

#nameString

Required. The name of the conversion custom variable. Name should be unique. The maximum length of name is 100 characters. There should not be any extra spaces before and after. Corresponds to the JSON property name

Returns:

  • (String)


7042
7043
7044
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7042

def name
  @name
end

#owner_customerString

Output only. The resource name of the customer that owns the conversion custom variable. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


7048
7049
7050
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7048

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion custom variable. Conversion custom variable resource names have the form: customers/customer_id/ conversionCustomVariables/conversion_custom_variable_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


7055
7056
7057
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7055

def resource_name
  @resource_name
end

#statusString

The status of the conversion custom variable for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


7060
7061
7062
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7060

def status
  @status
end

#tagString

Required. Immutable. The tag of the conversion custom variable. Tag should be unique and consist of a "u" character directly followed with a number less than ormequal to 100. For example: "u4". Corresponds to the JSON property tag

Returns:

  • (String)


7067
7068
7069
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7067

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7074

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @custom_column_ids = args[:custom_column_ids] if args.key?(:custom_column_ids)
  @family = args[:family] if args.key?(:family)
  @floodlight_conversion_custom_variable_info = args[:floodlight_conversion_custom_variable_info] if args.key?(:floodlight_conversion_custom_variable_info)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end