Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A collection of customer-wide settings related to Search Ads 360 Conversion Tracking.
Instance Attribute Summary collapse
-
#accepted_customer_data_terms ⇒ Boolean
(also: #accepted_customer_data_terms?)
Output only.
-
#conversion_tracking_id ⇒ Fixnum
Output only.
-
#conversion_tracking_status ⇒ String
Output only.
-
#cross_account_conversion_tracking_id ⇒ Fixnum
Output only.
-
#enhanced_conversions_for_leads_enabled ⇒ Boolean
(also: #enhanced_conversions_for_leads_enabled?)
Output only.
-
#google_ads_conversion_customer ⇒ String
Output only.
-
#google_ads_cross_account_conversion_tracking_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
constructor
A new instance of GoogleAdsSearchads360V0ResourcesConversionTrackingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
Returns a new instance of GoogleAdsSearchads360V0ResourcesConversionTrackingSetting.
7146 7147 7148 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted_customer_data_terms ⇒ Boolean Also known as: accepted_customer_data_terms?
Output only. Whether the customer has accepted customer data terms. If using
cross-account conversion tracking, this value is inherited from the manager.
This field is read-only. For more information, see https://support.google.com/
adspolicy/answer/7475709.
Corresponds to the JSON property acceptedCustomerDataTerms
7099 7100 7101 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7099 def accepted_customer_data_terms @accepted_customer_data_terms end |
#conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id used for this account. This id doesn't
indicate whether the customer uses conversion tracking (
conversion_tracking_status does). This field is read-only.
Corresponds to the JSON property conversionTrackingId
7107 7108 7109 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7107 def conversion_tracking_id @conversion_tracking_id end |
#conversion_tracking_status ⇒ String
Output only. Conversion tracking status. It indicates whether the customer is
using conversion tracking, and who is the conversion tracking owner of this
customer. If this customer is using cross-account conversion tracking, the
value returned will differ based on the login-customer-id of the request.
Corresponds to the JSON property conversionTrackingStatus
7115 7116 7117 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7115 def conversion_tracking_status @conversion_tracking_status end |
#cross_account_conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id of the customer's manager. This is set
when the customer is opted into cross-account conversion tracking, and it
overrides conversion_tracking_id.
Corresponds to the JSON property crossAccountConversionTrackingId
7122 7123 7124 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7122 def cross_account_conversion_tracking_id @cross_account_conversion_tracking_id end |
#enhanced_conversions_for_leads_enabled ⇒ Boolean Also known as: enhanced_conversions_for_leads_enabled?
Output only. Whether the customer is opted-in for enhanced conversions for
leads. If using cross-account conversion tracking, this value is inherited
from the manager. This field is read-only.
Corresponds to the JSON property enhancedConversionsForLeadsEnabled
7129 7130 7131 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7129 def enhanced_conversions_for_leads_enabled @enhanced_conversions_for_leads_enabled end |
#google_ads_conversion_customer ⇒ String
Output only. The resource name of the customer where conversions are created
and managed. This field is read-only.
Corresponds to the JSON property googleAdsConversionCustomer
7136 7137 7138 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7136 def google_ads_conversion_customer @google_ads_conversion_customer end |
#google_ads_cross_account_conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id of the customer's manager. This is set
when the customer is opted into conversion tracking, and it overrides
conversion_tracking_id. This field can only be managed through the Google Ads
UI. This field is read-only.
Corresponds to the JSON property googleAdsCrossAccountConversionTrackingId
7144 7145 7146 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7144 def google_ads_cross_account_conversion_tracking_id @google_ads_cross_account_conversion_tracking_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7151 7152 7153 7154 7155 7156 7157 7158 7159 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7151 def update!(**args) @accepted_customer_data_terms = args[:accepted_customer_data_terms] if args.key?(:accepted_customer_data_terms) @conversion_tracking_id = args[:conversion_tracking_id] if args.key?(:conversion_tracking_id) @conversion_tracking_status = args[:conversion_tracking_status] if args.key?(:conversion_tracking_status) @cross_account_conversion_tracking_id = args[:cross_account_conversion_tracking_id] if args.key?(:cross_account_conversion_tracking_id) @enhanced_conversions_for_leads_enabled = args[:enhanced_conversions_for_leads_enabled] if args.key?(:enhanced_conversions_for_leads_enabled) @google_ads_conversion_customer = args[:google_ads_conversion_customer] if args.key?(:google_ads_conversion_customer) @google_ads_cross_account_conversion_tracking_id = args[:google_ads_cross_account_conversion_tracking_id] if args.key?(:google_ads_cross_account_conversion_tracking_id) end |