Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomColumn
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A custom column. See Search Ads 360 custom column at https://support.google. com/sa360/answer/9633916
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#queryable ⇒ Boolean
(also: #queryable?)
Output only.
-
#referenced_system_columns ⇒ Array<String>
Output only.
-
#references_attributes ⇒ Boolean
(also: #references_attributes?)
Output only.
-
#references_metrics ⇒ Boolean
(also: #references_metrics?)
Output only.
-
#render_type ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#value_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomColumn
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCustomColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomColumn
Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomColumn.
7144 7145 7146 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. User-defined description of the custom column.
Corresponds to the JSON property description
7089 7090 7091 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7089 def description @description end |
#id ⇒ Fixnum
Output only. ID of the custom column.
Corresponds to the JSON property id
7094 7095 7096 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7094 def id @id end |
#name ⇒ String
Output only. User-defined name of the custom column.
Corresponds to the JSON property name
7099 7100 7101 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7099 def name @name end |
#queryable ⇒ Boolean Also known as: queryable?
Output only. True when the custom column is available to be used in the query
of SearchAds360Service.Search and SearchAds360Service.SearchStream.
Corresponds to the JSON property queryable
7105 7106 7107 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7105 def queryable @queryable end |
#referenced_system_columns ⇒ Array<String>
Output only. The list of the referenced system columns of this custom column.
For example, A custom column "sum of impressions and clicks" has referenced
system columns of "metrics.clicks", "metrics.impressions".
Corresponds to the JSON property referencedSystemColumns
7113 7114 7115 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7113 def referenced_system_columns @referenced_system_columns end |
#references_attributes ⇒ Boolean Also known as: references_attributes?
Output only. True when the custom column is referring to one or more
attributes.
Corresponds to the JSON property referencesAttributes
7119 7120 7121 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7119 def references_attributes @references_attributes end |
#references_metrics ⇒ Boolean Also known as: references_metrics?
Output only. True when the custom column is referring to one or more metrics.
Corresponds to the JSON property referencesMetrics
7125 7126 7127 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7125 def references_metrics @references_metrics end |
#render_type ⇒ String
Output only. How the result value of the custom column should be interpreted.
Corresponds to the JSON property renderType
7131 7132 7133 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7131 def render_type @render_type end |
#resource_name ⇒ String
Immutable. The resource name of the custom column. Custom column resource
names have the form: customers/customer_id/customColumns/custom_column_id`
Corresponds to the JSON propertyresourceName`
7137 7138 7139 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7137 def resource_name @resource_name end |
#value_type ⇒ String
Output only. The type of the result value of the custom column.
Corresponds to the JSON property valueType
7142 7143 7144 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7142 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7149 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @queryable = args[:queryable] if args.key?(:queryable) @referenced_system_columns = args[:referenced_system_columns] if args.key?(:referenced_system_columns) @references_attributes = args[:references_attributes] if args.key?(:references_attributes) @references_metrics = args[:references_metrics] if args.key?(:references_metrics) @render_type = args[:render_type] if args.key?(:render_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @value_type = args[:value_type] if args.key?(:value_type) end |