Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

CustomerAssetSet is the linkage between a customer and an asset set. Adding a CustomerAssetSet links an asset set with a customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerAssetSet

Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomerAssetSet.



7392
7393
7394
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_setString

Immutable. The asset set which is linked to the customer. Corresponds to the JSON property assetSet

Returns:

  • (String)


7373
7374
7375
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7373

def asset_set
  @asset_set
end

#customerString

Immutable. The customer to which this asset set is linked. Corresponds to the JSON property customer

Returns:

  • (String)


7378
7379
7380
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7378

def customer
  @customer
end

#resource_nameString

Immutable. The resource name of the customer asset set. Asset set asset resource names have the form: customers/customer_id/customerAssetSets/ asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


7385
7386
7387
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7385

def resource_name
  @resource_name
end

#statusString

Output only. The status of the customer asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


7390
7391
7392
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7390

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7397
7398
7399
7400
7401
7402
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7397

def update!(**args)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @customer = args[:customer] if args.key?(:customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end