Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Represents customer-manager link relationship.
Instance Attribute Summary collapse
-
#manager_customer ⇒ String
Output only.
-
#manager_link_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Status of the link between the customer and the manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerManagerLink
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCustomerManagerLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerManagerLink
Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomerManagerLink.
7616 7617 7618 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manager_customer ⇒ String
Output only. The manager customer linked to the customer.
Corresponds to the JSON property managerCustomer
7591 7592 7593 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7591 def manager_customer @manager_customer end |
#manager_link_id ⇒ Fixnum
Output only. ID of the customer-manager link. This field is read only.
Corresponds to the JSON property managerLinkId
7596 7597 7598 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7596 def manager_link_id @manager_link_id end |
#resource_name ⇒ String
Immutable. Name of the resource. CustomerManagerLink resource names have the
form: customers/customer_id/customerManagerLinks/manager_customer_id~
manager_link_id`
Corresponds to the JSON propertyresourceName`
7603 7604 7605 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7603 def resource_name @resource_name end |
#start_time ⇒ String
Output only. The timestamp when the CustomerManagerLink was created. The
timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property startTime
7609 7610 7611 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7609 def start_time @start_time end |
#status ⇒ String
Status of the link between the customer and the manager.
Corresponds to the JSON property status
7614 7615 7616 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7614 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7621 def update!(**args) @manager_customer = args[:manager_customer] if args.key?(:manager_customer) @manager_link_id = args[:manager_link_id] if args.key?(:manager_link_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) end |