Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
DoubleClick Campaign Manager (DCM) setting for a manager customer.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#network_id ⇒ Fixnum
Output only.
-
#time_zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
constructor
A new instance of GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
Returns a new instance of GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting.
7570 7571 7572 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. ID of the Campaign Manager advertiser associated with this
customer.
Corresponds to the JSON property advertiserId
7557 7558 7559 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7557 def advertiser_id @advertiser_id end |
#network_id ⇒ Fixnum
Output only. ID of the Campaign Manager network associated with this customer.
Corresponds to the JSON property networkId
7562 7563 7564 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7562 def network_id @network_id end |
#time_zone ⇒ String
Output only. Time zone of the Campaign Manager network associated with this
customer in IANA Time Zone Database format, such as America/New_York.
Corresponds to the JSON property timeZone
7568 7569 7570 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7568 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7575 7576 7577 7578 7579 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7575 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @network_id = args[:network_id] if args.key?(:network_id) @time_zone = args[:time_zone] if args.key?(:time_zone) end |