Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A gender view resource. Represents the view of a customer's performance
metrics aggregated by gender. All statistics are aggregated at the ad group
level. Note: While you can segment metrics by age range using age_range_view
or by gender using gender_view, the Search Ads 360 API does not support
segmenting metrics by both age range and gender simultaneously in a single
query. Analyzing performance across both dimensions combined is not supported
in the Search Ads 360 API.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGenderView
constructor
A new instance of GoogleAdsSearchads360V0ResourcesGenderView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGenderView
Returns a new instance of GoogleAdsSearchads360V0ResourcesGenderView.
7710 7711 7712 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the gender view. Gender view resource names
have the form: customers/customer_id/genderViews/ad_group_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
7708 7709 7710 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7708 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7715 7716 7717 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7715 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |