Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A geo target constant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGeoTargetConstant

Returns a new instance of GoogleAdsSearchads360V0ResourcesGeoTargetConstant.



7769
7770
7771
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_nameString

Output only. The fully qualified English name, consisting of the target's name and that of its parent and country. Corresponds to the JSON property canonicalName

Returns:

  • (String)


7728
7729
7730
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7728

def canonical_name
  @canonical_name
end

#country_codeString

Output only. The ISO-3166-1 alpha-2 country code that is associated with the target. Corresponds to the JSON property countryCode

Returns:

  • (String)


7734
7735
7736
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7734

def country_code
  @country_code
end

#idFixnum

Output only. The ID of the geo target constant. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7739
7740
7741
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7739

def id
  @id
end

#nameString

Output only. Geo target constant English name. Corresponds to the JSON property name

Returns:

  • (String)


7744
7745
7746
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7744

def name
  @name
end

#parent_geo_targetString

Output only. The resource name of the parent geo target constant. Geo target constant resource names have the form: geoTargetConstants/ parent_geo_target_constant_id` Corresponds to the JSON propertyparentGeoTarget`

Returns:

  • (String)


7751
7752
7753
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7751

def parent_geo_target
  @parent_geo_target
end

#resource_nameString

Output only. The resource name of the geo target constant. Geo target constant resource names have the form: geoTargetConstants/geo_target_constant_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


7757
7758
7759
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7757

def resource_name
  @resource_name
end

#statusString

Output only. Geo target constant status. Corresponds to the JSON property status

Returns:

  • (String)


7762
7763
7764
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7762

def status
  @status
end

#target_typeString

Output only. Geo target constant target type. Corresponds to the JSON property targetType

Returns:

  • (String)


7767
7768
7769
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7767

def target_type
  @target_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7774

def update!(**args)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @country_code = args[:country_code] if args.key?(:country_code)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @parent_geo_target = args[:parent_geo_target] if args.key?(:parent_geo_target)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @target_type = args[:target_type] if args.key?(:target_type)
end