Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesLabel

Returns a new instance of GoogleAdsSearchads360V0ResourcesLabel.



7754
7755
7756
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. ID of the label. Read only. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7729
7730
7731
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7729

def id
  @id
end

#nameString

The name of the label. This field is required and should not be empty when creating a new label. The length of this string should be between 1 and 80, inclusive. Corresponds to the JSON property name

Returns:

  • (String)


7736
7737
7738
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7736

def name
  @name
end

#resource_nameString

Immutable. Name of the resource. Label resource names have the form: customers/owner_customer_id/labels/label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


7742
7743
7744
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7742

def resource_name
  @resource_name
end

#statusString

Output only. Status of the label. Read only. Corresponds to the JSON property status

Returns:

  • (String)


7747
7748
7749
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7747

def status
  @status
end

#text_labelGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTextLabel

A type of label displaying text on a colored background. Corresponds to the JSON property textLabel



7752
7753
7754
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7752

def text_label
  @text_label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7759
7760
7761
7762
7763
7764
7765
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7759

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @text_label = args[:text_label] if args.key?(:text_label)
end