Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of this user list.
-
#resource_name ⇒ String
Immutable.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserList
constructor
A new instance of GoogleAdsSearchads360V0ResourcesUserList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserList
Returns a new instance of GoogleAdsSearchads360V0ResourcesUserList.
8268 8269 8270 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. Id of the user list.
Corresponds to the JSON property id
8249 8250 8251 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8249 def id @id end |
#name ⇒ String
Name of this user list. Unique per user list, except in some cases where a
user list of the same name has access_reason set to SHARED.
Corresponds to the JSON property name
8255 8256 8257 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8255 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the user list. User list resource names have
the form: customers/customer_id/userLists/user_list_id`
Corresponds to the JSON propertyresourceName`
8261 8262 8263 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8261 def resource_name @resource_name end |
#type ⇒ String
Output only. Type of this list. This field is read-only.
Corresponds to the JSON property type
8266 8267 8268 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8266 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8273 8274 8275 8276 8277 8278 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8273 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @type = args[:type] if args.key?(:type) end |