Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesVisit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A visit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesVisit

Returns a new instance of GoogleAdsSearchads360V0ResourcesVisit.



8403
8404
8405
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_idFixnum

Output only. Ad ID. A value of 0 indicates that the ad is unattributed. Corresponds to the JSON property adId

Returns:

  • (Fixnum)


8325
8326
8327
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8325

def ad_id
  @ad_id
end

#asset_field_typeString

Output only. Asset field type of the visit event. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


8330
8331
8332
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8330

def asset_field_type
  @asset_field_type
end

#asset_idFixnum

Output only. ID of the asset which was interacted with during the visit event. Corresponds to the JSON property assetId

Returns:

  • (Fixnum)


8335
8336
8337
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8335

def asset_id
  @asset_id
end

#click_idString

Output only. A unique string for each visit that is passed to the landing page as the click id URL parameter. Corresponds to the JSON property clickId

Returns:

  • (String)


8341
8342
8343
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8341

def click_id
  @click_id
end

#criterion_idFixnum

Output only. Search Ads 360 keyword ID. A value of 0 indicates that the keyword is unattributed. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


8347
8348
8349
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8347

def criterion_id
  @criterion_id
end

#idFixnum

Output only. The ID of the visit. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8352
8353
8354
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8352

def id
  @id
end

#merchant_idFixnum

Output only. The Search Ads 360 inventory account ID containing the product that was clicked on. Search Ads 360 generates this ID when you link an inventory account in Search Ads 360. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


8359
8360
8361
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8359

def merchant_id
  @merchant_id
end

#product_channelString

Output only. The sales channel of the product that was clicked on: Online or Local. Corresponds to the JSON property productChannel

Returns:

  • (String)


8365
8366
8367
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8365

def product_channel
  @product_channel
end

#product_country_codeString

Output only. The country (ISO-3166 format) registered for the inventory feed that contains the product clicked on. Corresponds to the JSON property productCountryCode

Returns:

  • (String)


8371
8372
8373
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8371

def product_country_code
  @product_country_code
end

#product_idString

Output only. The ID of the product clicked on. Corresponds to the JSON property productId

Returns:

  • (String)


8376
8377
8378
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8376

def product_id
  @product_id
end

#product_language_codeString

Output only. The language (ISO-639-1) that has been set for the Merchant Center feed containing data about the product. Corresponds to the JSON property productLanguageCode

Returns:

  • (String)


8382
8383
8384
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8382

def product_language_code
  @product_language_code
end

#product_store_idString

Output only. The store in the Local Inventory Ad that was clicked on. This should match the store IDs used in your local products feed. Corresponds to the JSON property productStoreId

Returns:

  • (String)


8388
8389
8390
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8388

def product_store_id
  @product_store_id
end

#resource_nameString

Output only. The resource name of the visit. Visit resource names have the form: customers/customer_id/visits/ad_group_id~criterion_id~ ds_visit_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


8395
8396
8397
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8395

def resource_name
  @resource_name
end

#visit_date_timeString

Output only. The timestamp of the visit event. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property visitDateTime

Returns:

  • (String)


8401
8402
8403
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8401

def visit_date_time
  @visit_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8408
8409
8410
8411
8412
8413
8414
8415
8416
8417
8418
8419
8420
8421
8422
8423
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8408

def update!(**args)
  @ad_id = args[:ad_id] if args.key?(:ad_id)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
  @asset_id = args[:asset_id] if args.key?(:asset_id)
  @click_id = args[:click_id] if args.key?(:click_id)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @id = args[:id] if args.key?(:id)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @product_channel = args[:product_channel] if args.key?(:product_channel)
  @product_country_code = args[:product_country_code] if args.key?(:product_country_code)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_language_code = args[:product_language_code] if args.key?(:product_language_code)
  @product_store_id = args[:product_store_id] if args.key?(:product_store_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @visit_date_time = args[:visit_date_time] if args.key?(:visit_date_time)
end