Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Message for conversion custom metric header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom metric ID.
-
#name ⇒ String
The user defined name of the conversion custom metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader
constructor
A new instance of GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader
Returns a new instance of GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader.
8401 8402 8403 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom metric ID.
Corresponds to the JSON property id
8394 8395 8396 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8394 def id @id end |
#name ⇒ String
The user defined name of the conversion custom metric.
Corresponds to the JSON property name
8399 8400 8401 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8399 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8406 8407 8408 8409 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8406 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |