Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Response message for SearchAds360FieldService.SearchSearchAds360Fields.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results.
-
#results ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesSearchAds360Field>
The list of fields that matched the query.
-
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360FieldsResponse.
9020 9021 9022 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results. Pass the content
of this string as the page_token attribute of the next request.
next_page_token is not returned for the last page.
Corresponds to the JSON property nextPageToken
9008 9009 9010 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9008 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesSearchAds360Field>
The list of fields that matched the query.
Corresponds to the JSON property results
9013 9014 9015 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9013 def results @results end |
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Corresponds to the JSON property totalResultsCount
9018 9019 9020 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9018 def total_results_count @total_results_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9025 9026 9027 9028 9029 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9025 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) @total_results_count = args[:total_results_count] if args.key?(:total_results_count) end |