Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Request message for SearchAds360Service.Search.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#query ⇒ String
Required.
-
#return_total_results_count ⇒ Boolean
(also: #return_total_results_count?)
If true, the total number of results that match the query ignoring the LIMIT clause will be included in the response.
-
#summary_row_setting ⇒ String
Determines whether a summary row will be returned.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Request.
9170 9171 9172 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page. When too large a page is
requested, the server may decide to further limit the number of returned
resources.
Corresponds to the JSON property pageSize
9136 9137 9138 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9136 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results
will be returned. Use the value obtained from next_page_token in the
previous response in order to request the next page of results.
Corresponds to the JSON property pageToken
9143 9144 9145 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9143 def page_token @page_token end |
#query ⇒ String
Required. The query string.
Corresponds to the JSON property query
9148 9149 9150 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9148 def query @query end |
#return_total_results_count ⇒ Boolean Also known as: return_total_results_count?
If true, the total number of results that match the query ignoring the LIMIT
clause will be included in the response. Default is false.
Corresponds to the JSON property returnTotalResultsCount
9154 9155 9156 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9154 def return_total_results_count @return_total_results_count end |
#summary_row_setting ⇒ String
Determines whether a summary row will be returned. By default, summary row is
not returned. If requested, the summary row will be sent in a response by
itself after all other query results are returned.
Corresponds to the JSON property summaryRowSetting
9162 9163 9164 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9162 def summary_row_setting @summary_row_setting end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed.
Corresponds to the JSON property validateOnly
9167 9168 9169 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9167 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9175 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) @return_total_results_count = args[:return_total_results_count] if args.key?(:return_total_results_count) @summary_row_setting = args[:summary_row_setting] if args.key?(:summary_row_setting) @validate_only = args[:validate_only] if args.key?(:validate_only) end |