Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Response
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Response
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Response message for SearchAds360Service.Search.
Instance Attribute Summary collapse
-
#conversion_custom_dimension_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomDimensionHeader>
The headers of the conversion custom dimensions in the results.
-
#conversion_custom_metric_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader>
The headers of the conversion custom metrics in the results.
-
#custom_column_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesCustomColumnHeader>
The headers of the custom columns in the results.
-
#field_mask ⇒ String
FieldMask that represents what fields were requested by the user.
-
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results.
-
#raw_event_conversion_dimension_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionDimensionHeader>
The headers of the raw event conversion dimensions in the results.
-
#raw_event_conversion_metric_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader>
The headers of the raw event conversion metrics in the results.
-
#results ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row>
The list of rows that matched the query.
-
#summary_row ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
A returned row from the query.
-
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Response
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Response.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Response
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Response.
9241 9242 9243 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_custom_dimension_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomDimensionHeader>
The headers of the conversion custom dimensions in the results.
Corresponds to the JSON property conversionCustomDimensionHeaders
9192 9193 9194 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9192 def conversion_custom_dimension_headers @conversion_custom_dimension_headers end |
#conversion_custom_metric_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesConversionCustomMetricHeader>
The headers of the conversion custom metrics in the results.
Corresponds to the JSON property conversionCustomMetricHeaders
9197 9198 9199 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9197 def conversion_custom_metric_headers @conversion_custom_metric_headers end |
#custom_column_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesCustomColumnHeader>
The headers of the custom columns in the results.
Corresponds to the JSON property customColumnHeaders
9202 9203 9204 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9202 def custom_column_headers @custom_column_headers end |
#field_mask ⇒ String
FieldMask that represents what fields were requested by the user.
Corresponds to the JSON property fieldMask
9207 9208 9209 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9207 def field_mask @field_mask end |
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results. Pass the content
of this string as the page_token attribute of the next request.
next_page_token is not returned for the last page.
Corresponds to the JSON property nextPageToken
9214 9215 9216 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9214 def next_page_token @next_page_token end |
#raw_event_conversion_dimension_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionDimensionHeader>
The headers of the raw event conversion dimensions in the results.
Corresponds to the JSON property rawEventConversionDimensionHeaders
9219 9220 9221 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9219 def raw_event_conversion_dimension_headers @raw_event_conversion_dimension_headers end |
#raw_event_conversion_metric_headers ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader>
The headers of the raw event conversion metrics in the results.
Corresponds to the JSON property rawEventConversionMetricHeaders
9224 9225 9226 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9224 def raw_event_conversion_metric_headers @raw_event_conversion_metric_headers end |
#results ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row>
The list of rows that matched the query.
Corresponds to the JSON property results
9229 9230 9231 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9229 def results @results end |
#summary_row ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
A returned row from the query.
Corresponds to the JSON property summaryRow
9234 9235 9236 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9234 def summary_row @summary_row end |
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Corresponds to the JSON property totalResultsCount
9239 9240 9241 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9239 def total_results_count @total_results_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9246 9247 9248 9249 9250 9251 9252 9253 9254 9255 9256 9257 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9246 def update!(**args) @conversion_custom_dimension_headers = args[:conversion_custom_dimension_headers] if args.key?(:conversion_custom_dimension_headers) @conversion_custom_metric_headers = args[:conversion_custom_metric_headers] if args.key?(:conversion_custom_metric_headers) @custom_column_headers = args[:custom_column_headers] if args.key?(:custom_column_headers) @field_mask = args[:field_mask] if args.key?(:field_mask) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @raw_event_conversion_dimension_headers = args[:raw_event_conversion_dimension_headers] if args.key?(:raw_event_conversion_dimension_headers) @raw_event_conversion_metric_headers = args[:raw_event_conversion_metric_headers] if args.key?(:raw_event_conversion_metric_headers) @results = args[:results] if args.key?(:results) @summary_row = args[:summary_row] if args.key?(:summary_row) @total_results_count = args[:total_results_count] if args.key?(:total_results_count) end |