Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Evidence details when the destination is returning an HTTP error code or isn't functional in all locations for commonly used devices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking.



9370
9371
9372
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deviceString

The type of device that failed to load the URL. Corresponds to the JSON property device

Returns:

  • (String)


9347
9348
9349
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9347

def device
  @device
end

#dns_error_typeString

The type of DNS error. Corresponds to the JSON property dnsErrorType

Returns:

  • (String)


9352
9353
9354
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9352

def dns_error_type
  @dns_error_type
end

#expanded_urlString

The full URL that didn't work. Corresponds to the JSON property expandedUrl

Returns:

  • (String)


9357
9358
9359
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9357

def expanded_url
  @expanded_url
end

#http_error_codeFixnum

The HTTP error code. Corresponds to the JSON property httpErrorCode

Returns:

  • (Fixnum)


9362
9363
9364
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9362

def http_error_code
  @http_error_code
end

#last_checked_date_timeString

The time the URL was last checked. The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property lastCheckedDateTime

Returns:

  • (String)


9368
9369
9370
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9368

def last_checked_date_time
  @last_checked_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9375
9376
9377
9378
9379
9380
9381
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9375

def update!(**args)
  @device = args[:device] if args.key?(:device)
  @dns_error_type = args[:dns_error_type] if args.key?(:dns_error_type)
  @expanded_url = args[:expanded_url] if args.key?(:expanded_url)
  @http_error_code = args[:http_error_code] if args.key?(:http_error_code)
  @last_checked_date_time = args[:last_checked_date_time] if args.key?(:last_checked_date_time)
end