Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A part of a field path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement

Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.



9576
9577
9578
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

The name of a field or a oneof Corresponds to the JSON property fieldName

Returns:

  • (String)


9569
9570
9571
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9569

def field_name
  @field_name
end

#indexFixnum

If field_name is a repeated field, this is the element that failed Corresponds to the JSON property index

Returns:

  • (Fixnum)


9574
9575
9576
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9574

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9581
9582
9583
9584
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9581

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @index = args[:index] if args.key?(:index)
end