Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsSearchAds360Error
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsSearchAds360Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Search Ads 360-specific error.
Instance Attribute Summary collapse
-
#details ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorDetails
Additional error details.
-
#error_code ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorCode
The error reason represented by type and enum.
-
#location ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorLocation
Describes the part of the request proto that caused the error.
-
#message ⇒ String
A human-readable description of the error.
-
#trigger ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonValue
A generic data container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Error
constructor
A new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Error
Returns a new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Error.
10994 10995 10996 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorDetails
Additional error details.
Corresponds to the JSON property details
10972 10973 10974 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10972 def details @details end |
#error_code ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorCode
The error reason represented by type and enum.
Corresponds to the JSON property errorCode
10977 10978 10979 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10977 def error_code @error_code end |
#location ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorLocation
Describes the part of the request proto that caused the error.
Corresponds to the JSON property location
10982 10983 10984 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10982 def location @location end |
#message ⇒ String
A human-readable description of the error.
Corresponds to the JSON property message
10987 10988 10989 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10987 def @message end |
#trigger ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonValue
A generic data container.
Corresponds to the JSON property trigger
10992 10993 10994 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10992 def trigger @trigger end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10999 11000 11001 11002 11003 11004 11005 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10999 def update!(**args) @details = args[:details] if args.key?(:details) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) @trigger = args[:trigger] if args.key?(:trigger) end |