Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Metadata of offline user data job.
Instance Attribute Summary collapse
-
#match_rate_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata.
11109 11110 11111 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 11109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#match_rate_range ⇒ String
Output only. Match rate of the Customer Match user list upload. Describes the
estimated match rate when the status of the job is "RUNNING" and final match
rate when the final match rate is available after the status of the job is "
SUCCESS/FAILED".
Corresponds to the JSON property matchRateRange
11107 11108 11109 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 11107 def match_rate_range @match_rate_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11114 11115 11116 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 11114 def update!(**args) @match_rate_range = args[:match_rate_range] if args.key?(:match_rate_range) end |