Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Segment only fields.
Instance Attribute Summary collapse
-
#ad_format_type ⇒ String
Ad Format type.
-
#ad_network_type ⇒ String
Ad network type.
-
#asset_interaction_target ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAssetInteractionTarget
An AssetInteractionTarget segment.
-
#conversion_action ⇒ String
Resource name of the conversion action.
-
#conversion_action_category ⇒ String
Conversion action category.
-
#conversion_action_name ⇒ String
Conversion action name.
-
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The conversion custom dimensions.
-
#date ⇒ String
Date to which metrics apply.
-
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
-
#device ⇒ String
Device to which metrics apply.
-
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
-
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
-
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
-
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
-
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
-
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
-
#keyword ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeyword
A Keyword criterion segment.
-
#month ⇒ String
Month as represented by the date of the first day of a month.
-
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
-
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
-
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
-
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
-
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
-
#product_brand ⇒ String
Brand of the product.
-
#product_channel ⇒ String
Channel of the product.
-
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
-
#product_condition ⇒ String
Condition of the product.
-
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the product.
-
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
-
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
-
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
-
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
-
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
-
#product_item_id ⇒ String
Item ID of the product.
-
#product_language ⇒ String
Resource name of the language constant for the language of the product.
-
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
-
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
-
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
-
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
-
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
-
#product_sold_brand ⇒ String
Brand of the product sold.
-
#product_sold_condition ⇒ String
Condition of the product sold.
-
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
-
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
-
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
-
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
-
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
-
#product_sold_item_id ⇒ String
Item ID of the product sold.
-
#product_sold_title ⇒ String
Title of the product sold.
-
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
-
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
-
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
-
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
-
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
-
#product_store_id ⇒ String
Store ID of the product.
-
#product_title ⇒ String
Title of the product.
-
#product_type_l1 ⇒ String
Type (level 1) of the product.
-
#product_type_l2 ⇒ String
Type (level 2) of the product.
-
#product_type_l3 ⇒ String
Type (level 3) of the product.
-
#product_type_l4 ⇒ String
Type (level 4) of the product.
-
#product_type_l5 ⇒ String
Type (level 5) of the product.
-
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter.
-
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The raw event conversion dimensions.
-
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers, speakers, or teams.
-
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel.
-
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
-
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context, for example, the brand of a car rental, a vacation home, or an event.
-
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
-
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
-
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
-
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center) that supplies inventory feed data for Vertical Ads.
-
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to categorize and segment data in the context of Vertical Ads.
-
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of Monday.
-
#year ⇒ Fixnum
Year, formatted as yyyy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSegments
constructor
A new instance of GoogleAdsSearchads360V0CommonSegments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSegments
Returns a new instance of GoogleAdsSearchads360V0CommonSegments.
2394 2395 2396 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_format_type ⇒ String
Ad Format type.
Corresponds to the JSON property adFormatType
2017 2018 2019 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2017 def ad_format_type @ad_format_type end |
#ad_network_type ⇒ String
Ad network type.
Corresponds to the JSON property adNetworkType
2022 2023 2024 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2022 def ad_network_type @ad_network_type end |
#asset_interaction_target ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAssetInteractionTarget
An AssetInteractionTarget segment.
Corresponds to the JSON property assetInteractionTarget
2027 2028 2029 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2027 def asset_interaction_target @asset_interaction_target end |
#conversion_action ⇒ String
Resource name of the conversion action.
Corresponds to the JSON property conversionAction
2032 2033 2034 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2032 def conversion_action @conversion_action end |
#conversion_action_category ⇒ String
Conversion action category.
Corresponds to the JSON property conversionActionCategory
2037 2038 2039 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2037 def conversion_action_category @conversion_action_category end |
#conversion_action_name ⇒ String
Conversion action name.
Corresponds to the JSON property conversionActionName
2042 2043 2044 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2042 def conversion_action_name @conversion_action_name end |
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The conversion custom dimensions.
Corresponds to the JSON property conversionCustomDimensions
2047 2048 2049 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2047 def conversion_custom_dimensions @conversion_custom_dimensions end |
#date ⇒ String
Date to which metrics apply. yyyy-MM-dd format, for example, 2018-04-17.
Corresponds to the JSON property date
2052 2053 2054 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2052 def date @date end |
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
Corresponds to the JSON property dayOfWeek
2057 2058 2059 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2057 def day_of_week @day_of_week end |
#device ⇒ String
Device to which metrics apply.
Corresponds to the JSON property device
2062 2063 2064 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2062 def device @device end |
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
Corresponds to the JSON property geoTargetCity
2067 2068 2069 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2067 def geo_target_city @geo_target_city end |
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
Corresponds to the JSON property geoTargetCountry
2072 2073 2074 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2072 def geo_target_country @geo_target_country end |
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
Corresponds to the JSON property geoTargetMetro
2077 2078 2079 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2077 def geo_target_metro @geo_target_metro end |
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
Corresponds to the JSON property geoTargetPostalCode
2082 2083 2084 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2082 def geo_target_postal_code @geo_target_postal_code end |
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
Corresponds to the JSON property geoTargetRegion
2087 2088 2089 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2087 def geo_target_region @geo_target_region end |
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
Corresponds to the JSON property hour
2092 2093 2094 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2092 def hour @hour end |
#keyword ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeyword
A Keyword criterion segment.
Corresponds to the JSON property keyword
2097 2098 2099 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2097 def keyword @keyword end |
#month ⇒ String
Month as represented by the date of the first day of a month. Formatted as
yyyy-MM-dd.
Corresponds to the JSON property month
2103 2104 2105 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2103 def month @month end |
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
Corresponds to the JSON property productBiddingCategoryLevel1
2108 2109 2110 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2108 def product_bidding_category_level1 @product_bidding_category_level1 end |
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
Corresponds to the JSON property productBiddingCategoryLevel2
2113 2114 2115 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2113 def product_bidding_category_level2 @product_bidding_category_level2 end |
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
Corresponds to the JSON property productBiddingCategoryLevel3
2118 2119 2120 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2118 def product_bidding_category_level3 @product_bidding_category_level3 end |
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
Corresponds to the JSON property productBiddingCategoryLevel4
2123 2124 2125 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2123 def product_bidding_category_level4 @product_bidding_category_level4 end |
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
Corresponds to the JSON property productBiddingCategoryLevel5
2128 2129 2130 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2128 def product_bidding_category_level5 @product_bidding_category_level5 end |
#product_brand ⇒ String
Brand of the product.
Corresponds to the JSON property productBrand
2133 2134 2135 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2133 def product_brand @product_brand end |
#product_channel ⇒ String
Channel of the product.
Corresponds to the JSON property productChannel
2138 2139 2140 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2138 def product_channel @product_channel end |
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
Corresponds to the JSON property productChannelExclusivity
2143 2144 2145 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2143 def product_channel_exclusivity @product_channel_exclusivity end |
#product_condition ⇒ String
Condition of the product.
Corresponds to the JSON property productCondition
2148 2149 2150 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2148 def product_condition @product_condition end |
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the
product.
Corresponds to the JSON property productCountry
2154 2155 2156 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2154 def product_country @product_country end |
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
Corresponds to the JSON property productCustomAttribute0
2159 2160 2161 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2159 def product_custom_attribute0 @product_custom_attribute0 end |
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
Corresponds to the JSON property productCustomAttribute1
2164 2165 2166 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2164 def product_custom_attribute1 @product_custom_attribute1 end |
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
Corresponds to the JSON property productCustomAttribute2
2169 2170 2171 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2169 def product_custom_attribute2 @product_custom_attribute2 end |
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
Corresponds to the JSON property productCustomAttribute3
2174 2175 2176 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2174 def product_custom_attribute3 @product_custom_attribute3 end |
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
Corresponds to the JSON property productCustomAttribute4
2179 2180 2181 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2179 def product_custom_attribute4 @product_custom_attribute4 end |
#product_item_id ⇒ String
Item ID of the product.
Corresponds to the JSON property productItemId
2184 2185 2186 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2184 def product_item_id @product_item_id end |
#product_language ⇒ String
Resource name of the language constant for the language of the product.
Corresponds to the JSON property productLanguage
2189 2190 2191 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2189 def product_language @product_language end |
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel1
2194 2195 2196 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2194 def product_sold_bidding_category_level1 @product_sold_bidding_category_level1 end |
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel2
2199 2200 2201 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2199 def product_sold_bidding_category_level2 @product_sold_bidding_category_level2 end |
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel3
2204 2205 2206 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2204 def product_sold_bidding_category_level3 @product_sold_bidding_category_level3 end |
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel4
2209 2210 2211 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2209 def product_sold_bidding_category_level4 @product_sold_bidding_category_level4 end |
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel5
2214 2215 2216 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2214 def product_sold_bidding_category_level5 @product_sold_bidding_category_level5 end |
#product_sold_brand ⇒ String
Brand of the product sold.
Corresponds to the JSON property productSoldBrand
2219 2220 2221 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2219 def product_sold_brand @product_sold_brand end |
#product_sold_condition ⇒ String
Condition of the product sold.
Corresponds to the JSON property productSoldCondition
2224 2225 2226 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2224 def product_sold_condition @product_sold_condition end |
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute0
2229 2230 2231 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2229 def product_sold_custom_attribute0 @product_sold_custom_attribute0 end |
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute1
2234 2235 2236 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2234 def product_sold_custom_attribute1 @product_sold_custom_attribute1 end |
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute2
2239 2240 2241 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2239 def product_sold_custom_attribute2 @product_sold_custom_attribute2 end |
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute3
2244 2245 2246 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2244 def product_sold_custom_attribute3 @product_sold_custom_attribute3 end |
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute4
2249 2250 2251 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2249 def product_sold_custom_attribute4 @product_sold_custom_attribute4 end |
#product_sold_item_id ⇒ String
Item ID of the product sold.
Corresponds to the JSON property productSoldItemId
2254 2255 2256 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2254 def product_sold_item_id @product_sold_item_id end |
#product_sold_title ⇒ String
Title of the product sold.
Corresponds to the JSON property productSoldTitle
2259 2260 2261 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2259 def product_sold_title @product_sold_title end |
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
Corresponds to the JSON property productSoldTypeL1
2264 2265 2266 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2264 def product_sold_type_l1 @product_sold_type_l1 end |
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
Corresponds to the JSON property productSoldTypeL2
2269 2270 2271 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2269 def product_sold_type_l2 @product_sold_type_l2 end |
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
Corresponds to the JSON property productSoldTypeL3
2274 2275 2276 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2274 def product_sold_type_l3 @product_sold_type_l3 end |
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
Corresponds to the JSON property productSoldTypeL4
2279 2280 2281 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2279 def product_sold_type_l4 @product_sold_type_l4 end |
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
Corresponds to the JSON property productSoldTypeL5
2284 2285 2286 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2284 def product_sold_type_l5 @product_sold_type_l5 end |
#product_store_id ⇒ String
Store ID of the product.
Corresponds to the JSON property productStoreId
2289 2290 2291 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2289 def product_store_id @product_store_id end |
#product_title ⇒ String
Title of the product.
Corresponds to the JSON property productTitle
2294 2295 2296 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2294 def product_title @product_title end |
#product_type_l1 ⇒ String
Type (level 1) of the product.
Corresponds to the JSON property productTypeL1
2299 2300 2301 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2299 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Type (level 2) of the product.
Corresponds to the JSON property productTypeL2
2304 2305 2306 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2304 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Type (level 3) of the product.
Corresponds to the JSON property productTypeL3
2309 2310 2311 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2309 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Type (level 4) of the product.
Corresponds to the JSON property productTypeL4
2314 2315 2316 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2314 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Type (level 5) of the product.
Corresponds to the JSON property productTypeL5
2319 2320 2321 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2319 def product_type_l5 @product_type_l5 end |
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter. Uses the
calendar year for quarters, for example, the second quarter of 2018 starts on
2018-04-01. Formatted as yyyy-MM-dd.
Corresponds to the JSON property quarter
2326 2327 2328 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2326 def quarter @quarter end |
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The raw event conversion dimensions.
Corresponds to the JSON property rawEventConversionDimensions
2331 2332 2333 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2331 def raw_event_conversion_dimensions @raw_event_conversion_dimensions end |
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers,
speakers, or teams.
Corresponds to the JSON property verticalAdsEventParticipantDisplayNames
2337 2338 2339 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2337 def vertical_ads_event_participant_display_names @vertical_ads_event_participant_display_names end |
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel. Generally in the range of 1 to 5 stars, but fully
customizable in the hotel feed.
Corresponds to the JSON property verticalAdsHotelClass
2343 2344 2345 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2343 def vertical_ads_hotel_class @vertical_ads_hotel_class end |
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
Corresponds to the JSON property verticalAdsListing
2348 2349 2350 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2348 def vertical_ads_listing @vertical_ads_listing end |
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context,
for example, the brand of a car rental, a vacation home, or an event.
Corresponds to the JSON property verticalAdsListingBrand
2354 2355 2356 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2354 def vertical_ads_listing_brand @vertical_ads_listing_brand end |
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCity
2359 2360 2361 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2359 def vertical_ads_listing_city @vertical_ads_listing_city end |
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCountry
2364 2365 2366 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2364 def vertical_ads_listing_country @vertical_ads_listing_country end |
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingRegion
2369 2370 2371 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2369 def vertical_ads_listing_region @vertical_ads_listing_region end |
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center)
that supplies inventory feed data for Vertical Ads.
Corresponds to the JSON property verticalAdsPartnerAccount
2375 2376 2377 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2375 def vertical_ads_partner_account @vertical_ads_partner_account end |
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to
categorize and segment data in the context of Vertical Ads.
Corresponds to the JSON property verticalAdsVertical
2381 2382 2383 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2381 def vertical_ads_vertical @vertical_ads_vertical end |
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of
Monday. Formatted as yyyy-MM-dd.
Corresponds to the JSON property week
2387 2388 2389 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2387 def week @week end |
#year ⇒ Fixnum
Year, formatted as yyyy.
Corresponds to the JSON property year
2392 2393 2394 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2392 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2399 def update!(**args) @ad_format_type = args[:ad_format_type] if args.key?(:ad_format_type) @ad_network_type = args[:ad_network_type] if args.key?(:ad_network_type) @asset_interaction_target = args[:asset_interaction_target] if args.key?(:asset_interaction_target) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_action_category = args[:conversion_action_category] if args.key?(:conversion_action_category) @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name) @conversion_custom_dimensions = args[:conversion_custom_dimensions] if args.key?(:conversion_custom_dimensions) @date = args[:date] if args.key?(:date) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @device = args[:device] if args.key?(:device) @geo_target_city = args[:geo_target_city] if args.key?(:geo_target_city) @geo_target_country = args[:geo_target_country] if args.key?(:geo_target_country) @geo_target_metro = args[:geo_target_metro] if args.key?(:geo_target_metro) @geo_target_postal_code = args[:geo_target_postal_code] if args.key?(:geo_target_postal_code) @geo_target_region = args[:geo_target_region] if args.key?(:geo_target_region) @hour = args[:hour] if args.key?(:hour) @keyword = args[:keyword] if args.key?(:keyword) @month = args[:month] if args.key?(:month) @product_bidding_category_level1 = args[:product_bidding_category_level1] if args.key?(:product_bidding_category_level1) @product_bidding_category_level2 = args[:product_bidding_category_level2] if args.key?(:product_bidding_category_level2) @product_bidding_category_level3 = args[:product_bidding_category_level3] if args.key?(:product_bidding_category_level3) @product_bidding_category_level4 = args[:product_bidding_category_level4] if args.key?(:product_bidding_category_level4) @product_bidding_category_level5 = args[:product_bidding_category_level5] if args.key?(:product_bidding_category_level5) @product_brand = args[:product_brand] if args.key?(:product_brand) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity) @product_condition = args[:product_condition] if args.key?(:product_condition) @product_country = args[:product_country] if args.key?(:product_country) @product_custom_attribute0 = args[:product_custom_attribute0] if args.key?(:product_custom_attribute0) @product_custom_attribute1 = args[:product_custom_attribute1] if args.key?(:product_custom_attribute1) @product_custom_attribute2 = args[:product_custom_attribute2] if args.key?(:product_custom_attribute2) @product_custom_attribute3 = args[:product_custom_attribute3] if args.key?(:product_custom_attribute3) @product_custom_attribute4 = args[:product_custom_attribute4] if args.key?(:product_custom_attribute4) @product_item_id = args[:product_item_id] if args.key?(:product_item_id) @product_language = args[:product_language] if args.key?(:product_language) @product_sold_bidding_category_level1 = args[:product_sold_bidding_category_level1] if args.key?(:product_sold_bidding_category_level1) @product_sold_bidding_category_level2 = args[:product_sold_bidding_category_level2] if args.key?(:product_sold_bidding_category_level2) @product_sold_bidding_category_level3 = args[:product_sold_bidding_category_level3] if args.key?(:product_sold_bidding_category_level3) @product_sold_bidding_category_level4 = args[:product_sold_bidding_category_level4] if args.key?(:product_sold_bidding_category_level4) @product_sold_bidding_category_level5 = args[:product_sold_bidding_category_level5] if args.key?(:product_sold_bidding_category_level5) @product_sold_brand = args[:product_sold_brand] if args.key?(:product_sold_brand) @product_sold_condition = args[:product_sold_condition] if args.key?(:product_sold_condition) @product_sold_custom_attribute0 = args[:product_sold_custom_attribute0] if args.key?(:product_sold_custom_attribute0) @product_sold_custom_attribute1 = args[:product_sold_custom_attribute1] if args.key?(:product_sold_custom_attribute1) @product_sold_custom_attribute2 = args[:product_sold_custom_attribute2] if args.key?(:product_sold_custom_attribute2) @product_sold_custom_attribute3 = args[:product_sold_custom_attribute3] if args.key?(:product_sold_custom_attribute3) @product_sold_custom_attribute4 = args[:product_sold_custom_attribute4] if args.key?(:product_sold_custom_attribute4) @product_sold_item_id = args[:product_sold_item_id] if args.key?(:product_sold_item_id) @product_sold_title = args[:product_sold_title] if args.key?(:product_sold_title) @product_sold_type_l1 = args[:product_sold_type_l1] if args.key?(:product_sold_type_l1) @product_sold_type_l2 = args[:product_sold_type_l2] if args.key?(:product_sold_type_l2) @product_sold_type_l3 = args[:product_sold_type_l3] if args.key?(:product_sold_type_l3) @product_sold_type_l4 = args[:product_sold_type_l4] if args.key?(:product_sold_type_l4) @product_sold_type_l5 = args[:product_sold_type_l5] if args.key?(:product_sold_type_l5) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @product_title = args[:product_title] if args.key?(:product_title) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @quarter = args[:quarter] if args.key?(:quarter) @raw_event_conversion_dimensions = args[:raw_event_conversion_dimensions] if args.key?(:raw_event_conversion_dimensions) @vertical_ads_event_participant_display_names = args[:vertical_ads_event_participant_display_names] if args.key?(:vertical_ads_event_participant_display_names) @vertical_ads_hotel_class = args[:vertical_ads_hotel_class] if args.key?(:vertical_ads_hotel_class) @vertical_ads_listing = args[:vertical_ads_listing] if args.key?(:vertical_ads_listing) @vertical_ads_listing_brand = args[:vertical_ads_listing_brand] if args.key?(:vertical_ads_listing_brand) @vertical_ads_listing_city = args[:vertical_ads_listing_city] if args.key?(:vertical_ads_listing_city) @vertical_ads_listing_country = args[:vertical_ads_listing_country] if args.key?(:vertical_ads_listing_country) @vertical_ads_listing_region = args[:vertical_ads_listing_region] if args.key?(:vertical_ads_listing_region) @vertical_ads_partner_account = args[:vertical_ads_partner_account] if args.key?(:vertical_ads_partner_account) @vertical_ads_vertical = args[:vertical_ads_vertical] if args.key?(:vertical_ads_vertical) @week = args[:week] if args.key?(:week) @year = args[:year] if args.key?(:year) end |