Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Segment only fields.
Instance Attribute Summary collapse
-
#ad_format_type ⇒ String
Ad Format type.
-
#ad_network_type ⇒ String
Ad network type.
-
#asset_interaction_target ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAssetInteractionTarget
An AssetInteractionTarget segment.
-
#conversion_action ⇒ String
Resource name of the conversion action.
-
#conversion_action_category ⇒ String
Conversion action category.
-
#conversion_action_name ⇒ String
Conversion action name.
-
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The conversion custom dimensions.
-
#date ⇒ String
Date to which metrics apply.
-
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
-
#device ⇒ String
Device to which metrics apply.
-
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
-
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
-
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
-
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
-
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
-
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
-
#keyword ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeyword
A Keyword criterion segment.
-
#month ⇒ String
Month as represented by the date of the first day of a month.
-
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
-
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
-
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
-
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
-
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
-
#product_brand ⇒ String
Brand of the product.
-
#product_channel ⇒ String
Channel of the product.
-
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
-
#product_condition ⇒ String
Condition of the product.
-
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the product.
-
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
-
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
-
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
-
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
-
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
-
#product_item_id ⇒ String
Item ID of the product.
-
#product_language ⇒ String
Resource name of the language constant for the language of the product.
-
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
-
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
-
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
-
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
-
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
-
#product_sold_brand ⇒ String
Brand of the product sold.
-
#product_sold_condition ⇒ String
Condition of the product sold.
-
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
-
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
-
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
-
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
-
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
-
#product_sold_item_id ⇒ String
Item ID of the product sold.
-
#product_sold_title ⇒ String
Title of the product sold.
-
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
-
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
-
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
-
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
-
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
-
#product_store_id ⇒ String
Store ID of the product.
-
#product_title ⇒ String
Title of the product.
-
#product_type_l1 ⇒ String
Type (level 1) of the product.
-
#product_type_l2 ⇒ String
Type (level 2) of the product.
-
#product_type_l3 ⇒ String
Type (level 3) of the product.
-
#product_type_l4 ⇒ String
Type (level 4) of the product.
-
#product_type_l5 ⇒ String
Type (level 5) of the product.
-
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter.
-
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The raw event conversion dimensions.
-
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers, speakers, or teams.
-
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel.
-
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
-
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context, for example, the brand of a car rental, a vacation home, or an event.
-
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
-
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
-
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
-
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center) that supplies inventory feed data for Vertical Ads.
-
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to categorize and segment data in the context of Vertical Ads.
-
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of Monday.
-
#year ⇒ Fixnum
Year, formatted as yyyy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSegments
constructor
A new instance of GoogleAdsSearchads360V0CommonSegments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSegments
Returns a new instance of GoogleAdsSearchads360V0CommonSegments.
2385 2386 2387 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_format_type ⇒ String
Ad Format type.
Corresponds to the JSON property adFormatType
2008 2009 2010 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2008 def ad_format_type @ad_format_type end |
#ad_network_type ⇒ String
Ad network type.
Corresponds to the JSON property adNetworkType
2013 2014 2015 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2013 def ad_network_type @ad_network_type end |
#asset_interaction_target ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAssetInteractionTarget
An AssetInteractionTarget segment.
Corresponds to the JSON property assetInteractionTarget
2018 2019 2020 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2018 def asset_interaction_target @asset_interaction_target end |
#conversion_action ⇒ String
Resource name of the conversion action.
Corresponds to the JSON property conversionAction
2023 2024 2025 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2023 def conversion_action @conversion_action end |
#conversion_action_category ⇒ String
Conversion action category.
Corresponds to the JSON property conversionActionCategory
2028 2029 2030 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2028 def conversion_action_category @conversion_action_category end |
#conversion_action_name ⇒ String
Conversion action name.
Corresponds to the JSON property conversionActionName
2033 2034 2035 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2033 def conversion_action_name @conversion_action_name end |
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The conversion custom dimensions.
Corresponds to the JSON property conversionCustomDimensions
2038 2039 2040 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2038 def conversion_custom_dimensions @conversion_custom_dimensions end |
#date ⇒ String
Date to which metrics apply. yyyy-MM-dd format, for example, 2018-04-17.
Corresponds to the JSON property date
2043 2044 2045 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2043 def date @date end |
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
Corresponds to the JSON property dayOfWeek
2048 2049 2050 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2048 def day_of_week @day_of_week end |
#device ⇒ String
Device to which metrics apply.
Corresponds to the JSON property device
2053 2054 2055 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2053 def device @device end |
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
Corresponds to the JSON property geoTargetCity
2058 2059 2060 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2058 def geo_target_city @geo_target_city end |
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
Corresponds to the JSON property geoTargetCountry
2063 2064 2065 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2063 def geo_target_country @geo_target_country end |
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
Corresponds to the JSON property geoTargetMetro
2068 2069 2070 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2068 def geo_target_metro @geo_target_metro end |
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
Corresponds to the JSON property geoTargetPostalCode
2073 2074 2075 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2073 def geo_target_postal_code @geo_target_postal_code end |
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
Corresponds to the JSON property geoTargetRegion
2078 2079 2080 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2078 def geo_target_region @geo_target_region end |
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
Corresponds to the JSON property hour
2083 2084 2085 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2083 def hour @hour end |
#keyword ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeyword
A Keyword criterion segment.
Corresponds to the JSON property keyword
2088 2089 2090 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2088 def keyword @keyword end |
#month ⇒ String
Month as represented by the date of the first day of a month. Formatted as
yyyy-MM-dd.
Corresponds to the JSON property month
2094 2095 2096 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2094 def month @month end |
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
Corresponds to the JSON property productBiddingCategoryLevel1
2099 2100 2101 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2099 def product_bidding_category_level1 @product_bidding_category_level1 end |
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
Corresponds to the JSON property productBiddingCategoryLevel2
2104 2105 2106 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2104 def product_bidding_category_level2 @product_bidding_category_level2 end |
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
Corresponds to the JSON property productBiddingCategoryLevel3
2109 2110 2111 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2109 def product_bidding_category_level3 @product_bidding_category_level3 end |
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
Corresponds to the JSON property productBiddingCategoryLevel4
2114 2115 2116 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2114 def product_bidding_category_level4 @product_bidding_category_level4 end |
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
Corresponds to the JSON property productBiddingCategoryLevel5
2119 2120 2121 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2119 def product_bidding_category_level5 @product_bidding_category_level5 end |
#product_brand ⇒ String
Brand of the product.
Corresponds to the JSON property productBrand
2124 2125 2126 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2124 def product_brand @product_brand end |
#product_channel ⇒ String
Channel of the product.
Corresponds to the JSON property productChannel
2129 2130 2131 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2129 def product_channel @product_channel end |
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
Corresponds to the JSON property productChannelExclusivity
2134 2135 2136 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2134 def product_channel_exclusivity @product_channel_exclusivity end |
#product_condition ⇒ String
Condition of the product.
Corresponds to the JSON property productCondition
2139 2140 2141 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2139 def product_condition @product_condition end |
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the
product.
Corresponds to the JSON property productCountry
2145 2146 2147 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2145 def product_country @product_country end |
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
Corresponds to the JSON property productCustomAttribute0
2150 2151 2152 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2150 def product_custom_attribute0 @product_custom_attribute0 end |
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
Corresponds to the JSON property productCustomAttribute1
2155 2156 2157 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2155 def product_custom_attribute1 @product_custom_attribute1 end |
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
Corresponds to the JSON property productCustomAttribute2
2160 2161 2162 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2160 def product_custom_attribute2 @product_custom_attribute2 end |
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
Corresponds to the JSON property productCustomAttribute3
2165 2166 2167 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2165 def product_custom_attribute3 @product_custom_attribute3 end |
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
Corresponds to the JSON property productCustomAttribute4
2170 2171 2172 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2170 def product_custom_attribute4 @product_custom_attribute4 end |
#product_item_id ⇒ String
Item ID of the product.
Corresponds to the JSON property productItemId
2175 2176 2177 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2175 def product_item_id @product_item_id end |
#product_language ⇒ String
Resource name of the language constant for the language of the product.
Corresponds to the JSON property productLanguage
2180 2181 2182 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2180 def product_language @product_language end |
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel1
2185 2186 2187 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2185 def product_sold_bidding_category_level1 @product_sold_bidding_category_level1 end |
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel2
2190 2191 2192 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2190 def product_sold_bidding_category_level2 @product_sold_bidding_category_level2 end |
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel3
2195 2196 2197 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2195 def product_sold_bidding_category_level3 @product_sold_bidding_category_level3 end |
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel4
2200 2201 2202 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2200 def product_sold_bidding_category_level4 @product_sold_bidding_category_level4 end |
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel5
2205 2206 2207 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2205 def product_sold_bidding_category_level5 @product_sold_bidding_category_level5 end |
#product_sold_brand ⇒ String
Brand of the product sold.
Corresponds to the JSON property productSoldBrand
2210 2211 2212 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2210 def product_sold_brand @product_sold_brand end |
#product_sold_condition ⇒ String
Condition of the product sold.
Corresponds to the JSON property productSoldCondition
2215 2216 2217 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2215 def product_sold_condition @product_sold_condition end |
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute0
2220 2221 2222 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2220 def product_sold_custom_attribute0 @product_sold_custom_attribute0 end |
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute1
2225 2226 2227 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2225 def product_sold_custom_attribute1 @product_sold_custom_attribute1 end |
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute2
2230 2231 2232 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2230 def product_sold_custom_attribute2 @product_sold_custom_attribute2 end |
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute3
2235 2236 2237 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2235 def product_sold_custom_attribute3 @product_sold_custom_attribute3 end |
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute4
2240 2241 2242 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2240 def product_sold_custom_attribute4 @product_sold_custom_attribute4 end |
#product_sold_item_id ⇒ String
Item ID of the product sold.
Corresponds to the JSON property productSoldItemId
2245 2246 2247 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2245 def product_sold_item_id @product_sold_item_id end |
#product_sold_title ⇒ String
Title of the product sold.
Corresponds to the JSON property productSoldTitle
2250 2251 2252 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2250 def product_sold_title @product_sold_title end |
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
Corresponds to the JSON property productSoldTypeL1
2255 2256 2257 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2255 def product_sold_type_l1 @product_sold_type_l1 end |
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
Corresponds to the JSON property productSoldTypeL2
2260 2261 2262 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2260 def product_sold_type_l2 @product_sold_type_l2 end |
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
Corresponds to the JSON property productSoldTypeL3
2265 2266 2267 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2265 def product_sold_type_l3 @product_sold_type_l3 end |
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
Corresponds to the JSON property productSoldTypeL4
2270 2271 2272 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2270 def product_sold_type_l4 @product_sold_type_l4 end |
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
Corresponds to the JSON property productSoldTypeL5
2275 2276 2277 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2275 def product_sold_type_l5 @product_sold_type_l5 end |
#product_store_id ⇒ String
Store ID of the product.
Corresponds to the JSON property productStoreId
2280 2281 2282 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2280 def product_store_id @product_store_id end |
#product_title ⇒ String
Title of the product.
Corresponds to the JSON property productTitle
2285 2286 2287 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2285 def product_title @product_title end |
#product_type_l1 ⇒ String
Type (level 1) of the product.
Corresponds to the JSON property productTypeL1
2290 2291 2292 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2290 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Type (level 2) of the product.
Corresponds to the JSON property productTypeL2
2295 2296 2297 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2295 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Type (level 3) of the product.
Corresponds to the JSON property productTypeL3
2300 2301 2302 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2300 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Type (level 4) of the product.
Corresponds to the JSON property productTypeL4
2305 2306 2307 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2305 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Type (level 5) of the product.
Corresponds to the JSON property productTypeL5
2310 2311 2312 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2310 def product_type_l5 @product_type_l5 end |
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter. Uses the
calendar year for quarters, for example, the second quarter of 2018 starts on
2018-04-01. Formatted as yyyy-MM-dd.
Corresponds to the JSON property quarter
2317 2318 2319 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2317 def quarter @quarter end |
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The raw event conversion dimensions.
Corresponds to the JSON property rawEventConversionDimensions
2322 2323 2324 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2322 def raw_event_conversion_dimensions @raw_event_conversion_dimensions end |
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers,
speakers, or teams.
Corresponds to the JSON property verticalAdsEventParticipantDisplayNames
2328 2329 2330 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2328 def vertical_ads_event_participant_display_names @vertical_ads_event_participant_display_names end |
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel. Generally in the range of 1 to 5 stars, but fully
customizable in the hotel feed.
Corresponds to the JSON property verticalAdsHotelClass
2334 2335 2336 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2334 def vertical_ads_hotel_class @vertical_ads_hotel_class end |
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
Corresponds to the JSON property verticalAdsListing
2339 2340 2341 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2339 def vertical_ads_listing @vertical_ads_listing end |
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context,
for example, the brand of a car rental, a vacation home, or an event.
Corresponds to the JSON property verticalAdsListingBrand
2345 2346 2347 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2345 def vertical_ads_listing_brand @vertical_ads_listing_brand end |
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCity
2350 2351 2352 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2350 def vertical_ads_listing_city @vertical_ads_listing_city end |
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCountry
2355 2356 2357 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2355 def vertical_ads_listing_country @vertical_ads_listing_country end |
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingRegion
2360 2361 2362 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2360 def vertical_ads_listing_region @vertical_ads_listing_region end |
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center)
that supplies inventory feed data for Vertical Ads.
Corresponds to the JSON property verticalAdsPartnerAccount
2366 2367 2368 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2366 def vertical_ads_partner_account @vertical_ads_partner_account end |
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to
categorize and segment data in the context of Vertical Ads.
Corresponds to the JSON property verticalAdsVertical
2372 2373 2374 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2372 def vertical_ads_vertical @vertical_ads_vertical end |
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of
Monday. Formatted as yyyy-MM-dd.
Corresponds to the JSON property week
2378 2379 2380 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2378 def week @week end |
#year ⇒ Fixnum
Year, formatted as yyyy.
Corresponds to the JSON property year
2383 2384 2385 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2383 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2390 def update!(**args) @ad_format_type = args[:ad_format_type] if args.key?(:ad_format_type) @ad_network_type = args[:ad_network_type] if args.key?(:ad_network_type) @asset_interaction_target = args[:asset_interaction_target] if args.key?(:asset_interaction_target) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_action_category = args[:conversion_action_category] if args.key?(:conversion_action_category) @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name) @conversion_custom_dimensions = args[:conversion_custom_dimensions] if args.key?(:conversion_custom_dimensions) @date = args[:date] if args.key?(:date) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @device = args[:device] if args.key?(:device) @geo_target_city = args[:geo_target_city] if args.key?(:geo_target_city) @geo_target_country = args[:geo_target_country] if args.key?(:geo_target_country) @geo_target_metro = args[:geo_target_metro] if args.key?(:geo_target_metro) @geo_target_postal_code = args[:geo_target_postal_code] if args.key?(:geo_target_postal_code) @geo_target_region = args[:geo_target_region] if args.key?(:geo_target_region) @hour = args[:hour] if args.key?(:hour) @keyword = args[:keyword] if args.key?(:keyword) @month = args[:month] if args.key?(:month) @product_bidding_category_level1 = args[:product_bidding_category_level1] if args.key?(:product_bidding_category_level1) @product_bidding_category_level2 = args[:product_bidding_category_level2] if args.key?(:product_bidding_category_level2) @product_bidding_category_level3 = args[:product_bidding_category_level3] if args.key?(:product_bidding_category_level3) @product_bidding_category_level4 = args[:product_bidding_category_level4] if args.key?(:product_bidding_category_level4) @product_bidding_category_level5 = args[:product_bidding_category_level5] if args.key?(:product_bidding_category_level5) @product_brand = args[:product_brand] if args.key?(:product_brand) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity) @product_condition = args[:product_condition] if args.key?(:product_condition) @product_country = args[:product_country] if args.key?(:product_country) @product_custom_attribute0 = args[:product_custom_attribute0] if args.key?(:product_custom_attribute0) @product_custom_attribute1 = args[:product_custom_attribute1] if args.key?(:product_custom_attribute1) @product_custom_attribute2 = args[:product_custom_attribute2] if args.key?(:product_custom_attribute2) @product_custom_attribute3 = args[:product_custom_attribute3] if args.key?(:product_custom_attribute3) @product_custom_attribute4 = args[:product_custom_attribute4] if args.key?(:product_custom_attribute4) @product_item_id = args[:product_item_id] if args.key?(:product_item_id) @product_language = args[:product_language] if args.key?(:product_language) @product_sold_bidding_category_level1 = args[:product_sold_bidding_category_level1] if args.key?(:product_sold_bidding_category_level1) @product_sold_bidding_category_level2 = args[:product_sold_bidding_category_level2] if args.key?(:product_sold_bidding_category_level2) @product_sold_bidding_category_level3 = args[:product_sold_bidding_category_level3] if args.key?(:product_sold_bidding_category_level3) @product_sold_bidding_category_level4 = args[:product_sold_bidding_category_level4] if args.key?(:product_sold_bidding_category_level4) @product_sold_bidding_category_level5 = args[:product_sold_bidding_category_level5] if args.key?(:product_sold_bidding_category_level5) @product_sold_brand = args[:product_sold_brand] if args.key?(:product_sold_brand) @product_sold_condition = args[:product_sold_condition] if args.key?(:product_sold_condition) @product_sold_custom_attribute0 = args[:product_sold_custom_attribute0] if args.key?(:product_sold_custom_attribute0) @product_sold_custom_attribute1 = args[:product_sold_custom_attribute1] if args.key?(:product_sold_custom_attribute1) @product_sold_custom_attribute2 = args[:product_sold_custom_attribute2] if args.key?(:product_sold_custom_attribute2) @product_sold_custom_attribute3 = args[:product_sold_custom_attribute3] if args.key?(:product_sold_custom_attribute3) @product_sold_custom_attribute4 = args[:product_sold_custom_attribute4] if args.key?(:product_sold_custom_attribute4) @product_sold_item_id = args[:product_sold_item_id] if args.key?(:product_sold_item_id) @product_sold_title = args[:product_sold_title] if args.key?(:product_sold_title) @product_sold_type_l1 = args[:product_sold_type_l1] if args.key?(:product_sold_type_l1) @product_sold_type_l2 = args[:product_sold_type_l2] if args.key?(:product_sold_type_l2) @product_sold_type_l3 = args[:product_sold_type_l3] if args.key?(:product_sold_type_l3) @product_sold_type_l4 = args[:product_sold_type_l4] if args.key?(:product_sold_type_l4) @product_sold_type_l5 = args[:product_sold_type_l5] if args.key?(:product_sold_type_l5) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @product_title = args[:product_title] if args.key?(:product_title) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @quarter = args[:quarter] if args.key?(:quarter) @raw_event_conversion_dimensions = args[:raw_event_conversion_dimensions] if args.key?(:raw_event_conversion_dimensions) @vertical_ads_event_participant_display_names = args[:vertical_ads_event_participant_display_names] if args.key?(:vertical_ads_event_participant_display_names) @vertical_ads_hotel_class = args[:vertical_ads_hotel_class] if args.key?(:vertical_ads_hotel_class) @vertical_ads_listing = args[:vertical_ads_listing] if args.key?(:vertical_ads_listing) @vertical_ads_listing_brand = args[:vertical_ads_listing_brand] if args.key?(:vertical_ads_listing_brand) @vertical_ads_listing_city = args[:vertical_ads_listing_city] if args.key?(:vertical_ads_listing_city) @vertical_ads_listing_country = args[:vertical_ads_listing_country] if args.key?(:vertical_ads_listing_country) @vertical_ads_listing_region = args[:vertical_ads_listing_region] if args.key?(:vertical_ads_listing_region) @vertical_ads_partner_account = args[:vertical_ads_partner_account] if args.key?(:vertical_ads_partner_account) @vertical_ads_vertical = args[:vertical_ads_vertical] if args.key?(:vertical_ads_vertical) @week = args[:week] if args.key?(:week) @year = args[:year] if args.key?(:year) end |