Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Represents an attestation about synthetic content from a single source.
Instance Attribute Summary collapse
-
#source ⇒ String
The source of the synthetic content attestation.
-
#status ⇒ String
Indicates whether the content is considered synthetic by this source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSyntheticContentAttestation
constructor
A new instance of GoogleAdsSearchads360V0CommonSyntheticContentAttestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSyntheticContentAttestation
Returns a new instance of GoogleAdsSearchads360V0CommonSyntheticContentAttestation.
2491 2492 2493 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source ⇒ String
The source of the synthetic content attestation.
Corresponds to the JSON property source
2484 2485 2486 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2484 def source @source end |
#status ⇒ String
Indicates whether the content is considered synthetic by this source.
Corresponds to the JSON property status
2489 2490 2491 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2489 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2496 2497 2498 2499 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2496 def update!(**args) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) end |