Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Container for synthetic content attestations from different sources, such as the advertiser and Google systems.
Instance Attribute Summary collapse
-
#advertiser_attestation ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
-
#system_attestation ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSyntheticContentInfo
constructor
A new instance of GoogleAdsSearchads360V0CommonSyntheticContentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonSyntheticContentInfo
Returns a new instance of GoogleAdsSearchads360V0CommonSyntheticContentInfo.
2517 2518 2519 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_attestation ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Corresponds to the JSON property advertiserAttestation
2510 2511 2512 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2510 def advertiser_attestation @advertiser_attestation end |
#system_attestation ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Corresponds to the JSON property systemAttestation
2515 2516 2517 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2515 def system_attestation @system_attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2522 2523 2524 2525 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2522 def update!(**args) @advertiser_attestation = args[:advertiser_attestation] if args.key?(:advertiser_attestation) @system_attestation = args[:system_attestation] if args.key?(:system_attestation) end |