Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_cpa_micros ⇒ Fixnum
Average CPA target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetCpa
constructor
A new instance of GoogleAdsSearchads360V0CommonTargetCpa.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetCpa
Returns a new instance of GoogleAdsSearchads360V0CommonTargetCpa.
2493 2494 2495 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidCeilingMicros
2478 2479 2480 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2478 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidFloorMicros
2485 2486 2487 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2485 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_cpa_micros ⇒ Fixnum
Average CPA target. This target should be greater than or equal to minimum
billable unit based on the currency for the account.
Corresponds to the JSON property targetCpaMicros
2491 2492 2493 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2491 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2498 2499 2500 2501 2502 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2498 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |