Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetOutrankShare
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetOutrankShare
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bidding strategy that sets bids based on the target fraction of auctions where the advertiser should outrank a specific competitor. This strategy is deprecated.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetOutrankShare
constructor
A new instance of GoogleAdsSearchads360V0CommonTargetOutrankShare.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetOutrankShare
Returns a new instance of GoogleAdsSearchads360V0CommonTargetOutrankShare.
2566 2567 2568 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy.
Corresponds to the JSON property cpcBidCeilingMicros
2564 2565 2566 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2564 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2571 2572 2573 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2571 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) end |