Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_roas ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetRoas
constructor
A new instance of GoogleAdsSearchads360V0CommonTargetRoas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonTargetRoas
Returns a new instance of GoogleAdsSearchads360V0CommonTargetRoas.
2692 2693 2694 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidCeilingMicros
2677 2678 2679 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2677 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidFloorMicros
2684 2685 2686 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2684 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_roas ⇒ Float
Required. The chosen revenue (based on conversion data) per unit of spend.
Value must be between 0.01 and 1000.0, inclusive.
Corresponds to the JSON property targetRoas
2690 2691 2692 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2690 def target_roas @target_roas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2697 2698 2699 2700 2701 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2697 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_roas = args[:target_roas] if args.key?(:target_roas) end |