Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCallAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCallAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A unified call asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to.
-
#call_conversion_reporting_state ⇒ String
Output only.
-
#call_only ⇒ Boolean
(also: #call_only?)
Whether the call only shows the phone number without a link to the website.
-
#call_tracking_enabled ⇒ Boolean
(also: #call_tracking_enabled?)
Whether the call should be enabled on call tracking.
-
#country_code ⇒ String
Two-letter country code of the phone number.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#phone_number ⇒ String
The advertiser's raw phone number.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
-
#use_searcher_time_zone ⇒ Boolean
(also: #use_searcher_time_zone?)
Whether to show the call extension in search user's time zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedCallAsset
constructor
A new instance of GoogleAdsSearchads360V0CommonUnifiedCallAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedCallAsset
Returns a new instance of GoogleAdsSearchads360V0CommonUnifiedCallAsset.
2812 2813 2814 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
2753 2754 2755 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2753 def ad_schedule_targets @ad_schedule_targets end |
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to. If not set, the
default conversion action is used. This field only has effect if
call_conversion_reporting_state is set to
USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION.
Corresponds to the JSON property callConversionAction
2761 2762 2763 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2761 def call_conversion_action @call_conversion_action end |
#call_conversion_reporting_state ⇒ String
Output only. Indicates whether this CallAsset should use its own call
conversion setting, follow the account level setting, or disable call
conversion.
Corresponds to the JSON property callConversionReportingState
2768 2769 2770 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2768 def call_conversion_reporting_state @call_conversion_reporting_state end |
#call_only ⇒ Boolean Also known as: call_only?
Whether the call only shows the phone number without a link to the website.
Applies to Microsoft Ads.
Corresponds to the JSON property callOnly
2774 2775 2776 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2774 def call_only @call_only end |
#call_tracking_enabled ⇒ Boolean Also known as: call_tracking_enabled?
Whether the call should be enabled on call tracking. Applies to Microsoft Ads.
Corresponds to the JSON property callTrackingEnabled
2780 2781 2782 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2780 def call_tracking_enabled @call_tracking_enabled end |
#country_code ⇒ String
Two-letter country code of the phone number. Examples: 'US', 'us'.
Corresponds to the JSON property countryCode
2786 2787 2788 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2786 def country_code @country_code end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
2792 2793 2794 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2792 def end_date @end_date end |
#phone_number ⇒ String
The advertiser's raw phone number. Examples: '1234567890', '(123)456-7890'
Corresponds to the JSON property phoneNumber
2797 2798 2799 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2797 def phone_number @phone_number end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
2803 2804 2805 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2803 def start_date @start_date end |
#use_searcher_time_zone ⇒ Boolean Also known as: use_searcher_time_zone?
Whether to show the call extension in search user's time zone. Applies to
Microsoft Ads.
Corresponds to the JSON property useSearcherTimeZone
2809 2810 2811 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2809 def use_searcher_time_zone @use_searcher_time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2817 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action) @call_conversion_reporting_state = args[:call_conversion_reporting_state] if args.key?(:call_conversion_reporting_state) @call_only = args[:call_only] if args.key?(:call_only) @call_tracking_enabled = args[:call_tracking_enabled] if args.key?(:call_tracking_enabled) @country_code = args[:country_code] if args.key?(:country_code) @end_date = args[:end_date] if args.key?(:end_date) @phone_number = args[:phone_number] if args.key?(:phone_number) @start_date = args[:start_date] if args.key?(:start_date) @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone) end |