Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCalloutAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A unified callout asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedCalloutAsset

Returns a new instance of GoogleAdsSearchads360V0CommonUnifiedCalloutAsset.



2865
2866
2867
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedule_targetsArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAdScheduleInfo>

List of non-overlapping schedules specifying all time intervals for which the asset may serve. There can be a maximum of 6 schedules per day, 42 in total. Corresponds to the JSON property adScheduleTargets



2839
2840
2841
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2839

def ad_schedule_targets
  @ad_schedule_targets
end

#callout_textString

The callout text. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property calloutText

Returns:

  • (String)


2845
2846
2847
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2845

def callout_text
  @callout_text
end

#end_dateString

Last date of when this asset is effective and still serving, in yyyy-MM-dd format. Corresponds to the JSON property endDate

Returns:

  • (String)


2851
2852
2853
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2851

def end_date
  @end_date
end

#start_dateString

Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format. Corresponds to the JSON property startDate

Returns:

  • (String)


2857
2858
2859
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2857

def start_date
  @start_date
end

#use_searcher_time_zoneBoolean Also known as: use_searcher_time_zone?

Whether to show the asset in search user's time zone. Applies to Microsoft Ads. Corresponds to the JSON property useSearcherTimeZone

Returns:

  • (Boolean)


2862
2863
2864
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2862

def use_searcher_time_zone
  @use_searcher_time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2870
2871
2872
2873
2874
2875
2876
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2870

def update!(**args)
  @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets)
  @callout_text = args[:callout_text] if args.key?(:callout_text)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone)
end