Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A unified location asset.
Instance Attribute Summary collapse
-
#business_profile_locations ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonBusinessProfileLocation>
The list of business locations for the customer.
-
#location_ownership_type ⇒ String
The type of location ownership.
-
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedLocationAsset
constructor
A new instance of GoogleAdsSearchads360V0CommonUnifiedLocationAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedLocationAsset
Returns a new instance of GoogleAdsSearchads360V0CommonUnifiedLocationAsset.
2966 2967 2968 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_profile_locations ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonBusinessProfileLocation>
The list of business locations for the customer. This will only be returned if
the Location Asset is syncing from the Business Profile account. It is
possible to have multiple Business Profile listings under the same account
that point to the same Place ID.
Corresponds to the JSON property businessProfileLocations
2949 2950 2951 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2949 def business_profile_locations @business_profile_locations end |
#location_ownership_type ⇒ String
The type of location ownership. If the type is BUSINESS_OWNER, it will be
served as a location extension. If the type is AFFILIATE, it will be served as
an affiliate location.
Corresponds to the JSON property locationOwnershipType
2956 2957 2958 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2956 def location_ownership_type @location_ownership_type end |
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on
Google Maps. This field is unique for a given customer ID and asset type. See
https://developers.google.com/places/web-service/place-id to learn more about
Place ID.
Corresponds to the JSON property placeId
2964 2965 2966 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2964 def place_id @place_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2971 2972 2973 2974 2975 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2971 def update!(**args) @business_profile_locations = args[:business_profile_locations] if args.key?(:business_profile_locations) @location_ownership_type = args[:location_ownership_type] if args.key?(:location_ownership_type) @place_id = args[:place_id] if args.key?(:place_id) end |