Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A unified location asset.
Instance Attribute Summary collapse
-
#business_profile_locations ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonBusinessProfileLocation>
The list of business locations for the customer.
-
#location_ownership_type ⇒ String
The type of location ownership.
-
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedLocationAsset
constructor
A new instance of GoogleAdsSearchads360V0CommonUnifiedLocationAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0CommonUnifiedLocationAsset
Returns a new instance of GoogleAdsSearchads360V0CommonUnifiedLocationAsset.
2906 2907 2908 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_profile_locations ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonBusinessProfileLocation>
The list of business locations for the customer. This will only be returned if
the Location Asset is syncing from the Business Profile account. It is
possible to have multiple Business Profile listings under the same account
that point to the same Place ID.
Corresponds to the JSON property businessProfileLocations
2889 2890 2891 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2889 def business_profile_locations @business_profile_locations end |
#location_ownership_type ⇒ String
The type of location ownership. If the type is BUSINESS_OWNER, it will be
served as a location extension. If the type is AFFILIATE, it will be served as
an affiliate location.
Corresponds to the JSON property locationOwnershipType
2896 2897 2898 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2896 def location_ownership_type @location_ownership_type end |
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on
Google Maps. This field is unique for a given customer ID and asset type. See
https://developers.google.com/places/web-service/place-id to learn more about
Place ID.
Corresponds to the JSON property placeId
2904 2905 2906 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2904 def place_id @place_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2911 2912 2913 2914 2915 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 2911 def update!(**args) @business_profile_locations = args[:business_profile_locations] if args.key?(:business_profile_locations) @location_ownership_type = args[:location_ownership_type] if args.key?(:location_ownership_type) @place_id = args[:place_id] if args.key?(:place_id) end |