Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Additional error details.
Instance Attribute Summary collapse
-
#quota_error_details ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
-
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorDetails
constructor
A new instance of GoogleAdsSearchads360V0ErrorsErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorDetails
Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorDetails.
3320 3321 3322 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#quota_error_details ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
Corresponds to the JSON property quotaErrorDetails
3312 3313 3314 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3312 def quota_error_details @quota_error_details end |
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't. This is used when
the error code is not published in the client specified version.
Corresponds to the JSON property unpublishedErrorCode
3318 3319 3320 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3318 def unpublished_error_code @unpublished_error_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3325 3326 3327 3328 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3325 def update!(**args) @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details) @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code) end |