Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Represents a view of BiddingStrategies owned by and shared with the customer. In contrast to BiddingStrategy, this resource includes strategies owned by managers of the customer and shared with this customer - in addition to strategies owned by this customer. This resource does not provide metrics and only exposes a limited subset of the BiddingStrategy attributes.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#maximize_conversion_value ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.
-
#maximize_conversions ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.
-
#name ⇒ String
Output only.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#owner_descriptive_name ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
-
#target_impression_share ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location).
-
#target_roas ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
-
#target_spend ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy.
4298 4299 4300 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of the bidding strategy.
Corresponds to the JSON property id
4233 4234 4235 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4233 def id @id end |
#maximize_conversion_value ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversionValue
4239 4240 4241 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4239 def maximize_conversion_value @maximize_conversion_value end |
#maximize_conversions ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversions
An automated bidding strategy to help get the most conversions for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversions
4245 4246 4247 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4245 def maximize_conversions @maximize_conversions end |
#name ⇒ String
Output only. The name of the bidding strategy.
Corresponds to the JSON property name
4250 4251 4252 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4250 def name @name end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the bidding strategy.
Corresponds to the JSON property ownerCustomerId
4255 4256 4257 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4255 def owner_customer_id @owner_customer_id end |
#owner_descriptive_name ⇒ String
Output only. descriptive_name of the Customer which owns the bidding strategy.
Corresponds to the JSON property ownerDescriptiveName
4260 4261 4262 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4260 def owner_descriptive_name @owner_descriptive_name end |
#resource_name ⇒ String
Output only. The resource name of the accessible bidding strategy.
AccessibleBiddingStrategy resource names have the form: customers/
customer_id/accessibleBiddingStrategies/bidding_strategy_id`
Corresponds to the JSON propertyresourceName`
4267 4268 4269 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4267 def resource_name @resource_name end |
#target_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
An automated bid strategy that sets bids to help get as many conversions as
possible at the target cost-per-acquisition (CPA) you set.
Corresponds to the JSON property targetCpa
4273 4274 4275 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4273 def target_cpa @target_cpa end |
#target_impression_share ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of
search ads are shown at the top of the first page (or other targeted location).
Corresponds to the JSON property targetImpressionShare
4279 4280 4281 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4279 def target_impression_share @target_impression_share end |
#target_roas ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging
a specific target return on ad spend (ROAS).
Corresponds to the JSON property targetRoas
4285 4286 4287 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4285 def target_roas @target_roas end |
#target_spend ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as
possible within your budget.
Corresponds to the JSON property targetSpend
4291 4292 4293 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4291 def target_spend @target_spend end |
#type ⇒ String
Output only. The type of the bidding strategy.
Corresponds to the JSON property type
4296 4297 4298 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4296 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4303 def update!(**args) @id = args[:id] if args.key?(:id) @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value) @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions) @name = args[:name] if args.key?(:name) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @owner_descriptive_name = args[:owner_descriptive_name] if args.key?(:owner_descriptive_name) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_cpa = args[:target_cpa] if args.key?(:target_cpa) @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share) @target_roas = args[:target_roas] if args.key?(:target_roas) @target_spend = args[:target_spend] if args.key?(:target_spend) @type = args[:type] if args.key?(:type) end |