Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue

Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyMaximizeConversionValue.



3465
3466
3467
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_roasFloat

Output only. The target return on ad spend (ROAS) option. If set, the bid strategy will maximize revenue while averaging the target return on ad spend. If the target ROAS is high, the bid strategy may not be able to spend the full budget. If the target ROAS is not set, the bid strategy will aim to achieve the highest possible ROAS for the budget. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


3463
3464
3465
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3463

def target_roas
  @target_roas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3470
3471
3472
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3470

def update!(**args)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
end