Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
Instance Attribute Summary collapse
-
#target_cpa_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa
Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetCpa.
3514 3515 3516 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_cpa_micros ⇒ Fixnum
Output only. Average CPA target. This target should be greater than or equal
to minimum billable unit based on the currency for the account.
Corresponds to the JSON property targetCpaMicros
3512 3513 3514 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3512 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3519 3520 3521 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3519 def update!(**args) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |