Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Output only.
-
#target_spend_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend
Returns a new instance of GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategyTargetSpend.
3600 3601 3602 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Output only. Maximum bid limit that can be set by the bid strategy. The limit
applies to all keywords managed by the strategy.
Corresponds to the JSON property cpcBidCeilingMicros
3588 3589 3590 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3588 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#target_spend_micros ⇒ Fixnum
Output only. The spend target under which to maximize clicks. A TargetSpend
bidder will attempt to spend the smaller of this value or the natural
throttling spend amount. If not specified, the budget is used as the spend
target. This field is deprecated and should no longer be used. See https://ads-
developers.googleblog.com/2020/05/reminder-about-sunset-creation-of.html for
details.
Corresponds to the JSON property targetSpendMicros
3598 3599 3600 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3598 def target_spend_micros @target_spend_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3605 3606 3607 3608 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3605 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @target_spend_micros = args[:target_spend_micros] if args.key?(:target_spend_micros) end |