Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An ad.
Instance Attribute Summary collapse
-
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
-
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
-
#expanded_text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad.
-
#final_app_urls ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the specific app installed.
-
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for the ad.
-
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
-
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Immutable.
-
#product_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
-
#resource_name ⇒ String
Immutable.
-
#responsive_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
-
#synthetic_content_info ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
Container for synthetic content attestations from different sources, such as the advertiser and Google systems.
-
#text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAd
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAd
Returns a new instance of GoogleAdsSearchads360V0ResourcesAd.
4409 4410 4411 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
Corresponds to the JSON property displayUrl
4326 4327 4328 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4326 def display_url @display_url end |
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
Corresponds to the JSON property expandedDynamicSearchAd
4331 4332 4333 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4331 def @expanded_dynamic_search_ad end |
#expanded_text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad. Expanded text ads are deprecated. Use
SearchAds360ResponsiveSearchAd instead.
Corresponds to the JSON property expandedTextAd
4337 4338 4339 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4337 def @expanded_text_ad end |
#final_app_urls ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the
specific app installed.
Corresponds to the JSON property finalAppUrls
4343 4344 4345 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4343 def final_app_urls @final_app_urls end |
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for
the ad.
Corresponds to the JSON property finalMobileUrls
4349 4350 4351 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4349 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
Corresponds to the JSON property finalUrlSuffix
4354 4355 4356 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4354 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
Corresponds to the JSON property finalUrls
4359 4360 4361 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4359 def final_urls @final_urls end |
#id ⇒ Fixnum
Output only. The ID of the ad.
Corresponds to the JSON property id
4364 4365 4366 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4364 def id @id end |
#name ⇒ String
Immutable. The name of the ad. This is only used to be able to identify the ad.
It does not need to be unique and does not affect the served ad.
Corresponds to the JSON property name
4370 4371 4372 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4370 def name @name end |
#product_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
Corresponds to the JSON property productAd
4375 4376 4377 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4375 def product_ad @product_ad end |
#resource_name ⇒ String
Immutable. The resource name of the ad. Ad resource names have the form:
customers/customer_id/ads/ad_id`
Corresponds to the JSON propertyresourceName`
4381 4382 4383 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4381 def resource_name @resource_name end |
#responsive_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
Corresponds to the JSON property responsiveSearchAd
4386 4387 4388 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4386 def responsive_search_ad @responsive_search_ad end |
#synthetic_content_info ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
Container for synthetic content attestations from different sources, such as
the advertiser and Google systems.
Corresponds to the JSON property syntheticContentInfo
4392 4393 4394 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4392 def synthetic_content_info @synthetic_content_info end |
#text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
Corresponds to the JSON property textAd
4397 4398 4399 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4397 def text_ad @text_ad end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
4402 4403 4404 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4402 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Output only. The type of ad.
Corresponds to the JSON property type
4407 4408 4409 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4407 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4414 def update!(**args) @display_url = args[:display_url] if args.key?(:display_url) @expanded_dynamic_search_ad = args[:expanded_dynamic_search_ad] if args.key?(:expanded_dynamic_search_ad) @expanded_text_ad = args[:expanded_text_ad] if args.key?(:expanded_text_ad) @final_app_urls = args[:final_app_urls] if args.key?(:final_app_urls) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @product_ad = args[:product_ad] if args.key?(:product_ad) @resource_name = args[:resource_name] if args.key?(:resource_name) @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad) @synthetic_content_info = args[:synthetic_content_info] if args.key?(:synthetic_content_info) @text_ad = args[:text_ad] if args.key?(:text_ad) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) end |