Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An ad.
Instance Attribute Summary collapse
-
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
-
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
-
#expanded_text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad.
-
#final_app_urls ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the specific app installed.
-
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for the ad.
-
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
-
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Immutable.
-
#product_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
-
#resource_name ⇒ String
Immutable.
-
#responsive_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
-
#text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAd
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAd
Returns a new instance of GoogleAdsSearchads360V0ResourcesAd.
4342 4343 4344 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
Corresponds to the JSON property displayUrl
4266 4267 4268 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4266 def display_url @display_url end |
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
Corresponds to the JSON property expandedDynamicSearchAd
4271 4272 4273 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4271 def @expanded_dynamic_search_ad end |
#expanded_text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad.
Corresponds to the JSON property expandedTextAd
4276 4277 4278 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4276 def @expanded_text_ad end |
#final_app_urls ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the
specific app installed.
Corresponds to the JSON property finalAppUrls
4282 4283 4284 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4282 def final_app_urls @final_app_urls end |
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for
the ad.
Corresponds to the JSON property finalMobileUrls
4288 4289 4290 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4288 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
Corresponds to the JSON property finalUrlSuffix
4293 4294 4295 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4293 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
Corresponds to the JSON property finalUrls
4298 4299 4300 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4298 def final_urls @final_urls end |
#id ⇒ Fixnum
Output only. The ID of the ad.
Corresponds to the JSON property id
4303 4304 4305 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4303 def id @id end |
#name ⇒ String
Immutable. The name of the ad. This is only used to be able to identify the ad.
It does not need to be unique and does not affect the served ad.
Corresponds to the JSON property name
4309 4310 4311 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4309 def name @name end |
#product_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
Corresponds to the JSON property productAd
4314 4315 4316 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4314 def product_ad @product_ad end |
#resource_name ⇒ String
Immutable. The resource name of the ad. Ad resource names have the form:
customers/customer_id/ads/ad_id`
Corresponds to the JSON propertyresourceName`
4320 4321 4322 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4320 def resource_name @resource_name end |
#responsive_search_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
Corresponds to the JSON property responsiveSearchAd
4325 4326 4327 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4325 def responsive_search_ad @responsive_search_ad end |
#text_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
Corresponds to the JSON property textAd
4330 4331 4332 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4330 def text_ad @text_ad end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
4335 4336 4337 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4335 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Output only. The type of ad.
Corresponds to the JSON property type
4340 4341 4342 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4340 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4347 def update!(**args) @display_url = args[:display_url] if args.key?(:display_url) @expanded_dynamic_search_ad = args[:expanded_dynamic_search_ad] if args.key?(:expanded_dynamic_search_ad) @expanded_text_ad = args[:expanded_text_ad] if args.key?(:expanded_text_ad) @final_app_urls = args[:final_app_urls] if args.key?(:final_app_urls) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @product_ad = args[:product_ad] if args.key?(:product_ad) @resource_name = args[:resource_name] if args.key?(:resource_name) @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad) @text_ad = args[:text_ad] if args.key?(:text_ad) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) end |