Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An ad group.
Instance Attribute Summary collapse
-
#ad_rotation_mode ⇒ String
The ad rotation mode of the ad group.
-
#cpc_bid_micros ⇒ Fixnum
The maximum CPC (cost-per-click) bid.
-
#creation_time ⇒ String
Output only.
-
#effective_labels ⇒ Array<String>
Output only.
-
#end_date ⇒ String
Output only.
-
#engine_id ⇒ String
Output only.
-
#engine_status ⇒ String
Output only.
-
#final_url_suffix ⇒ String
URL template for appending params to Final URL.
-
#id ⇒ Fixnum
Output only.
-
#labels ⇒ Array<String>
Output only.
-
#language_code ⇒ String
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#name ⇒ String
The name of the ad group.
-
#resource_name ⇒ String
Immutable.
-
#start_date ⇒ String
Output only.
-
#status ⇒ String
The status of the ad group.
-
#targeting_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group levels.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroup
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroup
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroup.
4559 4560 4561 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_rotation_mode ⇒ String
The ad rotation mode of the ad group.
Corresponds to the JSON property adRotationMode
4441 4442 4443 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4441 def ad_rotation_mode @ad_rotation_mode end |
#cpc_bid_micros ⇒ Fixnum
The maximum CPC (cost-per-click) bid. This field is used when the ad group's
effective bidding strategy is Manual CPC. This field is not applicable and
will be ignored if the ad group's campaign is using a portfolio bidding
strategy.
Corresponds to the JSON property cpcBidMicros
4449 4450 4451 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4449 def cpc_bid_micros @cpc_bid_micros end |
#creation_time ⇒ String
Output only. The timestamp when this ad_group was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
4455 4456 4457 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4455 def creation_time @creation_time end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this ad group.
An effective label is a label inherited or directly assigned to this ad group.
Corresponds to the JSON property effectiveLabels
4461 4462 4463 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4461 def effective_labels @effective_labels end |
#end_date ⇒ String
Output only. Date when the ad group ends serving ads. By default, the ad group
ends on the ad group's end date. If this field is set, then the ad group ends
at the end of the specified date in the customer's time zone. This field is
only available for Microsoft Advertising and Facebook gateway accounts. Format:
YYYY-MM-DD Example: 2019-03-14
Corresponds to the JSON property endDate
4470 4471 4472 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4470 def end_date @end_date end |
#engine_id ⇒ String
Output only. ID of the ad group in the external engine account. This field is
for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu
etc. For Google Ads entity, use "ad_group.id" instead.
Corresponds to the JSON property engineId
4477 4478 4479 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4477 def engine_id @engine_id end |
#engine_status ⇒ String
Output only. The Engine Status for ad group.
Corresponds to the JSON property engineStatus
4482 4483 4484 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4482 def engine_status @engine_status end |
#final_url_suffix ⇒ String
URL template for appending params to Final URL.
Corresponds to the JSON property finalUrlSuffix
4487 4488 4489 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4487 def final_url_suffix @final_url_suffix end |
#id ⇒ Fixnum
Output only. The ID of the ad group.
Corresponds to the JSON property id
4492 4493 4494 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4492 def id @id end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this ad group.
Corresponds to the JSON property labels
4497 4498 4499 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4497 def labels @labels end |
#language_code ⇒ String
Output only. The language of the ads and keywords in an ad group. This field
is only available for Microsoft Advertising accounts. More details: https://
docs.microsoft.com/en-us/advertising/guides/ad-languages?view=bingads-13#
adlanguage
Corresponds to the JSON property languageCode
4505 4506 4507 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4505 def language_code @language_code end |
#last_modified_time ⇒ String
Output only. The datetime when this ad group was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
4511 4512 4513 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4511 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the ad group. This field is required and should not be empty when
creating new ad groups. It must contain fewer than 255 UTF-8 full-width
characters. It must not contain any null (code point 0x0), NL line feed (code
point 0xA) or carriage return (code point 0xD) characters.
Corresponds to the JSON property name
4519 4520 4521 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4519 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the ad group. Ad group resource names have the
form: customers/customer_id/adGroups/ad_group_id`
Corresponds to the JSON propertyresourceName`
4525 4526 4527 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4525 def resource_name @resource_name end |
#start_date ⇒ String
Output only. Date when this ad group starts serving ads. By default, the ad
group starts now or the ad group's start date, whichever is later. If this
field is set, then the ad group starts at the beginning of the specified date
in the customer's time zone. This field is only available for Microsoft
Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03-
14
Corresponds to the JSON property startDate
4535 4536 4537 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4535 def start_date @start_date end |
#status ⇒ String
The status of the ad group.
Corresponds to the JSON property status
4540 4541 4542 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4540 def status @status end |
#targeting_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group
levels. For more details about the targeting setting, visit https://support.
google.com/google-ads/answer/7365594
Corresponds to the JSON property targetingSetting
4547 4548 4549 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4547 def targeting_setting @targeting_setting end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
4552 4553 4554 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4552 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Immutable. The type of the ad group.
Corresponds to the JSON property type
4557 4558 4559 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4557 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4564 def update!(**args) @ad_rotation_mode = args[:ad_rotation_mode] if args.key?(:ad_rotation_mode) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @creation_time = args[:creation_time] if args.key?(:creation_time) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @end_date = args[:end_date] if args.key?(:end_date) @engine_id = args[:engine_id] if args.key?(:engine_id) @engine_status = args[:engine_status] if args.key?(:engine_status) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @id = args[:id] if args.key?(:id) @labels = args[:labels] if args.key?(:labels) @language_code = args[:language_code] if args.key?(:language_code) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @status = args[:status] if args.key?(:status) @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) end |