Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroup

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroup.



4491
4492
4493
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_rotation_modeString

The ad rotation mode of the ad group. Corresponds to the JSON property adRotationMode

Returns:

  • (String)


4373
4374
4375
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4373

def ad_rotation_mode
  @ad_rotation_mode
end

#cpc_bid_microsFixnum

The maximum CPC (cost-per-click) bid. This field is used when the ad group's effective bidding strategy is Manual CPC. This field is not applicable and will be ignored if the ad group's campaign is using a portfolio bidding strategy. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


4381
4382
4383
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4381

def cpc_bid_micros
  @cpc_bid_micros
end

#creation_timeString

Output only. The timestamp when this ad_group was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


4387
4388
4389
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4387

def creation_time
  @creation_time
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad group. An effective label is a label inherited or directly assigned to this ad group. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


4393
4394
4395
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4393

def effective_labels
  @effective_labels
end

#end_dateString

Output only. Date when the ad group ends serving ads. By default, the ad group ends on the ad group's end date. If this field is set, then the ad group ends at the end of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03-14 Corresponds to the JSON property endDate

Returns:

  • (String)


4402
4403
4404
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4402

def end_date
  @end_date
end

#engine_idString

Output only. ID of the ad group in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "ad_group.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


4409
4410
4411
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4409

def engine_id
  @engine_id
end

#engine_statusString

Output only. The Engine Status for ad group. Corresponds to the JSON property engineStatus

Returns:

  • (String)


4414
4415
4416
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4414

def engine_status
  @engine_status
end

#final_url_suffixString

URL template for appending params to Final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


4419
4420
4421
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4419

def final_url_suffix
  @final_url_suffix
end

#idFixnum

Output only. The ID of the ad group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4424
4425
4426
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4424

def id
  @id
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4429
4430
4431
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4429

def labels
  @labels
end

#language_codeString

Output only. The language of the ads and keywords in an ad group. This field is only available for Microsoft Advertising accounts. More details: https:// docs.microsoft.com/en-us/advertising/guides/ad-languages?view=bingads-13# adlanguage Corresponds to the JSON property languageCode

Returns:

  • (String)


4437
4438
4439
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4437

def language_code
  @language_code
end

#last_modified_timeString

Output only. The datetime when this ad group was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


4443
4444
4445
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4443

def last_modified_time
  @last_modified_time
end

#nameString

The name of the ad group. This field is required and should not be empty when creating new ad groups. It must contain fewer than 255 UTF-8 full-width characters. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


4451
4452
4453
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4451

def name
  @name
end

#resource_nameString

Immutable. The resource name of the ad group. Ad group resource names have the form: customers/customer_id/adGroups/ad_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4457
4458
4459
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4457

def resource_name
  @resource_name
end

#start_dateString

Output only. Date when this ad group starts serving ads. By default, the ad group starts now or the ad group's start date, whichever is later. If this field is set, then the ad group starts at the beginning of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03- 14 Corresponds to the JSON property startDate

Returns:

  • (String)


4467
4468
4469
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4467

def start_date
  @start_date
end

#statusString

The status of the ad group. Corresponds to the JSON property status

Returns:

  • (String)


4472
4473
4474
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4472

def status
  @status
end

#targeting_settingGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetingSetting

Settings for the targeting-related features, at the campaign and ad group levels. For more details about the targeting setting, visit https://support. google.com/google-ads/answer/7365594 Corresponds to the JSON property targetingSetting



4479
4480
4481
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4479

def targeting_setting
  @targeting_setting
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


4484
4485
4486
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4484

def tracking_url_template
  @tracking_url_template
end

#typeString

Immutable. The type of the ad group. Corresponds to the JSON property type

Returns:

  • (String)


4489
4490
4491
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4489

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4496
4497
4498
4499
4500
4501
4502
4503
4504
4505
4506
4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4496

def update!(**args)
  @ad_rotation_mode = args[:ad_rotation_mode] if args.key?(:ad_rotation_mode)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @end_date = args[:end_date] if args.key?(:end_date)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @status = args[:status] if args.key?(:status)
  @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
end