Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
An ad group ad.
Instance Attribute Summary collapse
-
#ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
An ad.
-
#creation_time ⇒ String
Output only.
-
#effective_labels ⇒ Array<String>
Output only.
-
#engine_id ⇒ String
Output only.
-
#engine_status ⇒ String
Output only.
-
#labels ⇒ Array<String>
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAd
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAd
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAd.
4645 4646 4647 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd
An ad.
Corresponds to the JSON property ad
4594 4595 4596 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4594 def ad @ad end |
#creation_time ⇒ String
Output only. The timestamp when this ad_group_ad was created. The datetime is
in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property creationTime
4600 4601 4602 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4600 def creation_time @creation_time end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this ad. An
effective label is a label inherited or directly assigned to this ad.
Corresponds to the JSON property effectiveLabels
4606 4607 4608 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4606 def effective_labels @effective_labels end |
#engine_id ⇒ String
Output only. ID of the ad in the external engine account. This field is for
Search Ads 360 account only, for example, Yahoo Japan, Microsoft, Baidu etc.
For non-Search Ads 360 entity, use "ad_group_ad.ad.id" instead.
Corresponds to the JSON property engineId
4613 4614 4615 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4613 def engine_id @engine_id end |
#engine_status ⇒ String
Output only. Additional status of the ad in the external engine account.
Possible statuses (depending on the type of external account) include active,
eligible, pending review, etc.
Corresponds to the JSON property engineStatus
4620 4621 4622 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4620 def engine_status @engine_status end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this ad group ad.
Corresponds to the JSON property labels
4625 4626 4627 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4625 def labels @labels end |
#last_modified_time ⇒ String
Output only. The datetime when this ad group ad was last modified. The
datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss"
format.
Corresponds to the JSON property lastModifiedTime
4632 4633 4634 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4632 def last_modified_time @last_modified_time end |
#resource_name ⇒ String
Immutable. The resource name of the ad. Ad group ad resource names have the
form: customers/customer_id/adGroupAds/ad_group_id~ad_id`
Corresponds to the JSON propertyresourceName`
4638 4639 4640 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4638 def resource_name @resource_name end |
#status ⇒ String
The status of the ad.
Corresponds to the JSON property status
4643 4644 4645 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4643 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4650 def update!(**args) @ad = args[:ad] if args.key?(:ad) @creation_time = args[:creation_time] if args.key?(:creation_time) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @engine_id = args[:engine_id] if args.key?(:engine_id) @engine_status = args[:engine_status] if args.key?(:engine_status) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |