Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAd

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAd.



4577
4578
4579
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAd

An ad. Corresponds to the JSON property ad



4526
4527
4528
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4526

def ad
  @ad
end

#creation_timeString

Output only. The timestamp when this ad_group_ad was created. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


4532
4533
4534
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4532

def creation_time
  @creation_time
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad. An effective label is a label inherited or directly assigned to this ad. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


4538
4539
4540
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4538

def effective_labels
  @effective_labels
end

#engine_idString

Output only. ID of the ad in the external engine account. This field is for Search Ads 360 account only, for example, Yahoo Japan, Microsoft, Baidu etc. For non-Search Ads 360 entity, use "ad_group_ad.ad.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


4545
4546
4547
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4545

def engine_id
  @engine_id
end

#engine_statusString

Output only. Additional status of the ad in the external engine account. Possible statuses (depending on the type of external account) include active, eligible, pending review, etc. Corresponds to the JSON property engineStatus

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4552

def engine_status
  @engine_status
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group ad. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4557
4558
4559
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4557

def labels
  @labels
end

#last_modified_timeString

Output only. The datetime when this ad group ad was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


4564
4565
4566
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4564

def last_modified_time
  @last_modified_time
end

#resource_nameString

Immutable. The resource name of the ad. Ad group ad resource names have the form: customers/customer_id/adGroupAds/ad_group_id~ad_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4570
4571
4572
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4570

def resource_name
  @resource_name
end

#statusString

The status of the ad. Corresponds to the JSON property status

Returns:

  • (String)


4575
4576
4577
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4575

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4582

def update!(**args)
  @ad = args[:ad] if args.key?(:ad)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @labels = args[:labels] if args.key?(:labels)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end