Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A relationship between an ad group ad and an effective label. An effective label is a label inherited or directly assigned to this ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel.



4622
4623
4624
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adString

Immutable. The ad group ad to which the effective label is attached. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


4603
4604
4605
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4603

def ad_group_ad
  @ad_group_ad
end

#labelString

Immutable. The effective label assigned to the ad group ad. Corresponds to the JSON property label

Returns:

  • (String)


4608
4609
4610
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4608

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


4613
4614
4615
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4613

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group ad effective label. Ad group ad effective label resource names have the form: customers/owner_customer_id/ adGroupAdEffectiveLabels/ad_group_id~ad_id~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4620
4621
4622
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4620

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4627
4628
4629
4630
4631
4632
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4627

def update!(**args)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end