Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAssetSet

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAssetSet.



4740
4741
4742
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which this asset set is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4721

def ad_group
  @ad_group
end

#asset_setString

Immutable. The asset set which is linked to the ad group. Corresponds to the JSON property assetSet

Returns:

  • (String)


4726
4727
4728
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4726

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the ad group asset set. Ad group asset set resource names have the form: customers/customer_id/adGroupAssetSets/ ad_group_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4733
4734
4735
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4733

def resource_name
  @resource_name
end

#statusString

Output only. The status of the ad group asset set. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


4738
4739
4740
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4738

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4745
4746
4747
4748
4749
4750
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4745

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end