Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An ad group audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated at the audience level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupAudienceView

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupAudienceView.



4766
4767
4768
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the ad group audience view. Ad group audience view resource names have the form: customers/customer_id/ adGroupAudienceViews/ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4764

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4771
4772
4773
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4771

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end