Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An ad group criterion. The ad_group_criterion report only returns criteria that were explicitly added to the ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterion

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterion.



4983
4984
4985
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which the criterion belongs. Corresponds to the JSON property adGroup

Returns:

  • (String)


4818
4819
4820
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4818

def ad_group
  @ad_group
end

#age_rangeGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



4823
4824
4825
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4823

def age_range
  @age_range
end

#bid_modifierFloat

The modifier for the bid when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


4829
4830
4831
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4829

def bid_modifier
  @bid_modifier
end

#cpc_bid_microsFixnum

The CPC (cost-per-click) bid. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


4834
4835
4836
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4834

def cpc_bid_micros
  @cpc_bid_micros
end

#creation_timeString

Output only. The timestamp when this ad group criterion was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


4840
4841
4842
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4840

def creation_time
  @creation_time
end

#criterion_idFixnum

Output only. The ID of the criterion. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


4845
4846
4847
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4845

def criterion_id
  @criterion_id
end

#effective_cpc_bid_microsFixnum

Output only. The effective CPC (cost-per-click) bid. Corresponds to the JSON property effectiveCpcBidMicros

Returns:

  • (Fixnum)


4850
4851
4852
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4850

def effective_cpc_bid_micros
  @effective_cpc_bid_micros
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad group criterion. An effective label is a label inherited or directly assigned to this ad group criterion. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


4857
4858
4859
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4857

def effective_labels
  @effective_labels
end

#engine_idString

Output only. ID of the ad group criterion in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "ad_group_criterion.criterion_id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


4865
4866
4867
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4865

def engine_id
  @engine_id
end

#engine_statusString

Output only. The Engine Status for ad group criterion. Corresponds to the JSON property engineStatus

Returns:

  • (String)


4870
4871
4872
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4870

def engine_status
  @engine_status
end

#final_mobile_urlsArray<String>

The list of possible final mobile URLs after all cross-domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


4875
4876
4877
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4875

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

URL template for appending params to final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


4880
4881
4882
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4880

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

The list of possible final URLs after all cross-domain redirects for the ad. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


4885
4886
4887
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4885

def final_urls
  @final_urls
end

#genderGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



4890
4891
4892
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4890

def gender
  @gender
end

#keywordGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keyword



4895
4896
4897
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4895

def keyword
  @keyword
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group criterion. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4900
4901
4902
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4900

def labels
  @labels
end

#last_modified_timeString

Output only. The datetime when this ad group criterion was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


4907
4908
4909
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4907

def last_modified_time
  @last_modified_time
end

#listing_groupGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonListingGroupInfo

A listing group criterion. Corresponds to the JSON property listingGroup



4912
4913
4914
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4912

def listing_group
  @listing_group
end

#locationGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationInfo

A location criterion. Corresponds to the JSON property location



4917
4918
4919
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4917

def location
  @location
end

#negativeBoolean Also known as: negative?

Immutable. Whether to target (false) or exclude (true) the criterion. This field is immutable. To switch a criterion from positive to negative, remove then re-add it. Corresponds to the JSON property negative

Returns:

  • (Boolean)


4924
4925
4926
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4924

def negative
  @negative
end

#position_estimatesGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates

Estimates for criterion bids at various positions. Corresponds to the JSON property positionEstimates



4930
4931
4932
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4930

def position_estimates
  @position_estimates
end

#quality_infoGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionQualityInfo

A container for ad group criterion quality information. Corresponds to the JSON property qualityInfo



4935
4936
4937
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4935

def quality_info
  @quality_info
end

#resource_nameString

Immutable. The resource name of the ad group criterion. Ad group criterion resource names have the form: customers/customer_id/adGroupCriteria/ ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


4942
4943
4944
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4942

def resource_name
  @resource_name
end

#statusString

The status of the criterion. This is the status of the ad group criterion entity, set by the client. Note: UI reports may incorporate additional information that affects whether a criterion is eligible to run. In some cases a criterion that's REMOVED in the API can still show as enabled in the UI. For example, campaigns by default show to users of all age ranges unless excluded. The UI will show each age range as "enabled", since they're eligible to see the ads; but AdGroupCriterion.status will show "removed", since no positive criterion was added. Corresponds to the JSON property status

Returns:

  • (String)


4954
4955
4956
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4954

def status
  @status
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


4959
4960
4961
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4959

def tracking_url_template
  @tracking_url_template
end

#typeString

Output only. The type of the criterion. Corresponds to the JSON property type

Returns:

  • (String)


4964
4965
4966
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4964

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>

The list of mappings used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. Corresponds to the JSON property urlCustomParameters



4970
4971
4972
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4970

def url_custom_parameters
  @url_custom_parameters
end

#user_listGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



4976
4977
4978
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4976

def user_list
  @user_list
end

#webpageGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageInfo

Represents a criterion for targeting webpages of an advertiser's website. Corresponds to the JSON property webpage



4981
4982
4983
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4981

def webpage
  @webpage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
5013
5014
5015
5016
5017
5018
# File 'lib/google/apis/searchads360_v0/classes.rb', line 4988

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @age_range = args[:age_range] if args.key?(:age_range)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @gender = args[:gender] if args.key?(:gender)
  @keyword = args[:keyword] if args.key?(:keyword)
  @labels = args[:labels] if args.key?(:labels)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @listing_group = args[:listing_group] if args.key?(:listing_group)
  @location = args[:location] if args.key?(:location)
  @negative = args[:negative] if args.key?(:negative)
  @position_estimates = args[:position_estimates] if args.key?(:position_estimates)
  @quality_info = args[:quality_info] if args.key?(:quality_info)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @user_list = args[:user_list] if args.key?(:user_list)
  @webpage = args[:webpage] if args.key?(:webpage)
end