Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A relationship between an ad group criterion and an effective label. An effective label is a label inherited or directly assigned to this ad group criterion.
Instance Attribute Summary collapse
-
#ad_group_criterion ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel.
5118 5119 5120 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_criterion ⇒ String
Immutable. The ad group criterion to which the effective label is attached.
Corresponds to the JSON property adGroupCriterion
5098 5099 5100 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5098 def ad_group_criterion @ad_group_criterion end |
#label ⇒ String
Immutable. The effective label assigned to the ad group criterion.
Corresponds to the JSON property label
5103 5104 5105 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5103 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
5108 5109 5110 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5108 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group criterion effective label. Ad
group criterion effective label resource names have the form: customers/
owner_customer_id/adGroupCriterionEffectiveLabels/ad_group_id~criterion_id
~label_id`
Corresponds to the JSON propertyresourceName`
5116 5117 5118 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5116 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5123 5124 5125 5126 5127 5128 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5123 def update!(**args) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |