Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A relationship between an ad group criterion and an effective label. An effective label is a label inherited or directly assigned to this ad group criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel.



5050
5051
5052
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_criterionString

Immutable. The ad group criterion to which the effective label is attached. Corresponds to the JSON property adGroupCriterion

Returns:

  • (String)


5030
5031
5032
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5030

def ad_group_criterion
  @ad_group_criterion
end

#labelString

Immutable. The effective label assigned to the ad group criterion. Corresponds to the JSON property label

Returns:

  • (String)


5035
5036
5037
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5035

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


5040
5041
5042
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5040

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group criterion effective label. Ad group criterion effective label resource names have the form: customers/ owner_customer_id/adGroupCriterionEffectiveLabels/ad_group_id~criterion_id ~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5048
5049
5050
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5048

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5055
5056
5057
5058
5059
5060
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5055

def update!(**args)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end