Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Estimates for criterion bids at various positions.
Instance Attribute Summary collapse
-
#top_of_page_cpc_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupCriterionPositionEstimates.
3621 3622 3623 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#top_of_page_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be displayed at
the top of the first page of search results.
Corresponds to the JSON property topOfPageCpcMicros
3619 3620 3621 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3619 def top_of_page_cpc_micros @top_of_page_cpc_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3626 3627 3628 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3626 def update!(**args) @top_of_page_cpc_micros = args[:top_of_page_cpc_micros] if args.key?(:top_of_page_cpc_micros) end |