Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A relationship between an ad group and an effective label. An effective label is a label inherited or directly assigned to this ad group.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel.
5129 5130 5131 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which the effective label is attached.
Corresponds to the JSON property adGroup
5110 5111 5112 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5110 def ad_group @ad_group end |
#label ⇒ String
Immutable. The effective label assigned to the ad group.
Corresponds to the JSON property label
5115 5116 5117 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5115 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
5120 5121 5122 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5120 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group effective label. Ad group
effective label resource names have the form: customers/owner_customer_id/
adGroupEffectiveLabels/ad_group_id~label_id`
Corresponds to the JSON propertyresourceName`
5127 5128 5129 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5127 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5134 5135 5136 5137 5138 5139 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5134 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |