Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it.
Instance Attribute Summary collapse
-
#call_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCallAsset
A unified call asset.
-
#call_to_action_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCallToActionAsset
A call to action asset.
-
#callout_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCalloutAsset
A unified callout asset.
-
#creation_time ⇒ String
Output only.
-
#engine_status ⇒ String
Output only.
-
#final_mobile_urls ⇒ Array<String>
A list of possible final mobile URLs after all cross domain redirects.
-
#final_url_suffix ⇒ String
URL template for appending params to landing page URLs served with parallel tracking.
-
#final_urls ⇒ Array<String>
A list of possible final URLs after all cross domain redirects.
-
#id ⇒ Fixnum
Output only.
-
#image_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonImageAsset
An Image asset.
-
#last_modified_time ⇒ String
Output only.
-
#location_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
A unified location asset.
-
#mobile_app_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMobileAppAsset
An asset representing a mobile app.
-
#name ⇒ String
Optional name of the asset.
-
#page_feed_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedPageFeedAsset
A Unified Page Feed asset.
-
#resource_name ⇒ String
Immutable.
-
#sitelink_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedSitelinkAsset
A unified sitelink asset.
-
#status ⇒ String
Output only.
-
#synthetic_content_info ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
Container for synthetic content attestations from different sources, such as the advertiser and Google systems.
-
#text_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTextAsset
A Text asset.
-
#tracking_url_template ⇒ String
URL template for constructing a tracking URL.
-
#type ⇒ String
Output only.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>
A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls.
-
#youtube_video_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonYoutubeVideoAsset
A YouTube asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAsset
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAsset
Returns a new instance of GoogleAdsSearchads360V0ResourcesAsset.
5409 5410 5411 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCallAsset
A unified call asset.
Corresponds to the JSON property callAsset
5286 5287 5288 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5286 def call_asset @call_asset end |
#call_to_action_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCallToActionAsset
A call to action asset.
Corresponds to the JSON property callToActionAsset
5291 5292 5293 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5291 def call_to_action_asset @call_to_action_asset end |
#callout_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCalloutAsset
A unified callout asset.
Corresponds to the JSON property calloutAsset
5296 5297 5298 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5296 def callout_asset @callout_asset end |
#creation_time ⇒ String
Output only. The timestamp when this asset was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
5302 5303 5304 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5302 def creation_time @creation_time end |
#engine_status ⇒ String
Output only. The Engine Status for an asset.
Corresponds to the JSON property engineStatus
5307 5308 5309 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5307 def engine_status @engine_status end |
#final_mobile_urls ⇒ Array<String>
A list of possible final mobile URLs after all cross domain redirects.
Corresponds to the JSON property finalMobileUrls
5312 5313 5314 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5312 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
URL template for appending params to landing page URLs served with parallel
tracking.
Corresponds to the JSON property finalUrlSuffix
5318 5319 5320 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5318 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
A list of possible final URLs after all cross domain redirects.
Corresponds to the JSON property finalUrls
5323 5324 5325 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5323 def final_urls @final_urls end |
#id ⇒ Fixnum
Output only. The ID of the asset.
Corresponds to the JSON property id
5328 5329 5330 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5328 def id @id end |
#image_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonImageAsset
An Image asset.
Corresponds to the JSON property imageAsset
5333 5334 5335 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5333 def image_asset @image_asset end |
#last_modified_time ⇒ String
Output only. The datetime when this asset was last modified. The datetime is
in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
5339 5340 5341 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5339 def last_modified_time @last_modified_time end |
#location_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset
A unified location asset.
Corresponds to the JSON property locationAsset
5344 5345 5346 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5344 def location_asset @location_asset end |
#mobile_app_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMobileAppAsset
An asset representing a mobile app.
Corresponds to the JSON property mobileAppAsset
5349 5350 5351 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5349 def mobile_app_asset @mobile_app_asset end |
#name ⇒ String
Optional name of the asset.
Corresponds to the JSON property name
5354 5355 5356 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5354 def name @name end |
#page_feed_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedPageFeedAsset
A Unified Page Feed asset.
Corresponds to the JSON property pageFeedAsset
5359 5360 5361 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5359 def page_feed_asset @page_feed_asset end |
#resource_name ⇒ String
Immutable. The resource name of the asset. Asset resource names have the form:
customers/customer_id/assets/asset_id`
Corresponds to the JSON propertyresourceName`
5365 5366 5367 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5365 def resource_name @resource_name end |
#sitelink_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedSitelinkAsset
A unified sitelink asset.
Corresponds to the JSON property sitelinkAsset
5370 5371 5372 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5370 def sitelink_asset @sitelink_asset end |
#status ⇒ String
Output only. The status of the asset.
Corresponds to the JSON property status
5375 5376 5377 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5375 def status @status end |
#synthetic_content_info ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSyntheticContentInfo
Container for synthetic content attestations from different sources, such as
the advertiser and Google systems.
Corresponds to the JSON property syntheticContentInfo
5381 5382 5383 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5381 def synthetic_content_info @synthetic_content_info end |
#text_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTextAsset
A Text asset.
Corresponds to the JSON property textAsset
5386 5387 5388 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5386 def text_asset @text_asset end |
#tracking_url_template ⇒ String
URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
5391 5392 5393 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5391 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Output only. Type of the asset.
Corresponds to the JSON property type
5396 5397 5398 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5396 def type @type end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>
A list of mappings to be used for substituting URL custom parameter tags in
the tracking_url_template, final_urls, and/or final_mobile_urls.
Corresponds to the JSON property urlCustomParameters
5402 5403 5404 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5402 def url_custom_parameters @url_custom_parameters end |
#youtube_video_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonYoutubeVideoAsset
A YouTube asset.
Corresponds to the JSON property youtubeVideoAsset
5407 5408 5409 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5407 def youtube_video_asset @youtube_video_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5414 def update!(**args) @call_asset = args[:call_asset] if args.key?(:call_asset) @call_to_action_asset = args[:call_to_action_asset] if args.key?(:call_to_action_asset) @callout_asset = args[:callout_asset] if args.key?(:callout_asset) @creation_time = args[:creation_time] if args.key?(:creation_time) @engine_status = args[:engine_status] if args.key?(:engine_status) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @id = args[:id] if args.key?(:id) @image_asset = args[:image_asset] if args.key?(:image_asset) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @location_asset = args[:location_asset] if args.key?(:location_asset) @mobile_app_asset = args[:mobile_app_asset] if args.key?(:mobile_app_asset) @name = args[:name] if args.key?(:name) @page_feed_asset = args[:page_feed_asset] if args.key?(:page_feed_asset) @resource_name = args[:resource_name] if args.key?(:resource_name) @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset) @status = args[:status] if args.key?(:status) @synthetic_content_info = args[:synthetic_content_info] if args.key?(:synthetic_content_info) @text_asset = args[:text_asset] if args.key?(:text_asset) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @youtube_video_asset = args[:youtube_video_asset] if args.key?(:youtube_video_asset) end |