Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAsset

Returns a new instance of GoogleAdsSearchads360V0ResourcesAsset.



5329
5330
5331
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCallAsset

A unified call asset. Corresponds to the JSON property callAsset



5212
5213
5214
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5212

def call_asset
  @call_asset
end

#call_to_action_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCallToActionAsset

A call to action asset. Corresponds to the JSON property callToActionAsset



5217
5218
5219
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5217

def call_to_action_asset
  @call_to_action_asset
end

#callout_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedCalloutAsset

A unified callout asset. Corresponds to the JSON property calloutAsset



5222
5223
5224
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5222

def callout_asset
  @callout_asset
end

#creation_timeString

Output only. The timestamp when this asset was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


5228
5229
5230
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5228

def creation_time
  @creation_time
end

#engine_statusString

Output only. The Engine Status for an asset. Corresponds to the JSON property engineStatus

Returns:

  • (String)


5233
5234
5235
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5233

def engine_status
  @engine_status
end

#final_mobile_urlsArray<String>

A list of possible final mobile URLs after all cross domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


5238
5239
5240
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5238

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

URL template for appending params to landing page URLs served with parallel tracking. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


5244
5245
5246
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5244

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

A list of possible final URLs after all cross domain redirects. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


5249
5250
5251
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5249

def final_urls
  @final_urls
end

#idFixnum

Output only. The ID of the asset. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5254
5255
5256
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5254

def id
  @id
end

#image_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonImageAsset

An Image asset. Corresponds to the JSON property imageAsset



5259
5260
5261
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5259

def image_asset
  @image_asset
end

#last_modified_timeString

Output only. The datetime when this asset was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


5265
5266
5267
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5265

def last_modified_time
  @last_modified_time
end

#location_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedLocationAsset

A unified location asset. Corresponds to the JSON property locationAsset



5270
5271
5272
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5270

def location_asset
  @location_asset
end

#mobile_app_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMobileAppAsset

An asset representing a mobile app. Corresponds to the JSON property mobileAppAsset



5275
5276
5277
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5275

def mobile_app_asset
  @mobile_app_asset
end

#nameString

Optional name of the asset. Corresponds to the JSON property name

Returns:

  • (String)


5280
5281
5282
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5280

def name
  @name
end

#page_feed_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUnifiedPageFeedAsset

A Unified Page Feed asset. Corresponds to the JSON property pageFeedAsset



5285
5286
5287
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5285

def page_feed_asset
  @page_feed_asset
end

#resource_nameString

Immutable. The resource name of the asset. Asset resource names have the form: customers/customer_id/assets/asset_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5291
5292
5293
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5291

def resource_name
  @resource_name
end

A unified sitelink asset. Corresponds to the JSON property sitelinkAsset



5296
5297
5298
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5296

def sitelink_asset
  @sitelink_asset
end

#statusString

Output only. The status of the asset. Corresponds to the JSON property status

Returns:

  • (String)


5301
5302
5303
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5301

def status
  @status
end

#text_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTextAsset

A Text asset. Corresponds to the JSON property textAsset



5306
5307
5308
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5306

def text_asset
  @text_asset
end

#tracking_url_templateString

URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5311

def tracking_url_template
  @tracking_url_template
end

#typeString

Output only. Type of the asset. Corresponds to the JSON property type

Returns:

  • (String)


5316
5317
5318
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5316

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>

A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls. Corresponds to the JSON property urlCustomParameters



5322
5323
5324
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5322

def url_custom_parameters
  @url_custom_parameters
end

#youtube_video_assetGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonYoutubeVideoAsset

A YouTube asset. Corresponds to the JSON property youtubeVideoAsset



5327
5328
5329
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5327

def youtube_video_asset
  @youtube_video_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5334

def update!(**args)
  @call_asset = args[:call_asset] if args.key?(:call_asset)
  @call_to_action_asset = args[:call_to_action_asset] if args.key?(:call_to_action_asset)
  @callout_asset = args[:callout_asset] if args.key?(:callout_asset)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @id = args[:id] if args.key?(:id)
  @image_asset = args[:image_asset] if args.key?(:image_asset)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @location_asset = args[:location_asset] if args.key?(:location_asset)
  @mobile_app_asset = args[:mobile_app_asset] if args.key?(:mobile_app_asset)
  @name = args[:name] if args.key?(:name)
  @page_feed_asset = args[:page_feed_asset] if args.key?(:page_feed_asset)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
  @status = args[:status] if args.key?(:status)
  @text_asset = args[:text_asset] if args.key?(:text_asset)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @youtube_video_asset = args[:youtube_video_asset] if args.key?(:youtube_video_asset)
end