Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

An asset group. AssetGroupAsset is used to link an asset to the asset group. AssetGroupSignal is used to associate a signal to an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroup

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroup.



5422
5423
5424
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_strengthString

Output only. Overall ad strength of this asset group. Corresponds to the JSON property adStrength

Returns:

  • (String)


5369
5370
5371
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5369

def ad_strength
  @ad_strength
end

#campaignString

Immutable. The campaign with which this asset group is associated. The asset which is linked to the asset group. Corresponds to the JSON property campaign

Returns:

  • (String)


5375
5376
5377
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5375

def campaign
  @campaign
end

#final_mobile_urlsArray<String>

A list of final mobile URLs after all cross domain redirects. In performance max, by default, the urls are eligible for expansion unless opted out. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


5381
5382
5383
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5381

def final_mobile_urls
  @final_mobile_urls
end

#final_urlsArray<String>

A list of final URLs after all cross domain redirects. In performance max, by default, the urls are eligible for expansion unless opted out. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


5387
5388
5389
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5387

def final_urls
  @final_urls
end

#idFixnum

Output only. The ID of the asset group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5392
5393
5394
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5392

def id
  @id
end

#nameString

Required. Name of the asset group. Required. It must have a minimum length of 1 and maximum length of 128. It must be unique under a campaign. Corresponds to the JSON property name

Returns:

  • (String)


5398
5399
5400
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5398

def name
  @name
end

#path1String

First part of text that may appear appended to the url displayed in the ad. Corresponds to the JSON property path1

Returns:

  • (String)


5403
5404
5405
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5403

def path1
  @path1
end

#path2String

Second part of text that may appear appended to the url displayed in the ad. This field can only be set when path1 is set. Corresponds to the JSON property path2

Returns:

  • (String)


5409
5410
5411
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5409

def path2
  @path2
end

#resource_nameString

Immutable. The resource name of the asset group. Asset group resource names have the form: customers/customer_id/assetGroups/asset_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5415
5416
5417
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5415

def resource_name
  @resource_name
end

#statusString

The status of the asset group. Corresponds to the JSON property status

Returns:

  • (String)


5420
5421
5422
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5420

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5427

def update!(**args)
  @ad_strength = args[:ad_strength] if args.key?(:ad_strength)
  @campaign = args[:campaign] if args.key?(:campaign)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @path1 = args[:path1] if args.key?(:path1)
  @path2 = args[:path2] if args.key?(:path2)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end