Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupAsset

Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroupAsset.



5474
5475
5476
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset group asset is linking. Corresponds to the JSON property asset

Returns:

  • (String)


5449
5450
5451
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5449

def asset
  @asset
end

#asset_groupString

Immutable. The asset group which this asset group asset is linking. Corresponds to the JSON property assetGroup

Returns:

  • (String)


5454
5455
5456
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5454

def asset_group
  @asset_group
end

#field_typeString

The description of the placement of the asset within the asset group. For example: HEADLINE, YOUTUBE_VIDEO etc Corresponds to the JSON property fieldType

Returns:

  • (String)


5460
5461
5462
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5460

def field_type
  @field_type
end

#resource_nameString

Immutable. The resource name of the asset group asset. Asset group asset resource name have the form: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


5467
5468
5469
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5467

def resource_name
  @resource_name
end

#statusString

The status of the link between an asset and asset group. Corresponds to the JSON property status

Returns:

  • (String)


5472
5473
5474
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5472

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5479
5480
5481
5482
5483
5484
5485
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5479

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @field_type = args[:field_type] if args.key?(:field_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end