Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more.
Instance Attribute Summary collapse
-
#asset_group ⇒ String
Immutable.
-
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAudienceInfo
An audience criterion.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupSignal
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAssetGroupSignal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetGroupSignal
Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetGroupSignal.
5599 5600 5601 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group ⇒ String
Immutable. The asset group which this asset group signal belongs to.
Corresponds to the JSON property assetGroup
5585 5586 5587 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5585 def asset_group @asset_group end |
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAudienceInfo
An audience criterion.
Corresponds to the JSON property audience
5590 5591 5592 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5590 def audience @audience end |
#resource_name ⇒ String
Immutable. The resource name of the asset group signal. Asset group signal
resource name have the form: customers/customer_id/assetGroupSignals/
asset_group_id~signal_id`
Corresponds to the JSON propertyresourceName`
5597 5598 5599 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5597 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5604 5605 5606 5607 5608 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5604 def update!(**args) @asset_group = args[:asset_group] if args.key?(:asset_group) @audience = args[:audience] if args.key?(:audience) @resource_name = args[:resource_name] if args.key?(:resource_name) end |