Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.
Instance Attribute Summary collapse
-
#asset ⇒ String
Immutable.
-
#asset_set ⇒ String
Immutable.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetSetAsset
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAssetSetAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAssetSetAsset
Returns a new instance of GoogleAdsSearchads360V0ResourcesAssetSetAsset.
5693 5694 5695 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Immutable. The asset which this asset set asset is linking to.
Corresponds to the JSON property asset
5674 5675 5676 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5674 def asset @asset end |
#asset_set ⇒ String
Immutable. The asset set which this asset set asset is linking to.
Corresponds to the JSON property assetSet
5679 5680 5681 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5679 def asset_set @asset_set end |
#resource_name ⇒ String
Immutable. The resource name of the asset set asset. Asset set asset resource
names have the form: customers/customer_id/assetSetAssets/asset_set_id~
asset_id`
Corresponds to the JSON propertyresourceName`
5686 5687 5688 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5686 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the asset set asset. Read-only.
Corresponds to the JSON property status
5691 5692 5693 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5691 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5698 5699 5700 5701 5702 5703 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5698 def update!(**args) @asset = args[:asset] if args.key?(:asset) @asset_set = args[:asset_set] if args.key?(:asset_set) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |