Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this audience.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAudience
constructor
A new instance of GoogleAdsSearchads360V0ResourcesAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesAudience
Returns a new instance of GoogleAdsSearchads360V0ResourcesAudience.
5734 5735 5736 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this audience.
Corresponds to the JSON property description
5715 5716 5717 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5715 def description @description end |
#id ⇒ Fixnum
Output only. ID of the audience.
Corresponds to the JSON property id
5720 5721 5722 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5720 def id @id end |
#name ⇒ String
Required. Name of the audience. It should be unique across all audiences. It
must have a minimum length of 1 and maximum length of 255.
Corresponds to the JSON property name
5726 5727 5728 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5726 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the audience. Audience names have the form:
customers/customer_id/audiences/audience_id`
Corresponds to the JSON propertyresourceName`
5732 5733 5734 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5732 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5739 5740 5741 5742 5743 5744 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5739 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) end |