Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A campaign.
Instance Attribute Summary collapse
-
#accessible_bidding_strategy ⇒ String
Output only.
-
#ad_serving_optimization_status ⇒ String
The ad serving optimization status of the campaign.
-
#advertising_channel_sub_type ⇒ String
Immutable.
-
#advertising_channel_type ⇒ String
Immutable.
-
#bidding_strategy ⇒ String
The resource name of the portfolio bidding strategy used by the campaign.
-
#bidding_strategy_system_status ⇒ String
Output only.
-
#bidding_strategy_type ⇒ String
Output only.
-
#campaign_budget ⇒ String
The resource name of the campaign budget of the campaign.
-
#create_time ⇒ String
Output only.
-
#creation_time ⇒ String
Output only.
-
#dynamic_search_ads_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting
The setting for controlling Dynamic Search Ads (DSA).
-
#effective_labels ⇒ Array<String>
Output only.
-
#end_date ⇒ String
The last day of the campaign in serving customer's timezone in YYYY-MM-DD format.
-
#engine_id ⇒ String
Output only.
-
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this campaign.
-
#feed_types ⇒ Array<String>
Output only.
-
#final_url_suffix ⇒ String
Suffix used to append query parameters to landing pages that are served with parallel tracking.
-
#frequency_caps ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFrequencyCapEntry>
A list that limits how often each user will see this campaign's ads.
-
#geo_target_type_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignGeoTargetTypeSetting
Represents a collection of settings related to ads geotargeting.
-
#id ⇒ Fixnum
Output only.
-
#labels ⇒ Array<String>
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#manual_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpa
Manual bidding strategy that allows advertiser to set the bid per advertiser- specified action.
-
#manual_cpc ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpc
Manual click-based bidding where user pays per click.
-
#manual_cpm ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpm
Manual impression-based bidding where user pays per thousand impressions.
-
#maximize_conversion_value ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.
-
#maximize_conversions ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions
An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.
-
#name ⇒ String
The name of the campaign.
-
#network_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
The network settings for the campaign.
-
#optimization_goal_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignOptimizationGoalSetting
Optimization goal setting for this campaign, which includes a set of optimization goal types.
-
#percent_cpc ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonPercentCpc
A bidding strategy where bids are a fraction of the advertised price for some good or service.
-
#real_time_bidding_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonRealTimeBiddingSetting
Settings for Real-Time Bidding, a feature only available for campaigns targeting the Ad Exchange network.
-
#resource_name ⇒ String
Immutable.
-
#selective_optimization ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignSelectiveOptimization
Selective optimization setting for this campaign, which includes a set of conversion actions to optimize this campaign towards.
-
#serving_status ⇒ String
Output only.
-
#shopping_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting
The setting for Shopping campaigns.
-
#start_date ⇒ String
The date when campaign started in serving customer's timezone in YYYY-MM-DD format.
-
#status ⇒ String
The status of the campaign.
-
#target_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
-
#target_cpm ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpm
Target CPM (cost per thousand impressions) is an automated bidding strategy that sets bids to optimize performance given the target CPM you set.
-
#target_impression_share ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location).
-
#target_roas ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
-
#target_spend ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
-
#tracking_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignTrackingSetting
Campaign-level settings for tracking information.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template,final_urls, ormobile_final_urls. -
#url_expansion_opt_out ⇒ Boolean
(also: #url_expansion_opt_out?)
Represents opting out of URL expansion to more targeted URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaign
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCampaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaign
Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaign.
6184 6185 6186 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessible_bidding_strategy ⇒ String
Output only. Resource name of AccessibleBiddingStrategy, a read-only view of
the unrestricted attributes of the attached portfolio bidding strategy
identified by 'bidding_strategy'. Empty, if the campaign does not use a
portfolio strategy. Unrestricted strategy attributes are available to all
customers with whom the strategy is shared and are read from the
AccessibleBiddingStrategy resource. In contrast, restricted attributes are
only available to the owner customer of the strategy and their managers.
Restricted attributes can only be read from the BiddingStrategy resource.
Corresponds to the JSON property accessibleBiddingStrategy
5903 5904 5905 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5903 def accessible_bidding_strategy @accessible_bidding_strategy end |
#ad_serving_optimization_status ⇒ String
The ad serving optimization status of the campaign.
Corresponds to the JSON property adServingOptimizationStatus
5908 5909 5910 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5908 def ad_serving_optimization_status @ad_serving_optimization_status end |
#advertising_channel_sub_type ⇒ String
Immutable. Optional refinement to advertising_channel_type. Must be a valid
sub-type of the parent channel type. Can be set only when creating campaigns.
After campaign is created, the field can not be changed.
Corresponds to the JSON property advertisingChannelSubType
5915 5916 5917 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5915 def advertising_channel_sub_type @advertising_channel_sub_type end |
#advertising_channel_type ⇒ String
Immutable. The primary serving target for ads within the campaign. The
targeting options can be refined in network_settings. This field is required
and should not be empty when creating new campaigns. Can be set only when
creating campaigns. After the campaign is created, the field can not be
changed.
Corresponds to the JSON property advertisingChannelType
5924 5925 5926 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5924 def advertising_channel_type @advertising_channel_type end |
#bidding_strategy ⇒ String
The resource name of the portfolio bidding strategy used by the campaign.
Corresponds to the JSON property biddingStrategy
5929 5930 5931 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5929 def bidding_strategy @bidding_strategy end |
#bidding_strategy_system_status ⇒ String
Output only. The system status of the campaign's bidding strategy.
Corresponds to the JSON property biddingStrategySystemStatus
5934 5935 5936 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5934 def bidding_strategy_system_status @bidding_strategy_system_status end |
#bidding_strategy_type ⇒ String
Output only. The type of bidding strategy. A bidding strategy can be created
by setting either the bidding scheme to create a standard bidding strategy or
the bidding_strategy field to create a portfolio bidding strategy. This
field is read-only.
Corresponds to the JSON property biddingStrategyType
5942 5943 5944 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5942 def bidding_strategy_type @bidding_strategy_type end |
#campaign_budget ⇒ String
The resource name of the campaign budget of the campaign.
Corresponds to the JSON property campaignBudget
5947 5948 5949 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5947 def campaign_budget @campaign_budget end |
#create_time ⇒ String
Output only. The timestamp when this campaign was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. create_time will
be deprecated in v1. Use creation_time instead.
Corresponds to the JSON property createTime
5954 5955 5956 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5954 def create_time @create_time end |
#creation_time ⇒ String
Output only. The timestamp when this campaign was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
5960 5961 5962 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5960 def creation_time @creation_time end |
#dynamic_search_ads_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignDynamicSearchAdsSetting
The setting for controlling Dynamic Search Ads (DSA).
Corresponds to the JSON property dynamicSearchAdsSetting
5965 5966 5967 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5965 def dynamic_search_ads_setting @dynamic_search_ads_setting end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this campaign.
An effective label is a label inherited or directly assigned to this campaign.
Corresponds to the JSON property effectiveLabels
5971 5972 5973 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5971 def effective_labels @effective_labels end |
#end_date ⇒ String
The last day of the campaign in serving customer's timezone in YYYY-MM-DD
format. On create, defaults to 2037-12-30, which means the campaign will run
indefinitely. To set an existing campaign to run indefinitely, set this field
to 2037-12-30.
Corresponds to the JSON property endDate
5979 5980 5981 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5979 def end_date @end_date end |
#engine_id ⇒ String
Output only. ID of the campaign in the external engine account. This field is
for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu
etc. For Google Ads entity, use "campaign.id" instead.
Corresponds to the JSON property engineId
5986 5987 5988 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5986 def engine_id @engine_id end |
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this campaign. Asset links
with these field types will not be inherited by this campaign from the upper
level.
Corresponds to the JSON property excludedParentAssetFieldTypes
5993 5994 5995 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5993 def excluded_parent_asset_field_types @excluded_parent_asset_field_types end |
#feed_types ⇒ Array<String>
Output only. Types of feeds that are attached directly to this campaign.
Corresponds to the JSON property feedTypes
5998 5999 6000 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 5998 def feed_types @feed_types end |
#final_url_suffix ⇒ String
Suffix used to append query parameters to landing pages that are served with
parallel tracking.
Corresponds to the JSON property finalUrlSuffix
6004 6005 6006 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6004 def final_url_suffix @final_url_suffix end |
#frequency_caps ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonFrequencyCapEntry>
A list that limits how often each user will see this campaign's ads.
Corresponds to the JSON property frequencyCaps
6009 6010 6011 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6009 def frequency_caps @frequency_caps end |
#geo_target_type_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignGeoTargetTypeSetting
Represents a collection of settings related to ads geotargeting.
Corresponds to the JSON property geoTargetTypeSetting
6014 6015 6016 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6014 def geo_target_type_setting @geo_target_type_setting end |
#id ⇒ Fixnum
Output only. The ID of the campaign.
Corresponds to the JSON property id
6019 6020 6021 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6019 def id @id end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this campaign.
Corresponds to the JSON property labels
6024 6025 6026 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6024 def labels @labels end |
#last_modified_time ⇒ String
Output only. The datetime when this campaign was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
6030 6031 6032 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6030 def last_modified_time @last_modified_time end |
#manual_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpa
Manual bidding strategy that allows advertiser to set the bid per advertiser-
specified action.
Corresponds to the JSON property manualCpa
6036 6037 6038 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6036 def manual_cpa @manual_cpa end |
#manual_cpc ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpc
Manual click-based bidding where user pays per click.
Corresponds to the JSON property manualCpc
6041 6042 6043 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6041 def manual_cpc @manual_cpc end |
#manual_cpm ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonManualCpm
Manual impression-based bidding where user pays per thousand impressions.
Corresponds to the JSON property manualCpm
6046 6047 6048 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6046 def manual_cpm @manual_cpm end |
#maximize_conversion_value ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversionValue
6052 6053 6054 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6052 def maximize_conversion_value @maximize_conversion_value end |
#maximize_conversions ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMaximizeConversions
An automated bidding strategy to help get the most conversions for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversions
6058 6059 6060 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6058 def maximize_conversions @maximize_conversions end |
#name ⇒ String
The name of the campaign. This field is required and should not be empty when
creating new campaigns. It must not contain any null (code point 0x0), NL line
feed (code point 0xA) or carriage return (code point 0xD) characters.
Corresponds to the JSON property name
6065 6066 6067 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6065 def name @name end |
#network_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
The network settings for the campaign.
Corresponds to the JSON property networkSettings
6070 6071 6072 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6070 def network_settings @network_settings end |
#optimization_goal_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignOptimizationGoalSetting
Optimization goal setting for this campaign, which includes a set of
optimization goal types.
Corresponds to the JSON property optimizationGoalSetting
6076 6077 6078 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6076 def optimization_goal_setting @optimization_goal_setting end |
#percent_cpc ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonPercentCpc
A bidding strategy where bids are a fraction of the advertised price for some
good or service.
Corresponds to the JSON property percentCpc
6082 6083 6084 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6082 def percent_cpc @percent_cpc end |
#real_time_bidding_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonRealTimeBiddingSetting
Settings for Real-Time Bidding, a feature only available for campaigns
targeting the Ad Exchange network.
Corresponds to the JSON property realTimeBiddingSetting
6088 6089 6090 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6088 def real_time_bidding_setting @real_time_bidding_setting end |
#resource_name ⇒ String
Immutable. The resource name of the campaign. Campaign resource names have the
form: customers/customer_id/campaigns/campaign_id`
Corresponds to the JSON propertyresourceName`
6094 6095 6096 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6094 def resource_name @resource_name end |
#selective_optimization ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignSelectiveOptimization
Selective optimization setting for this campaign, which includes a set of
conversion actions to optimize this campaign towards. This feature only
applies to app campaigns that use MULTI_CHANNEL as AdvertisingChannelType and
APP_CAMPAIGN or APP_CAMPAIGN_FOR_ENGAGEMENT as AdvertisingChannelSubType.
Corresponds to the JSON property selectiveOptimization
6102 6103 6104 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6102 def selective_optimization @selective_optimization end |
#serving_status ⇒ String
Output only. The ad serving status of the campaign.
Corresponds to the JSON property servingStatus
6107 6108 6109 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6107 def serving_status @serving_status end |
#shopping_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting
The setting for Shopping campaigns. Defines the universe of products that can
be advertised by the campaign, and how this campaign interacts with other
Shopping campaigns.
Corresponds to the JSON property shoppingSetting
6114 6115 6116 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6114 def shopping_setting @shopping_setting end |
#start_date ⇒ String
The date when campaign started in serving customer's timezone in YYYY-MM-DD
format.
Corresponds to the JSON property startDate
6120 6121 6122 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6120 def start_date @start_date end |
#status ⇒ String
The status of the campaign. When a new campaign is added, the status defaults
to ENABLED.
Corresponds to the JSON property status
6126 6127 6128 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6126 def status @status end |
#target_cpa ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpa
An automated bid strategy that sets bids to help get as many conversions as
possible at the target cost-per-acquisition (CPA) you set.
Corresponds to the JSON property targetCpa
6132 6133 6134 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6132 def target_cpa @target_cpa end |
#target_cpm ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetCpm
Target CPM (cost per thousand impressions) is an automated bidding strategy
that sets bids to optimize performance given the target CPM you set.
Corresponds to the JSON property targetCpm
6138 6139 6140 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6138 def target_cpm @target_cpm end |
#target_impression_share ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of
search ads are shown at the top of the first page (or other targeted location).
Corresponds to the JSON property targetImpressionShare
6144 6145 6146 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6144 def target_impression_share @target_impression_share end |
#target_roas ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging
a specific target return on ad spend (ROAS).
Corresponds to the JSON property targetRoas
6150 6151 6152 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6150 def target_roas @target_roas end |
#target_spend ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as
possible within your budget.
Corresponds to the JSON property targetSpend
6156 6157 6158 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6156 def target_spend @target_spend end |
#tracking_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignTrackingSetting
Campaign-level settings for tracking information.
Corresponds to the JSON property trackingSetting
6161 6162 6163 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6161 def tracking_setting @tracking_setting end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
6166 6167 6168 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6166 def tracking_url_template @tracking_url_template end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template, final_urls, or mobile_final_urls.
Corresponds to the JSON property urlCustomParameters
6172 6173 6174 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6172 def url_custom_parameters @url_custom_parameters end |
#url_expansion_opt_out ⇒ Boolean Also known as: url_expansion_opt_out?
Represents opting out of URL expansion to more targeted URLs. If opted out (
true), only the final URLs in the asset group or URLs specified in the
advertiser's Google Merchant Center or business data feeds are targeted. If
opted in (false), the entire domain will be targeted. This field can only be
set for Performance Max campaigns, where the default value is false.
Corresponds to the JSON property urlExpansionOptOut
6181 6182 6183 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6181 def url_expansion_opt_out @url_expansion_opt_out end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6189 6190 6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 6234 6235 6236 6237 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6189 def update!(**args) @accessible_bidding_strategy = args[:accessible_bidding_strategy] if args.key?(:accessible_bidding_strategy) @ad_serving_optimization_status = args[:ad_serving_optimization_status] if args.key?(:ad_serving_optimization_status) @advertising_channel_sub_type = args[:advertising_channel_sub_type] if args.key?(:advertising_channel_sub_type) @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @bidding_strategy_system_status = args[:bidding_strategy_system_status] if args.key?(:bidding_strategy_system_status) @bidding_strategy_type = args[:bidding_strategy_type] if args.key?(:bidding_strategy_type) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @create_time = args[:create_time] if args.key?(:create_time) @creation_time = args[:creation_time] if args.key?(:creation_time) @dynamic_search_ads_setting = args[:dynamic_search_ads_setting] if args.key?(:dynamic_search_ads_setting) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @end_date = args[:end_date] if args.key?(:end_date) @engine_id = args[:engine_id] if args.key?(:engine_id) @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types) @feed_types = args[:feed_types] if args.key?(:feed_types) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @frequency_caps = args[:frequency_caps] if args.key?(:frequency_caps) @geo_target_type_setting = args[:geo_target_type_setting] if args.key?(:geo_target_type_setting) @id = args[:id] if args.key?(:id) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @manual_cpa = args[:manual_cpa] if args.key?(:manual_cpa) @manual_cpc = args[:manual_cpc] if args.key?(:manual_cpc) @manual_cpm = args[:manual_cpm] if args.key?(:manual_cpm) @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value) @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions) @name = args[:name] if args.key?(:name) @network_settings = args[:network_settings] if args.key?(:network_settings) @optimization_goal_setting = args[:optimization_goal_setting] if args.key?(:optimization_goal_setting) @percent_cpc = args[:percent_cpc] if args.key?(:percent_cpc) @real_time_bidding_setting = args[:real_time_bidding_setting] if args.key?(:real_time_bidding_setting) @resource_name = args[:resource_name] if args.key?(:resource_name) @selective_optimization = args[:selective_optimization] if args.key?(:selective_optimization) @serving_status = args[:serving_status] if args.key?(:serving_status) @shopping_setting = args[:shopping_setting] if args.key?(:shopping_setting) @start_date = args[:start_date] if args.key?(:start_date) @status = args[:status] if args.key?(:status) @target_cpa = args[:target_cpa] if args.key?(:target_cpa) @target_cpm = args[:target_cpm] if args.key?(:target_cpm) @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share) @target_roas = args[:target_roas] if args.key?(:target_roas) @target_spend = args[:target_spend] if args.key?(:target_spend) @tracking_setting = args[:tracking_setting] if args.key?(:tracking_setting) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @url_expansion_opt_out = args[:url_expansion_opt_out] if args.key?(:url_expansion_opt_out) end |