Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

CampaignAssetSet is the linkage between a campaign and an asset set. Adding a CampaignAssetSet links an asset set with a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignAssetSet

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignAssetSet.



6306
6307
6308
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_setString

Immutable. The asset set which is linked to the campaign. Corresponds to the JSON property assetSet

Returns:

  • (String)


6287
6288
6289
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6287

def asset_set
  @asset_set
end

#campaignString

Immutable. The campaign to which this asset set is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


6292
6293
6294
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6292

def campaign
  @campaign
end

#resource_nameString

Immutable. The resource name of the campaign asset set. Asset set asset resource names have the form: customers/customer_id/campaignAssetSets/ campaign_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6299
6300
6301
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6299

def resource_name
  @resource_name
end

#statusString

Output only. The status of the campaign asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


6304
6305
6306
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6304

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6311
6312
6313
6314
6315
6316
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6311

def update!(**args)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end