Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignBudget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignBudget

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignBudget.



6377
6378
6379
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_microsFixnum

The average daily amount to be spent by the campaign. This field is used when the CampaignBudget period is set to DAILY, which is the default. Amount is specified in micros in the account's local currency. One million micros is equivalent to one currency unit. The effective monthly spend is capped at 30.4 times this daily amount. This field is mutually exclusive with ' total_amount_micros'. Only one of 'amount_micros' or 'total_amount_micros' should be set. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


6356
6357
6358
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6356

def amount_micros
  @amount_micros
end

#delivery_methodString

The delivery method that determines the rate at which the campaign budget is spent. Defaults to STANDARD if unspecified in a create operation. Corresponds to the JSON property deliveryMethod

Returns:

  • (String)


6362
6363
6364
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6362

def delivery_method
  @delivery_method
end

#periodString

Immutable. Period over which to spend the budget. Defaults to DAILY if not specified. Corresponds to the JSON property period

Returns:

  • (String)


6368
6369
6370
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6368

def period
  @period
end

#resource_nameString

Immutable. The resource name of the campaign budget. Campaign budget resource names have the form: customers/customer_id/campaignBudgets/ campaign_budget_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6375
6376
6377
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6375

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6382
6383
6384
6385
6386
6387
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6382

def update!(**args)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @delivery_method = args[:delivery_method] if args.key?(:delivery_method)
  @period = args[:period] if args.key?(:period)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end