Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A campaign criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignCriterion

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignCriterion.



6488
6489
6490
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



6397
6398
6399
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6397

def age_range
  @age_range
end

#bid_modifierFloat

The modifier for the bids when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Use 0 to opt out of a Device type. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


6404
6405
6406
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6404

def bid_modifier
  @bid_modifier
end

#criterion_idFixnum

Output only. The ID of the criterion. This field is ignored during mutate. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


6409
6410
6411
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6409

def criterion_id
  @criterion_id
end

#deviceGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonDeviceInfo

A device criterion. Corresponds to the JSON property device



6414
6415
6416
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6414

def device
  @device
end

#display_nameString

Output only. The display name of the criterion. This field is ignored for mutates. Corresponds to the JSON property displayName

Returns:

  • (String)


6420
6421
6422
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6420

def display_name
  @display_name
end

#genderGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



6425
6426
6427
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6425

def gender
  @gender
end

#keywordGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keyword



6430
6431
6432
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6430

def keyword
  @keyword
end

#languageGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLanguageInfo

A language criterion. Corresponds to the JSON property language



6435
6436
6437
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6435

def language
  @language
end

#last_modified_timeString

Output only. The datetime when this campaign criterion was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


6442
6443
6444
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6442

def last_modified_time
  @last_modified_time
end

#locationGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationInfo

A location criterion. Corresponds to the JSON property location



6447
6448
6449
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6447

def location
  @location
end

#location_groupGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonLocationGroupInfo

A radius around a list of locations specified through a feed. Corresponds to the JSON property locationGroup



6452
6453
6454
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6452

def location_group
  @location_group
end

#negativeBoolean Also known as: negative?

Immutable. Whether to target (false) or exclude (true) the criterion. Corresponds to the JSON property negative

Returns:

  • (Boolean)


6457
6458
6459
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6457

def negative
  @negative
end

#resource_nameString

Immutable. The resource name of the campaign criterion. Campaign criterion resource names have the form: customers/customer_id/campaignCriteria/ campaign_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6465
6466
6467
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6465

def resource_name
  @resource_name
end

#statusString

The status of the criterion. Corresponds to the JSON property status

Returns:

  • (String)


6470
6471
6472
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6470

def status
  @status
end

#typeString

Output only. The type of the criterion. Corresponds to the JSON property type

Returns:

  • (String)


6475
6476
6477
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6475

def type
  @type
end

#user_listGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



6481
6482
6483
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6481

def user_list
  @user_list
end

#webpageGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonWebpageInfo

Represents a criterion for targeting webpages of an advertiser's website. Corresponds to the JSON property webpage



6486
6487
6488
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6486

def webpage
  @webpage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6493
6494
6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6493

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @device = args[:device] if args.key?(:device)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gender = args[:gender] if args.key?(:gender)
  @keyword = args[:keyword] if args.key?(:keyword)
  @language = args[:language] if args.key?(:language)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @location = args[:location] if args.key?(:location)
  @location_group = args[:location_group] if args.key?(:location_group)
  @negative = args[:negative] if args.key?(:negative)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @user_list = args[:user_list] if args.key?(:user_list)
  @webpage = args[:webpage] if args.key?(:webpage)
end