Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
The network settings for the campaign.
Instance Attribute Summary collapse
-
#target_content_network ⇒ Boolean
(also: #target_content_network?)
Whether ads will be served on specified placements in the Google Display Network.
-
#target_google_search ⇒ Boolean
(also: #target_google_search?)
Whether ads will be served with google.com search results.
-
#target_partner_search_network ⇒ Boolean
(also: #target_partner_search_network?)
Whether ads will be served on the partner network.
-
#target_search_network ⇒ Boolean
(also: #target_search_network?)
Whether ads will be served on sites in the Google Search Partners Network ( requires
target_google_searchto also betrue).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings
Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignNetworkSettings.
3804 3805 3806 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_content_network ⇒ Boolean Also known as: target_content_network?
Whether ads will be served on specified placements in the Google Display
Network. Placements are specified using the Placement criterion.
Corresponds to the JSON property targetContentNetwork
3778 3779 3780 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3778 def target_content_network @target_content_network end |
#target_google_search ⇒ Boolean Also known as: target_google_search?
Whether ads will be served with google.com search results.
Corresponds to the JSON property targetGoogleSearch
3784 3785 3786 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3784 def target_google_search @target_google_search end |
#target_partner_search_network ⇒ Boolean Also known as: target_partner_search_network?
Whether ads will be served on the partner network. This is available only to
some select partner accounts. Unless you have been instructed to use this
field, it likely does not apply to your account. This does not control whether
ads will be served on Google Search Partners Network; use
target_search_network for that instead.
Corresponds to the JSON property targetPartnerSearchNetwork
3794 3795 3796 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3794 def target_partner_search_network @target_partner_search_network end |
#target_search_network ⇒ Boolean Also known as: target_search_network?
Whether ads will be served on sites in the Google Search Partners Network (
requires target_google_search to also be true).
Corresponds to the JSON property targetSearchNetwork
3801 3802 3803 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3801 def target_search_network @target_search_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3809 3810 3811 3812 3813 3814 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3809 def update!(**args) @target_content_network = args[:target_content_network] if args.key?(:target_content_network) @target_google_search = args[:target_google_search] if args.key?(:target_google_search) @target_partner_search_network = args[:target_partner_search_network] if args.key?(:target_partner_search_network) @target_search_network = args[:target_search_network] if args.key?(:target_search_network) end |