Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

The setting for Shopping campaigns. Defines the universe of products that can be advertised by the campaign, and how this campaign interacts with other Shopping campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting

Returns a new instance of GoogleAdsSearchads360V0ResourcesCampaignShoppingSetting.



3847
3848
3849
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_priorityFixnum

Priority of the campaign. Campaigns with numerically higher priorities take precedence over those with lower priorities. This field is required for Shopping campaigns, with values between 0 and 2, inclusive. This field is optional for Smart Shopping campaigns, but must be equal to 3 if set. Corresponds to the JSON property campaignPriority

Returns:

  • (Fixnum)


3812
3813
3814
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3812

def campaign_priority
  @campaign_priority
end

#enable_localBoolean Also known as: enable_local?

Whether to include local products. Corresponds to the JSON property enableLocal

Returns:

  • (Boolean)


3817
3818
3819
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3817

def enable_local
  @enable_local
end

#feed_labelString

Feed label of products to include in the campaign. Valid feed labels may contain a maximum of 20 characters including uppercase letters, numbers, hyphens, and underscores. If you previously used the deprecated sales_country in the two-letter country code (XX) format, the feed_label field should be used instead. For more information see the feed label support article. Corresponds to the JSON property feedLabel

Returns:

  • (String)


3828
3829
3830
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3828

def feed_label
  @feed_label
end

#merchant_idFixnum

Immutable. ID of the Merchant Center account. This field is required for create operations. This field is immutable for Shopping campaigns. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


3834
3835
3836
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3834

def merchant_id
  @merchant_id
end

#sales_countryString

Sales country of products to include in the campaign. Corresponds to the JSON property salesCountry

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3839

def sales_country
  @sales_country
end

#use_vehicle_inventoryBoolean Also known as: use_vehicle_inventory?

Immutable. Whether to target Vehicle Listing inventory. Corresponds to the JSON property useVehicleInventory

Returns:

  • (Boolean)


3844
3845
3846
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3844

def use_vehicle_inventory
  @use_vehicle_inventory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3852

def update!(**args)
  @campaign_priority = args[:campaign_priority] if args.key?(:campaign_priority)
  @enable_local = args[:enable_local] if args.key?(:enable_local)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @sales_country = args[:sales_country] if args.key?(:sales_country)
  @use_vehicle_inventory = args[:use_vehicle_inventory] if args.key?(:use_vehicle_inventory)
end