Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A conversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversion

Returns a new instance of GoogleAdsSearchads360V0ResourcesConversion.



6763
6764
6765
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_idFixnum

Output only. Ad ID. A value of 0 indicates that the ad is unattributed. Corresponds to the JSON property adId

Returns:

  • (Fixnum)


6625
6626
6627
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6625

def ad_id
  @ad_id
end

#advertiser_conversion_idString

Output only. For offline conversions, this is an ID provided by advertisers. If an advertiser doesn't specify such an ID, Search Ads 360 generates one. For online conversions, this is equal to the id column or the floodlight_order_id column depending on the advertiser's Floodlight instructions. Corresponds to the JSON property advertiserConversionId

Returns:

  • (String)


6633
6634
6635
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6633

def advertiser_conversion_id
  @advertiser_conversion_id
end

#asset_field_typeString

Output only. Asset field type of the conversion event. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


6638
6639
6640
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6638

def asset_field_type
  @asset_field_type
end

#asset_idFixnum

Output only. ID of the asset which was interacted with during the conversion event. Corresponds to the JSON property assetId

Returns:

  • (Fixnum)


6644
6645
6646
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6644

def asset_id
  @asset_id
end

#attribution_typeString

Output only. What the conversion is attributed to: Visit or Keyword+Ad. Corresponds to the JSON property attributionType

Returns:

  • (String)


6649
6650
6651
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6649

def attribution_type
  @attribution_type
end

#click_idString

Output only. A unique string, for the visit that the conversion is attributed to, that is passed to the landing page as the click id URL parameter. Corresponds to the JSON property clickId

Returns:

  • (String)


6655
6656
6657
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6655

def click_id
  @click_id
end

#conversion_date_timeString

Output only. The timestamp of the conversion event. Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


6660
6661
6662
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6660

def conversion_date_time
  @conversion_date_time
end

#conversion_last_modified_date_timeString

Output only. The timestamp of the last time the conversion was modified. Corresponds to the JSON property conversionLastModifiedDateTime

Returns:

  • (String)


6665
6666
6667
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6665

def conversion_last_modified_date_time
  @conversion_last_modified_date_time
end

#conversion_quantityFixnum

Output only. The quantity of items recorded by the conversion, as determined by the qty url parameter. The advertiser is responsible for dynamically populating the parameter (such as number of items sold in the conversion), otherwise it defaults to 1. Corresponds to the JSON property conversionQuantity

Returns:

  • (Fixnum)


6673
6674
6675
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6673

def conversion_quantity
  @conversion_quantity
end

#conversion_revenue_microsFixnum

Output only. The adjusted revenue in micros for the conversion event. This will always be in the currency of the serving account. Corresponds to the JSON property conversionRevenueMicros

Returns:

  • (Fixnum)


6679
6680
6681
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6679

def conversion_revenue_micros
  @conversion_revenue_micros
end

#conversion_visit_date_timeString

Output only. The timestamp of the visit that the conversion is attributed to. Corresponds to the JSON property conversionVisitDateTime

Returns:

  • (String)


6684
6685
6686
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6684

def conversion_visit_date_time
  @conversion_visit_date_time
end

#criterion_idFixnum

Output only. Search Ads 360 criterion ID. A value of 0 indicates that the criterion is unattributed. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


6690
6691
6692
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6690

def criterion_id
  @criterion_id
end

#floodlight_order_idString

Output only. The Floodlight order ID provided by the advertiser for the conversion. Corresponds to the JSON property floodlightOrderId

Returns:

  • (String)


6696
6697
6698
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6696

def floodlight_order_id
  @floodlight_order_id
end

#floodlight_original_revenueFixnum

Output only. The original, unchanged revenue associated with the Floodlight event (in the currency of the current report), before Floodlight currency instruction modifications. Corresponds to the JSON property floodlightOriginalRevenue

Returns:

  • (Fixnum)


6703
6704
6705
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6703

def floodlight_original_revenue
  @floodlight_original_revenue
end

#idFixnum

Output only. The ID of the conversion Corresponds to the JSON property id

Returns:

  • (Fixnum)


6708
6709
6710
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6708

def id
  @id
end

#merchant_idFixnum

Output only. The Search Ads 360 inventory account ID containing the product that was clicked on. Search Ads 360 generates this ID when you link an inventory account in Search Ads 360. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


6715
6716
6717
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6715

def merchant_id
  @merchant_id
end

#product_channelString

Output only. The sales channel of the product that was clicked on: Online or Local. Corresponds to the JSON property productChannel

Returns:

  • (String)


6721
6722
6723
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6721

def product_channel
  @product_channel
end

#product_country_codeString

Output only. The country (ISO-3166-format) registered for the inventory feed that contains the product clicked on. Corresponds to the JSON property productCountryCode

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6727

def product_country_code
  @product_country_code
end

#product_idString

Output only. The ID of the product clicked on. Corresponds to the JSON property productId

Returns:

  • (String)


6732
6733
6734
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6732

def product_id
  @product_id
end

#product_language_codeString

Output only. The language (ISO-639-1) that has been set for the Merchant Center feed containing data about the product. Corresponds to the JSON property productLanguageCode

Returns:

  • (String)


6738
6739
6740
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6738

def product_language_code
  @product_language_code
end

#product_store_idString

Output only. The store in the Local Inventory Ad that was clicked on. This should match the store IDs used in your local products feed. Corresponds to the JSON property productStoreId

Returns:

  • (String)


6744
6745
6746
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6744

def product_store_id
  @product_store_id
end

#resource_nameString

Output only. The resource name of the conversion. Conversion resource names have the form: customers/customer_id/conversions/ad_group_id~ criterion_id~ds_conversion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6751
6752
6753
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6751

def resource_name
  @resource_name
end

#statusString

Output only. The status of the conversion, either ENABLED or REMOVED.. Corresponds to the JSON property status

Returns:

  • (String)


6756
6757
6758
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6756

def status
  @status
end

#visit_idFixnum

Output only. The Search Ads 360 visit ID that the conversion is attributed to. Corresponds to the JSON property visitId

Returns:

  • (Fixnum)


6761
6762
6763
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6761

def visit_id
  @visit_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
6788
6789
6790
6791
6792
6793
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6768

def update!(**args)
  @ad_id = args[:ad_id] if args.key?(:ad_id)
  @advertiser_conversion_id = args[:advertiser_conversion_id] if args.key?(:advertiser_conversion_id)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
  @asset_id = args[:asset_id] if args.key?(:asset_id)
  @attribution_type = args[:attribution_type] if args.key?(:attribution_type)
  @click_id = args[:click_id] if args.key?(:click_id)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @conversion_last_modified_date_time = args[:conversion_last_modified_date_time] if args.key?(:conversion_last_modified_date_time)
  @conversion_quantity = args[:conversion_quantity] if args.key?(:conversion_quantity)
  @conversion_revenue_micros = args[:conversion_revenue_micros] if args.key?(:conversion_revenue_micros)
  @conversion_visit_date_time = args[:conversion_visit_date_time] if args.key?(:conversion_visit_date_time)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @floodlight_order_id = args[:floodlight_order_id] if args.key?(:floodlight_order_id)
  @floodlight_original_revenue = args[:floodlight_original_revenue] if args.key?(:floodlight_original_revenue)
  @id = args[:id] if args.key?(:id)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @product_channel = args[:product_channel] if args.key?(:product_channel)
  @product_country_code = args[:product_country_code] if args.key?(:product_country_code)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_language_code = args[:product_language_code] if args.key?(:product_language_code)
  @product_store_id = args[:product_store_id] if args.key?(:product_store_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @visit_id = args[:visit_id] if args.key?(:visit_id)
end