Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A conversion action.
Instance Attribute Summary collapse
-
#app_id ⇒ String
App ID for an app conversion action.
-
#attribution_model_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionAttributionModelSettings
Settings related to this conversion action's attribution model.
-
#category ⇒ String
The category of conversions reported for this conversion action.
-
#click_through_lookback_window_days ⇒ Fixnum
The maximum number of days that may elapse between an interaction (for example, a click) and a conversion event.
-
#creation_time ⇒ String
Output only.
-
#floodlight_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionFloodlightSettings
Settings related to a Floodlight conversion action.
-
#id ⇒ Fixnum
Output only.
-
#include_in_client_account_conversions_metric ⇒ Boolean
(also: #include_in_client_account_conversions_metric?)
Whether this conversion action should be included in the " client_account_conversions" metric.
-
#include_in_conversions_metric ⇒ Boolean
(also: #include_in_conversions_metric?)
Output only.
-
#name ⇒ String
The name of the conversion action.
-
#owner_customer ⇒ String
Output only.
-
#primary_for_goal ⇒ Boolean
(also: #primary_for_goal?)
If a conversion action's primary_for_goal bit is false, the conversion action is non-biddable for all campaigns regardless of their customer conversion goal or campaign conversion goal.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of this conversion action for conversion event accrual.
-
#type ⇒ String
Immutable.
-
#value_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
Settings related to the value for conversion events associated with this conversion action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionAction
constructor
A new instance of GoogleAdsSearchads360V0ResourcesConversionAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionAction
Returns a new instance of GoogleAdsSearchads360V0ResourcesConversionAction.
6899 6900 6901 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
App ID for an app conversion action.
Corresponds to the JSON property appId
6803 6804 6805 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6803 def app_id @app_id end |
#attribution_model_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionAttributionModelSettings
Settings related to this conversion action's attribution model.
Corresponds to the JSON property attributionModelSettings
6808 6809 6810 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6808 def attribution_model_settings @attribution_model_settings end |
#category ⇒ String
The category of conversions reported for this conversion action.
Corresponds to the JSON property category
6813 6814 6815 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6813 def category @category end |
#click_through_lookback_window_days ⇒ Fixnum
The maximum number of days that may elapse between an interaction (for example,
a click) and a conversion event.
Corresponds to the JSON property clickThroughLookbackWindowDays
6819 6820 6821 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6819 def click_through_lookback_window_days @click_through_lookback_window_days end |
#creation_time ⇒ String
Output only. Timestamp of the Floodlight activity's creation, formatted in ISO
8601.
Corresponds to the JSON property creationTime
6825 6826 6827 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6825 def creation_time @creation_time end |
#floodlight_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionFloodlightSettings
Settings related to a Floodlight conversion action.
Corresponds to the JSON property floodlightSettings
6830 6831 6832 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6830 def floodlight_settings @floodlight_settings end |
#id ⇒ Fixnum
Output only. The ID of the conversion action.
Corresponds to the JSON property id
6835 6836 6837 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6835 def id @id end |
#include_in_client_account_conversions_metric ⇒ Boolean Also known as: include_in_client_account_conversions_metric?
Whether this conversion action should be included in the "
client_account_conversions" metric.
Corresponds to the JSON property includeInClientAccountConversionsMetric
6841 6842 6843 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6841 def include_in_client_account_conversions_metric @include_in_client_account_conversions_metric end |
#include_in_conversions_metric ⇒ Boolean Also known as: include_in_conversions_metric?
Output only. Whether this conversion action should be included in the "
conversions" metric.
Corresponds to the JSON property includeInConversionsMetric
6848 6849 6850 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6848 def include_in_conversions_metric @include_in_conversions_metric end |
#name ⇒ String
The name of the conversion action. This field is required and should not be
empty when creating new conversion actions.
Corresponds to the JSON property name
6855 6856 6857 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6855 def name @name end |
#owner_customer ⇒ String
Output only. The resource name of the conversion action owner customer, or
null if this is a system-defined conversion action.
Corresponds to the JSON property ownerCustomer
6861 6862 6863 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6861 def owner_customer @owner_customer end |
#primary_for_goal ⇒ Boolean Also known as: primary_for_goal?
If a conversion action's primary_for_goal bit is false, the conversion action
is non-biddable for all campaigns regardless of their customer conversion goal
or campaign conversion goal. However, custom conversion goals do not respect
primary_for_goal, so if a campaign has a custom conversion goal configured
with a primary_for_goal = false conversion action, that conversion action is
still biddable. By default, primary_for_goal will be true if not set. In V9,
primary_for_goal can only be set to false after creation through an 'update'
operation because it's not declared as optional.
Corresponds to the JSON property primaryForGoal
6873 6874 6875 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6873 def primary_for_goal @primary_for_goal end |
#resource_name ⇒ String
Immutable. The resource name of the conversion action. Conversion action
resource names have the form: customers/customer_id/conversionActions/
conversion_action_id`
Corresponds to the JSON propertyresourceName`
6881 6882 6883 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6881 def resource_name @resource_name end |
#status ⇒ String
The status of this conversion action for conversion event accrual.
Corresponds to the JSON property status
6886 6887 6888 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6886 def status @status end |
#type ⇒ String
Immutable. The type of this conversion action.
Corresponds to the JSON property type
6891 6892 6893 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6891 def type @type end |
#value_settings ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
Settings related to the value for conversion events associated with this
conversion action.
Corresponds to the JSON property valueSettings
6897 6898 6899 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6897 def value_settings @value_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6904 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @attribution_model_settings = args[:attribution_model_settings] if args.key?(:attribution_model_settings) @category = args[:category] if args.key?(:category) @click_through_lookback_window_days = args[:click_through_lookback_window_days] if args.key?(:click_through_lookback_window_days) @creation_time = args[:creation_time] if args.key?(:creation_time) @floodlight_settings = args[:floodlight_settings] if args.key?(:floodlight_settings) @id = args[:id] if args.key?(:id) @include_in_client_account_conversions_metric = args[:include_in_client_account_conversions_metric] if args.key?(:include_in_client_account_conversions_metric) @include_in_conversions_metric = args[:include_in_conversions_metric] if args.key?(:include_in_conversions_metric) @name = args[:name] if args.key?(:name) @owner_customer = args[:owner_customer] if args.key?(:owner_customer) @primary_for_goal = args[:primary_for_goal] if args.key?(:primary_for_goal) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) @value_settings = args[:value_settings] if args.key?(:value_settings) end |