Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Settings related to the value for conversion events associated with this conversion action.
Instance Attribute Summary collapse
-
#always_use_default_value ⇒ Boolean
(also: #always_use_default_value?)
Controls whether the default value and default currency code are used in place of the value and currency code specified in conversion events for this conversion action.
-
#default_currency_code ⇒ String
The currency code to use when conversion events for this conversion action are sent with an invalid or missing currency code, or when this conversion action is configured to always use the default value.
-
#default_value ⇒ Float
The value to use when conversion events for this conversion action are sent with an invalid, disallowed or missing value, or when this conversion action is configured to always use the default value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
constructor
A new instance of GoogleAdsSearchads360V0ResourcesConversionActionValueSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionActionValueSettings
Returns a new instance of GoogleAdsSearchads360V0ResourcesConversionActionValueSettings.
3968 3969 3970 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#always_use_default_value ⇒ Boolean Also known as: always_use_default_value?
Controls whether the default value and default currency code are used in place
of the value and currency code specified in conversion events for this
conversion action.
Corresponds to the JSON property alwaysUseDefaultValue
3951 3952 3953 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3951 def always_use_default_value @always_use_default_value end |
#default_currency_code ⇒ String
The currency code to use when conversion events for this conversion action are
sent with an invalid or missing currency code, or when this conversion action
is configured to always use the default value.
Corresponds to the JSON property defaultCurrencyCode
3959 3960 3961 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3959 def default_currency_code @default_currency_code end |
#default_value ⇒ Float
The value to use when conversion events for this conversion action are sent
with an invalid, disallowed or missing value, or when this conversion action
is configured to always use the default value.
Corresponds to the JSON property defaultValue
3966 3967 3968 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3966 def default_value @default_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3973 3974 3975 3976 3977 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 3973 def update!(**args) @always_use_default_value = args[:always_use_default_value] if args.key?(:always_use_default_value) @default_currency_code = args[:default_currency_code] if args.key?(:default_currency_code) @default_value = args[:default_value] if args.key?(:default_value) end |