Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesConversionCustomVariable

Returns a new instance of GoogleAdsSearchads360V0ResourcesConversionCustomVariable.



6988
6989
6990
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

Output only. Cardinality of the conversion custom variable. Corresponds to the JSON property cardinality

Returns:

  • (String)


6933
6934
6935
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6933

def cardinality
  @cardinality
end

#custom_column_idsArray<Fixnum>

Output only. The IDs of custom columns that use this conversion custom variable. Corresponds to the JSON property customColumnIds

Returns:

  • (Array<Fixnum>)


6939
6940
6941
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6939

def custom_column_ids
  @custom_column_ids
end

#familyString

Output only. Family of the conversion custom variable. Corresponds to the JSON property family

Returns:

  • (String)


6944
6945
6946
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6944

def family
  @family
end

#floodlight_conversion_custom_variable_infoGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo

Information for Search Ads 360 Floodlight Conversion Custom Variables. Corresponds to the JSON property floodlightConversionCustomVariableInfo



6949
6950
6951
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6949

def floodlight_conversion_custom_variable_info
  @floodlight_conversion_custom_variable_info
end

#idFixnum

Output only. The ID of the conversion custom variable. Corresponds to the JSON property id

Returns:

  • (Fixnum)


6954
6955
6956
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6954

def id
  @id
end

#nameString

Required. The name of the conversion custom variable. Name should be unique. The maximum length of name is 100 characters. There should not be any extra spaces before and after. Corresponds to the JSON property name

Returns:

  • (String)


6961
6962
6963
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6961

def name
  @name
end

#owner_customerString

Output only. The resource name of the customer that owns the conversion custom variable. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


6967
6968
6969
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6967

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion custom variable. Conversion custom variable resource names have the form: customers/customer_id/ conversionCustomVariables/conversion_custom_variable_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


6974
6975
6976
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6974

def resource_name
  @resource_name
end

#statusString

The status of the conversion custom variable for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


6979
6980
6981
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6979

def status
  @status
end

#tagString

Required. Immutable. The tag of the conversion custom variable. Tag should be unique and consist of a "u" character directly followed with a number less than ormequal to 100. For example: "u4". Corresponds to the JSON property tag

Returns:

  • (String)


6986
6987
6988
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6986

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
# File 'lib/google/apis/searchads360_v0/classes.rb', line 6993

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @custom_column_ids = args[:custom_column_ids] if args.key?(:custom_column_ids)
  @family = args[:family] if args.key?(:family)
  @floodlight_conversion_custom_variable_info = args[:floodlight_conversion_custom_variable_info] if args.key?(:floodlight_conversion_custom_variable_info)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end