Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A customer.
Instance Attribute Summary collapse
-
#account_level ⇒ String
Output only.
-
#account_status ⇒ String
Output only.
-
#account_type ⇒ String
Output only.
-
#associate_manager_descriptive_name ⇒ String
Output only.
-
#associate_manager_id ⇒ Fixnum
Output only.
-
#auto_tagging_enabled ⇒ Boolean
(also: #auto_tagging_enabled?)
Whether auto-tagging is enabled for the customer.
-
#conversion_tracking_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
A collection of customer-wide settings related to Search Ads 360 Conversion Tracking.
-
#creation_time ⇒ String
Output only.
-
#currency_code ⇒ String
Immutable.
-
#descriptive_name ⇒ String
Optional, non-unique descriptive name of the customer.
-
#double_click_campaign_manager_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
DoubleClick Campaign Manager (DCM) setting for a manager customer.
-
#engine_id ⇒ String
Output only.
-
#final_url_suffix ⇒ String
The URL template for appending params to the final URL.
-
#id ⇒ Fixnum
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#manager ⇒ Boolean
(also: #manager?)
Output only.
-
#manager_descriptive_name ⇒ String
Output only.
-
#manager_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#sub_manager_descriptive_name ⇒ String
Output only.
-
#sub_manager_id ⇒ Fixnum
Output only.
-
#time_zone ⇒ String
Immutable.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL out of parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomer
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCustomer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomer
Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomer.
7299 7300 7301 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_level ⇒ String
Output only. The account level of the customer: Manager, Sub-manager,
Associate manager, Service account.
Corresponds to the JSON property accountLevel
7171 7172 7173 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7171 def account_level @account_level end |
#account_status ⇒ String
Output only. Account status, for example, Enabled, Paused, Removed, etc.
Corresponds to the JSON property accountStatus
7176 7177 7178 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7176 def account_status @account_status end |
#account_type ⇒ String
Output only. Engine account type, for example, Google Ads, Microsoft
Advertising, Yahoo Japan, Baidu, Facebook, Engine Track, etc.
Corresponds to the JSON property accountType
7182 7183 7184 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7182 def account_type @account_type end |
#associate_manager_descriptive_name ⇒ String
Output only. The descriptive name of the associate manager.
Corresponds to the JSON property associateManagerDescriptiveName
7187 7188 7189 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7187 def associate_manager_descriptive_name @associate_manager_descriptive_name end |
#associate_manager_id ⇒ Fixnum
Output only. The customer ID of the associate manager. A 0 value indicates
that the customer has no SA360 associate manager.
Corresponds to the JSON property associateManagerId
7193 7194 7195 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7193 def associate_manager_id @associate_manager_id end |
#auto_tagging_enabled ⇒ Boolean Also known as: auto_tagging_enabled?
Whether auto-tagging is enabled for the customer.
Corresponds to the JSON property autoTaggingEnabled
7198 7199 7200 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7198 def auto_tagging_enabled @auto_tagging_enabled end |
#conversion_tracking_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionTrackingSetting
A collection of customer-wide settings related to Search Ads 360 Conversion
Tracking.
Corresponds to the JSON property conversionTrackingSetting
7205 7206 7207 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7205 def conversion_tracking_setting @conversion_tracking_setting end |
#creation_time ⇒ String
Output only. The timestamp when this customer was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
7211 7212 7213 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7211 def creation_time @creation_time end |
#currency_code ⇒ String
Immutable. The currency in which the account operates. A subset of the
currency codes from the ISO 4217 standard is supported.
Corresponds to the JSON property currencyCode
7217 7218 7219 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7217 def currency_code @currency_code end |
#descriptive_name ⇒ String
Optional, non-unique descriptive name of the customer.
Corresponds to the JSON property descriptiveName
7222 7223 7224 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7222 def descriptive_name @descriptive_name end |
#double_click_campaign_manager_setting ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDoubleClickCampaignManagerSetting
DoubleClick Campaign Manager (DCM) setting for a manager customer.
Corresponds to the JSON property doubleClickCampaignManagerSetting
7227 7228 7229 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7227 def double_click_campaign_manager_setting @double_click_campaign_manager_setting end |
#engine_id ⇒ String
Output only. ID of the account in the external engine account.
Corresponds to the JSON property engineId
7232 7233 7234 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7232 def engine_id @engine_id end |
#final_url_suffix ⇒ String
The URL template for appending params to the final URL.
Corresponds to the JSON property finalUrlSuffix
7237 7238 7239 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7237 def final_url_suffix @final_url_suffix end |
#id ⇒ Fixnum
Output only. The ID of the customer.
Corresponds to the JSON property id
7242 7243 7244 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7242 def id @id end |
#last_modified_time ⇒ String
Output only. The datetime when this customer was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
7248 7249 7250 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7248 def last_modified_time @last_modified_time end |
#manager ⇒ Boolean Also known as: manager?
Output only. Whether the customer is a manager.
Corresponds to the JSON property manager
7253 7254 7255 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7253 def manager @manager end |
#manager_descriptive_name ⇒ String
Output only. The descriptive name of the manager.
Corresponds to the JSON property managerDescriptiveName
7259 7260 7261 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7259 def manager_descriptive_name @manager_descriptive_name end |
#manager_id ⇒ Fixnum
Output only. The customer ID of the manager. A 0 value indicates that the
customer has no SA360 manager.
Corresponds to the JSON property managerId
7265 7266 7267 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7265 def manager_id @manager_id end |
#resource_name ⇒ String
Immutable. The resource name of the customer. Customer resource names have the
form: customers/customer_id`
Corresponds to the JSON propertyresourceName`
7271 7272 7273 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7271 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the customer.
Corresponds to the JSON property status
7276 7277 7278 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7276 def status @status end |
#sub_manager_descriptive_name ⇒ String
Output only. The descriptive name of the sub manager.
Corresponds to the JSON property subManagerDescriptiveName
7281 7282 7283 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7281 def sub_manager_descriptive_name @sub_manager_descriptive_name end |
#sub_manager_id ⇒ Fixnum
Output only. The customer ID of the sub manager. A 0 value indicates that the
customer has no sub SA360 manager.
Corresponds to the JSON property subManagerId
7287 7288 7289 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7287 def sub_manager_id @sub_manager_id end |
#time_zone ⇒ String
Immutable. The local timezone ID of the customer.
Corresponds to the JSON property timeZone
7292 7293 7294 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7292 def time_zone @time_zone end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL out of parameters.
Corresponds to the JSON property trackingUrlTemplate
7297 7298 7299 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7297 def tracking_url_template @tracking_url_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 7316 7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 7328 7329 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7304 def update!(**args) @account_level = args[:account_level] if args.key?(:account_level) @account_status = args[:account_status] if args.key?(:account_status) @account_type = args[:account_type] if args.key?(:account_type) @associate_manager_descriptive_name = args[:associate_manager_descriptive_name] if args.key?(:associate_manager_descriptive_name) @associate_manager_id = args[:associate_manager_id] if args.key?(:associate_manager_id) @auto_tagging_enabled = args[:auto_tagging_enabled] if args.key?(:auto_tagging_enabled) @conversion_tracking_setting = args[:conversion_tracking_setting] if args.key?(:conversion_tracking_setting) @creation_time = args[:creation_time] if args.key?(:creation_time) @currency_code = args[:currency_code] if args.key?(:currency_code) @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name) @double_click_campaign_manager_setting = args[:double_click_campaign_manager_setting] if args.key?(:double_click_campaign_manager_setting) @engine_id = args[:engine_id] if args.key?(:engine_id) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @id = args[:id] if args.key?(:id) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @manager = args[:manager] if args.key?(:manager) @manager_descriptive_name = args[:manager_descriptive_name] if args.key?(:manager_descriptive_name) @manager_id = args[:manager_id] if args.key?(:manager_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @sub_manager_descriptive_name = args[:sub_manager_descriptive_name] if args.key?(:sub_manager_descriptive_name) @sub_manager_id = args[:sub_manager_id] if args.key?(:sub_manager_id) @time_zone = args[:time_zone] if args.key?(:time_zone) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) end |