Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A link between the given customer and a client customer. CustomerClients only exist for manager customers. All direct and indirect client customers are included, as well as the manager itself.
Instance Attribute Summary collapse
-
#applied_labels ⇒ Array<String>
Output only.
-
#client_customer ⇒ String
Output only.
-
#currency_code ⇒ String
Output only.
-
#descriptive_name ⇒ String
Output only.
-
#hidden ⇒ Boolean
(also: #hidden?)
Output only.
-
#id ⇒ Fixnum
Output only.
-
#level ⇒ Fixnum
Output only.
-
#manager ⇒ Boolean
(also: #manager?)
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#test_account ⇒ Boolean
(also: #test_account?)
Output only.
-
#time_zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerClient
constructor
A new instance of GoogleAdsSearchads360V0ResourcesCustomerClient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerClient
Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomerClient.
7563 7564 7565 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_labels ⇒ Array<String>
Output only. The resource names of the labels owned by the requesting customer
that are applied to the client customer. Label resource names have the form:
customers/customer_id/labels/label_id`
Corresponds to the JSON propertyappliedLabels`
7497 7498 7499 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7497 def applied_labels @applied_labels end |
#client_customer ⇒ String
Output only. The resource name of the client-customer which is linked to the
given customer. Read only.
Corresponds to the JSON property clientCustomer
7503 7504 7505 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7503 def client_customer @client_customer end |
#currency_code ⇒ String
Output only. Currency code (for example, 'USD', 'EUR') for the client. Read
only.
Corresponds to the JSON property currencyCode
7509 7510 7511 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7509 def currency_code @currency_code end |
#descriptive_name ⇒ String
Output only. Descriptive name for the client. Read only.
Corresponds to the JSON property descriptiveName
7514 7515 7516 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7514 def descriptive_name @descriptive_name end |
#hidden ⇒ Boolean Also known as:
Output only. Specifies whether this is a hidden account. Read only.
Corresponds to the JSON property hidden
7519 7520 7521 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7519 def hidden @hidden end |
#id ⇒ Fixnum
Output only. The ID of the client customer. Read only.
Corresponds to the JSON property id
7525 7526 7527 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7525 def id @id end |
#level ⇒ Fixnum
Output only. Distance between given customer and client. For self link, the
level value will be 0. Read only.
Corresponds to the JSON property level
7531 7532 7533 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7531 def level @level end |
#manager ⇒ Boolean Also known as: manager?
Output only. Identifies if the client is a manager. Read only.
Corresponds to the JSON property manager
7536 7537 7538 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7536 def manager @manager end |
#resource_name ⇒ String
Output only. The resource name of the customer client. CustomerClient resource
names have the form: customers/customer_id/customerClients/
client_customer_id`
Corresponds to the JSON propertyresourceName`
7544 7545 7546 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7544 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the client customer. Read only.
Corresponds to the JSON property status
7549 7550 7551 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7549 def status @status end |
#test_account ⇒ Boolean Also known as: test_account?
Output only. Identifies if the client is a test account. Read only.
Corresponds to the JSON property testAccount
7554 7555 7556 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7554 def test_account @test_account end |
#time_zone ⇒ String
Output only. Common Locale Data Repository (CLDR) string representation of the
time zone of the client, for example, America/Los_Angeles. Read only.
Corresponds to the JSON property timeZone
7561 7562 7563 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7561 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7568 def update!(**args) @applied_labels = args[:applied_labels] if args.key?(:applied_labels) @client_customer = args[:client_customer] if args.key?(:client_customer) @currency_code = args[:currency_code] if args.key?(:currency_code) @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name) @hidden = args[:hidden] if args.key?(:hidden) @id = args[:id] if args.key?(:id) @level = args[:level] if args.key?(:level) @manager = args[:manager] if args.key?(:manager) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @test_account = args[:test_account] if args.key?(:test_account) @time_zone = args[:time_zone] if args.key?(:time_zone) end |