Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A link between the given customer and a client customer. CustomerClients only exist for manager customers. All direct and indirect client customers are included, as well as the manager itself.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesCustomerClient

Returns a new instance of GoogleAdsSearchads360V0ResourcesCustomerClient.



7482
7483
7484
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_labelsArray<String>

Output only. The resource names of the labels owned by the requesting customer that are applied to the client customer. Label resource names have the form: customers/customer_id/labels/label_id` Corresponds to the JSON propertyappliedLabels`

Returns:

  • (Array<String>)


7416
7417
7418
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7416

def applied_labels
  @applied_labels
end

#client_customerString

Output only. The resource name of the client-customer which is linked to the given customer. Read only. Corresponds to the JSON property clientCustomer

Returns:

  • (String)


7422
7423
7424
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7422

def client_customer
  @client_customer
end

#currency_codeString

Output only. Currency code (for example, 'USD', 'EUR') for the client. Read only. Corresponds to the JSON property currencyCode

Returns:

  • (String)


7428
7429
7430
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7428

def currency_code
  @currency_code
end

#descriptive_nameString

Output only. Descriptive name for the client. Read only. Corresponds to the JSON property descriptiveName

Returns:

  • (String)


7433
7434
7435
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7433

def descriptive_name
  @descriptive_name
end

#hiddenBoolean Also known as: hidden?

Output only. Specifies whether this is a hidden account. Read only. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


7438
7439
7440
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7438

def hidden
  @hidden
end

#idFixnum

Output only. The ID of the client customer. Read only. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7444
7445
7446
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7444

def id
  @id
end

#levelFixnum

Output only. Distance between given customer and client. For self link, the level value will be 0. Read only. Corresponds to the JSON property level

Returns:

  • (Fixnum)


7450
7451
7452
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7450

def level
  @level
end

#managerBoolean Also known as: manager?

Output only. Identifies if the client is a manager. Read only. Corresponds to the JSON property manager

Returns:

  • (Boolean)


7455
7456
7457
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7455

def manager
  @manager
end

#resource_nameString

Output only. The resource name of the customer client. CustomerClient resource names have the form: customers/customer_id/customerClients/ client_customer_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


7463
7464
7465
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7463

def resource_name
  @resource_name
end

#statusString

Output only. The status of the client customer. Read only. Corresponds to the JSON property status

Returns:

  • (String)


7468
7469
7470
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7468

def status
  @status
end

#test_accountBoolean Also known as: test_account?

Output only. Identifies if the client is a test account. Read only. Corresponds to the JSON property testAccount

Returns:

  • (Boolean)


7473
7474
7475
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7473

def 
  @test_account
end

#time_zoneString

Output only. Common Locale Data Repository (CLDR) string representation of the time zone of the client, for example, America/Los_Angeles. Read only. Corresponds to the JSON property timeZone

Returns:

  • (String)


7480
7481
7482
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7480

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7487
7488
7489
7490
7491
7492
7493
7494
7495
7496
7497
7498
7499
7500
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7487

def update!(**args)
  @applied_labels = args[:applied_labels] if args.key?(:applied_labels)
  @client_customer = args[:client_customer] if args.key?(:client_customer)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name)
  @hidden = args[:hidden] if args.key?(:hidden)
  @id = args[:id] if args.key?(:id)
  @level = args[:level] if args.key?(:level)
  @manager = args[:manager] if args.key?(:manager)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @test_account = args[:test_account] if args.key?(:test_account)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end