Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A gender view. The gender_view resource reflects the effective serving state, rather than what criteria were added. An ad group without gender criteria by default shows to all genders, so all genders appear in gender_view with stats.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGenderView
constructor
A new instance of GoogleAdsSearchads360V0ResourcesGenderView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGenderView
Returns a new instance of GoogleAdsSearchads360V0ResourcesGenderView.
7625 7626 7627 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the gender view. Gender view resource names
have the form: customers/customer_id/genderViews/ad_group_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
7623 7624 7625 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7623 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7630 7631 7632 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7630 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |