Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A geo target constant.
Instance Attribute Summary collapse
-
#canonical_name ⇒ String
Output only.
-
#country_code ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#parent_geo_target ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#target_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGeoTargetConstant
constructor
A new instance of GoogleAdsSearchads360V0ResourcesGeoTargetConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesGeoTargetConstant
Returns a new instance of GoogleAdsSearchads360V0ResourcesGeoTargetConstant.
7684 7685 7686 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_name ⇒ String
Output only. The fully qualified English name, consisting of the target's name
and that of its parent and country.
Corresponds to the JSON property canonicalName
7643 7644 7645 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7643 def canonical_name @canonical_name end |
#country_code ⇒ String
Output only. The ISO-3166-1 alpha-2 country code that is associated with the
target.
Corresponds to the JSON property countryCode
7649 7650 7651 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7649 def country_code @country_code end |
#id ⇒ Fixnum
Output only. The ID of the geo target constant.
Corresponds to the JSON property id
7654 7655 7656 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7654 def id @id end |
#name ⇒ String
Output only. Geo target constant English name.
Corresponds to the JSON property name
7659 7660 7661 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7659 def name @name end |
#parent_geo_target ⇒ String
Output only. The resource name of the parent geo target constant. Geo target
constant resource names have the form: geoTargetConstants/
parent_geo_target_constant_id`
Corresponds to the JSON propertyparentGeoTarget`
7666 7667 7668 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7666 def parent_geo_target @parent_geo_target end |
#resource_name ⇒ String
Output only. The resource name of the geo target constant. Geo target constant
resource names have the form: geoTargetConstants/geo_target_constant_id`
Corresponds to the JSON propertyresourceName`
7672 7673 7674 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7672 def resource_name @resource_name end |
#status ⇒ String
Output only. Geo target constant status.
Corresponds to the JSON property status
7677 7678 7679 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7677 def status @status end |
#target_type ⇒ String
Output only. Geo target constant target type.
Corresponds to the JSON property targetType
7682 7683 7684 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7682 def target_type @target_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 7689 def update!(**args) @canonical_name = args[:canonical_name] if args.key?(:canonical_name) @country_code = args[:country_code] if args.key?(:country_code) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @parent_geo_target = args[:parent_geo_target] if args.key?(:parent_geo_target) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @target_type = args[:target_type] if args.key?(:target_type) end |