Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of this user list.
-
#resource_name ⇒ String
Immutable.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserList
constructor
A new instance of GoogleAdsSearchads360V0ResourcesUserList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserList
Returns a new instance of GoogleAdsSearchads360V0ResourcesUserList.
8183 8184 8185 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. Id of the user list.
Corresponds to the JSON property id
8164 8165 8166 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8164 def id @id end |
#name ⇒ String
Name of this user list. Unique per user list, except in some cases where a
user list of the same name has access_reason set to SHARED.
Corresponds to the JSON property name
8170 8171 8172 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8170 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the user list. User list resource names have
the form: customers/customer_id/userLists/user_list_id`
Corresponds to the JSON propertyresourceName`
8176 8177 8178 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8176 def resource_name @resource_name end |
#type ⇒ String
Output only. Type of this list. This field is read-only.
Corresponds to the JSON property type
8181 8182 8183 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8181 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8188 8189 8190 8191 8192 8193 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8188 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @type = args[:type] if args.key?(:type) end |