Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A user location view. User Location View includes all metrics aggregated at the country level, one row per country. It reports metrics at the actual physical location of the user by targeted or not targeted location. If other segment fields are used, you may get more than one row per country.
Instance Attribute Summary collapse
-
#country_criterion_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#targeting_location ⇒ Boolean
(also: #targeting_location?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserLocationView
constructor
A new instance of GoogleAdsSearchads360V0ResourcesUserLocationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ResourcesUserLocationView
Returns a new instance of GoogleAdsSearchads360V0ResourcesUserLocationView.
8306 8307 8308 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_criterion_id ⇒ Fixnum
Output only. Criterion Id for the country.
Corresponds to the JSON property countryCriterionId
8291 8292 8293 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8291 def country_criterion_id @country_criterion_id end |
#resource_name ⇒ String
Output only. The resource name of the user location view. UserLocation view
resource names have the form: customers/customer_id/userLocationViews/
country_criterion_id~targeting_location`
Corresponds to the JSON propertyresourceName`
8298 8299 8300 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8298 def resource_name @resource_name end |
#targeting_location ⇒ Boolean Also known as: targeting_location?
Output only. Indicates whether location was targeted or not.
Corresponds to the JSON property targetingLocation
8303 8304 8305 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8303 def targeting_location @targeting_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8311 8312 8313 8314 8315 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8311 def update!(**args) @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @targeting_location = args[:targeting_location] if args.key?(:targeting_location) end |