Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Message for raw event conversion metric header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom variable ID.
-
#name ⇒ String
The user defined name of the raw event metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader
constructor
A new instance of GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader
Returns a new instance of GoogleAdsSearchads360V0ServicesRawEventConversionMetricHeader.
8522 8523 8524 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom variable ID.
Corresponds to the JSON property id
8515 8516 8517 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8515 def id @id end |
#name ⇒ String
The user defined name of the raw event metric.
Corresponds to the JSON property name
8520 8521 8522 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8520 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8527 8528 8529 8530 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8527 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |