Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A returned row from the query.
Instance Attribute Summary collapse
-
#accessible_bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
Represents a view of BiddingStrategies owned by and shared with the customer.
-
#ad_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
An ad group.
-
#ad_group_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
An ad group ad.
-
#ad_group_ad_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
A relationship between an ad group ad and an effective label.
-
#ad_group_ad_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
-
#ad_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAsset
A link between an ad group and an asset.
-
#ad_group_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set.
-
#ad_group_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
An ad group audience view.
-
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
-
#ad_group_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterion
An ad group criterion.
-
#ad_group_criterion_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
A relationship between an ad group criterion and an effective label.
-
#ad_group_criterion_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel
A relationship between an ad group criterion and a label.
-
#ad_group_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
A relationship between an ad group and an effective label.
-
#ad_group_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupLabel
A relationship between an ad group and a label.
-
#age_range_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAgeRangeView
An age range view.
-
#asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads.
-
#asset_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroup
An asset group.
-
#asset_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group.
-
#asset_group_listing_group_filter ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter
AssetGroupListingGroupFilter represents a listing group filter tree node in an asset group.
-
#asset_group_signal ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
AssetGroupSignal represents a signal in an asset group.
-
#asset_group_top_combination_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView
A view on the usage of asset group asset top combinations.
-
#asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSet
An asset set representing a collection of assets.
-
#asset_set_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesBiddingStrategy
A bidding strategy.
-
#campaign ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
A campaign.
-
#campaign_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAsset
A link between a Campaign and an Asset.
-
#campaign_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set.
-
#campaign_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
A campaign audience view.
-
#campaign_budget ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignBudget
A campaign budget.
-
#campaign_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion
A campaign criterion.
-
#campaign_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel
Represents a relationship between a campaign and an effective label.
-
#campaign_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
-
#cart_data_sales_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCartDataSalesView
Cart data sales view.
-
#conversion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion
A conversion.
-
#conversion_action ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
A conversion action.
-
#conversion_custom_variable ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable
A conversion custom variable.
-
#custom_columns ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The custom columns.
-
#customer ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
A customer.
-
#customer_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAsset
A link between a customer and an asset.
-
#customer_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set.
-
#customer_client ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
A link between the given customer and a client customer.
-
#customer_manager_link ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
Represents customer-manager link relationship.
-
#dynamic_search_ads_search_term_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView
A dynamic search ads search term view.
-
#gender_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
A gender view resource.
-
#geo_target_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
A geo target constant.
-
#keyword_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesKeywordView
A keyword view.
-
#label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLabel
A label.
-
#language_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLanguageConstant
A language.
-
#location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLocationView
A location view summarizes the performance of campaigns by a Location criterion.
-
#metrics ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMetrics
Metrics data.
-
#product_bidding_category_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant
A Product Bidding Category.
-
#product_group_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductGroupView
A product group view.
-
#segments ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
Segment only fields.
-
#shopping_performance_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesShoppingPerformanceView
Shopping performance view.
-
#user_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
A user list.
-
#user_location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
A user location view.
-
#visit ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesVisit
A visit.
-
#webpage_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesWebpageView
A webpage view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchAds360Row
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchAds360Row.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchAds360Row
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchAds360Row.
8991 8992 8993 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessible_bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
Represents a view of BiddingStrategies owned by and shared with the customer.
In contrast to BiddingStrategy, this resource includes strategies owned by
managers of the customer and shared with this customer - in addition to
strategies owned by this customer. This resource does not provide metrics and
only exposes a limited subset of the BiddingStrategy attributes.
Corresponds to the JSON property accessibleBiddingStrategy
8629 8630 8631 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8629 def accessible_bidding_strategy @accessible_bidding_strategy end |
#ad_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
An ad group.
Corresponds to the JSON property adGroup
8634 8635 8636 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8634 def ad_group @ad_group end |
#ad_group_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
An ad group ad.
Corresponds to the JSON property adGroupAd
8639 8640 8641 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8639 def ad_group_ad @ad_group_ad end |
#ad_group_ad_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
A relationship between an ad group ad and an effective label. An effective
label is a label inherited or directly assigned to this ad group ad.
Corresponds to the JSON property adGroupAdEffectiveLabel
8645 8646 8647 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8645 def ad_group_ad_effective_label @ad_group_ad_effective_label end |
#ad_group_ad_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
Corresponds to the JSON property adGroupAdLabel
8650 8651 8652 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8650 def ad_group_ad_label @ad_group_ad_label end |
#ad_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAsset
A link between an ad group and an asset.
Corresponds to the JSON property adGroupAsset
8655 8656 8657 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8655 def ad_group_asset @ad_group_asset end |
#ad_group_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set. Creating
an AdGroupAssetSet links an asset set with an ad group.
Corresponds to the JSON property adGroupAssetSet
8661 8662 8663 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8661 def ad_group_asset_set @ad_group_asset_set end |
#ad_group_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
An ad group audience view. Includes performance data from interests and
remarketing lists for Display Network and YouTube Network ads, and remarketing
lists for search ads (RLSA), aggregated at the audience level.
Corresponds to the JSON property adGroupAudienceView
8668 8669 8670 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8668 def ad_group_audience_view @ad_group_audience_view end |
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
Corresponds to the JSON property adGroupBidModifier
8673 8674 8675 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8673 def ad_group_bid_modifier @ad_group_bid_modifier end |
#ad_group_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterion
An ad group criterion. The ad_group_criterion report only returns criteria
that were explicitly added to the ad group.
Corresponds to the JSON property adGroupCriterion
8679 8680 8681 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8679 def ad_group_criterion @ad_group_criterion end |
#ad_group_criterion_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
A relationship between an ad group criterion and an effective label. An
effective label is a label inherited or directly assigned to this ad group
criterion.
Corresponds to the JSON property adGroupCriterionEffectiveLabel
8686 8687 8688 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8686 def ad_group_criterion_effective_label @ad_group_criterion_effective_label end |
#ad_group_criterion_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel
A relationship between an ad group criterion and a label.
Corresponds to the JSON property adGroupCriterionLabel
8691 8692 8693 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8691 def ad_group_criterion_label @ad_group_criterion_label end |
#ad_group_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
A relationship between an ad group and an effective label. An effective label
is a label inherited or directly assigned to this ad group.
Corresponds to the JSON property adGroupEffectiveLabel
8697 8698 8699 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8697 def ad_group_effective_label @ad_group_effective_label end |
#ad_group_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupLabel
A relationship between an ad group and a label.
Corresponds to the JSON property adGroupLabel
8702 8703 8704 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8702 def ad_group_label @ad_group_label end |
#age_range_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAgeRangeView
An age range view. Represents the view of a customer's performance metrics (
like impressions and clicks) aggregated by age range. All statistics are
aggregated at the ad group level. Note: While you can segment metrics by age
range using age_range_view or by gender using gender_view, the Search Ads
360 API does not support segmenting metrics by both age range and gender
simultaneously in a single query. Analyzing performance across both dimensions
combined is not supported in the Search Ads 360 API.
Corresponds to the JSON property ageRangeView
8713 8714 8715 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8713 def age_range_view @age_range_view end |
#asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads. It can be an
image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and
cannot be removed. To stop an asset from serving, remove the asset from the
entity that is using it.
Corresponds to the JSON property asset
8721 8722 8723 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8721 def asset @asset end |
#asset_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroup
An asset group. AssetGroupAsset is used to link an asset to the asset group.
AssetGroupSignal is used to associate a signal to an asset group.
Corresponds to the JSON property assetGroup
8727 8728 8729 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8727 def asset_group @asset_group end |
#asset_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group. Adding an
AssetGroupAsset links an asset with an asset group.
Corresponds to the JSON property assetGroupAsset
8733 8734 8735 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8733 def asset_group_asset @asset_group_asset end |
#asset_group_listing_group_filter ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter
AssetGroupListingGroupFilter represents a listing group filter tree node in an
asset group.
Corresponds to the JSON property assetGroupListingGroupFilter
8739 8740 8741 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8739 def asset_group_listing_group_filter @asset_group_listing_group_filter end |
#asset_group_signal ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
AssetGroupSignal represents a signal in an asset group. The existence of a
signal tells the performance max campaign who's most likely to convert.
Performance Max uses the signal to look for new people with similar or
stronger intent to find conversions across Search, Display, Video, and more.
Corresponds to the JSON property assetGroupSignal
8747 8748 8749 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8747 def asset_group_signal @asset_group_signal end |
#asset_group_top_combination_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView
A view on the usage of asset group asset top combinations.
Corresponds to the JSON property assetGroupTopCombinationView
8752 8753 8754 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8752 def asset_group_top_combination_view @asset_group_top_combination_view end |
#asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSet
An asset set representing a collection of assets. Use AssetSetAsset to link an
asset to the asset set.
Corresponds to the JSON property assetSet
8758 8759 8760 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8758 def asset_set @asset_set end |
#asset_set_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property assetSetAsset
8764 8765 8766 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8764 def asset_set_asset @asset_set_asset end |
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property audience
8771 8772 8773 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8771 def audience @audience end |
#bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property biddingStrategy
8776 8777 8778 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8776 def bidding_strategy @bidding_strategy end |
#campaign ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
A campaign.
Corresponds to the JSON property campaign
8781 8782 8783 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8781 def campaign @campaign end |
#campaign_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAsset
A link between a Campaign and an Asset.
Corresponds to the JSON property campaignAsset
8786 8787 8788 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8786 def campaign_asset @campaign_asset end |
#campaign_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set. Adding a
CampaignAssetSet links an asset set with a campaign.
Corresponds to the JSON property campaignAssetSet
8792 8793 8794 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8792 def campaign_asset_set @campaign_asset_set end |
#campaign_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
A campaign audience view. Includes performance data from interests and
remarketing lists for Display Network and YouTube Network ads, and remarketing
lists for search ads (RLSA), aggregated by campaign and audience criterion.
This view only includes audiences attached at the campaign level.
Corresponds to the JSON property campaignAudienceView
8800 8801 8802 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8800 def campaign_audience_view @campaign_audience_view end |
#campaign_budget ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignBudget
A campaign budget.
Corresponds to the JSON property campaignBudget
8805 8806 8807 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8805 def campaign_budget @campaign_budget end |
#campaign_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property campaignCriterion
8810 8811 8812 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8810 def campaign_criterion @campaign_criterion end |
#campaign_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel
Represents a relationship between a campaign and an effective label. An
effective label is a label inherited or directly assigned to this campaign.
Corresponds to the JSON property campaignEffectiveLabel
8816 8817 8818 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8816 def campaign_effective_label @campaign_effective_label end |
#campaign_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
Corresponds to the JSON property campaignLabel
8821 8822 8823 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8821 def campaign_label @campaign_label end |
#cart_data_sales_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCartDataSalesView
Cart data sales view. Provides information about the products which were
purchased if conversions with cart data is implemented. Performance metrics
like revenue, gross profit, lead/cross-sell metrics etc. and Merchant Center
attributes such as brand, category etc. are available for products defined in
an inventory feed and sold as a result of Google ads. For purchases attributed
to clicks on Shopping ads, dimensions of both clicked and sold products can be
viewed together.
Corresponds to the JSON property cartDataSalesView
8832 8833 8834 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8832 def cart_data_sales_view @cart_data_sales_view end |
#conversion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion
A conversion.
Corresponds to the JSON property conversion
8837 8838 8839 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8837 def conversion @conversion end |
#conversion_action ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
A conversion action.
Corresponds to the JSON property conversionAction
8842 8843 8844 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8842 def conversion_action @conversion_action end |
#conversion_custom_variable ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable
A conversion custom variable. See "About custom Floodlight metrics and
dimensions in the new Search Ads 360" at https://support.google.com/sa360/
answer/13567857
Corresponds to the JSON property conversionCustomVariable
8849 8850 8851 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8849 def conversion_custom_variable @conversion_custom_variable end |
#custom_columns ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The custom columns.
Corresponds to the JSON property customColumns
8854 8855 8856 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8854 def custom_columns @custom_columns end |
#customer ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
A customer.
Corresponds to the JSON property customer
8859 8860 8861 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8859 def customer @customer end |
#customer_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAsset
A link between a customer and an asset.
Corresponds to the JSON property customerAsset
8864 8865 8866 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8864 def customer_asset @customer_asset end |
#customer_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set. Adding a
CustomerAssetSet links an asset set with a customer.
Corresponds to the JSON property customerAssetSet
8870 8871 8872 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8870 def customer_asset_set @customer_asset_set end |
#customer_client ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
A link between the given customer and a client customer. CustomerClients only
exist for manager customers. All direct and indirect client customers are
included, as well as the manager itself.
Corresponds to the JSON property customerClient
8877 8878 8879 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8877 def customer_client @customer_client end |
#customer_manager_link ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
Represents customer-manager link relationship.
Corresponds to the JSON property customerManagerLink
8882 8883 8884 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8882 def customer_manager_link @customer_manager_link end |
#dynamic_search_ads_search_term_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView
A dynamic search ads search term view.
Corresponds to the JSON property dynamicSearchAdsSearchTermView
8887 8888 8889 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8887 def dynamic_search_ads_search_term_view @dynamic_search_ads_search_term_view end |
#gender_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
A gender view resource. Represents the view of a customer's performance
metrics aggregated by gender. All statistics are aggregated at the ad group
level. Note: While you can segment metrics by age range using age_range_view
or by gender using gender_view, the Search Ads 360 API does not support
segmenting metrics by both age range and gender simultaneously in a single
query. Analyzing performance across both dimensions combined is not supported
in the Search Ads 360 API.
Corresponds to the JSON property genderView
8898 8899 8900 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8898 def gender_view @gender_view end |
#geo_target_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
A geo target constant.
Corresponds to the JSON property geoTargetConstant
8903 8904 8905 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8903 def geo_target_constant @geo_target_constant end |
#keyword_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesKeywordView
A keyword view.
Corresponds to the JSON property keywordView
8908 8909 8910 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8908 def keyword_view @keyword_view end |
#label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLabel
A label.
Corresponds to the JSON property label
8913 8914 8915 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8913 def label @label end |
#language_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLanguageConstant
A language.
Corresponds to the JSON property languageConstant
8918 8919 8920 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8918 def language_constant @language_constant end |
#location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLocationView
A location view summarizes the performance of campaigns by a Location
criterion.
Corresponds to the JSON property locationView
8924 8925 8926 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8924 def location_view @location_view end |
#metrics ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMetrics
Metrics data.
Corresponds to the JSON property metrics
8929 8930 8931 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8929 def metrics @metrics end |
#product_bidding_category_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant
A Product Bidding Category.
Corresponds to the JSON property productBiddingCategoryConstant
8934 8935 8936 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8934 def product_bidding_category_constant @product_bidding_category_constant end |
#product_group_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductGroupView
A product group view.
Corresponds to the JSON property productGroupView
8939 8940 8941 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8939 def product_group_view @product_group_view end |
#segments ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
Segment only fields.
Corresponds to the JSON property segments
8944 8945 8946 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8944 def segments @segments end |
#shopping_performance_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesShoppingPerformanceView
Shopping performance view. Provides Shopping campaign and Performance Max
campaign statistics aggregated at several product dimension levels. Product
dimension values from Merchant Center such as brand, category, custom
attributes, product condition, and product type will reflect the state of each
dimension as of the date and time when the corresponding event was recorded.
The number of impressions and clicks that shopping_performance_view returns
stats for may be different from campaign reports. shopping_performance_view
shows impressions and clicks on products appearing in ads, while campaign
reports show impressions and clicks on the ads themselves. Depending on the
format, an ad can show from zero to several products, so the numbers may not
match. In Search Ads 360 UI, you can query impressions and clicks of products
appearing in ads by selecting a column from "Product attributes" in the report
editor. For example, selecting the "Brand" column is equivalent to selecting
segments.product_brand.
Corresponds to the JSON property shoppingPerformanceView
8962 8963 8964 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8962 def shopping_performance_view @shopping_performance_view end |
#user_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property userList
8971 8972 8973 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8971 def user_list @user_list end |
#user_location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
A user location view. User Location View includes all metrics aggregated at
the country level, one row per country. It reports metrics at the actual
physical location of the user by targeted or not targeted location. If other
segment fields are used, you may get more than one row per country.
Corresponds to the JSON property userLocationView
8979 8980 8981 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8979 def user_location_view @user_location_view end |
#visit ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesVisit
A visit.
Corresponds to the JSON property visit
8984 8985 8986 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8984 def visit @visit end |
#webpage_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesWebpageView
A webpage view.
Corresponds to the JSON property webpageView
8989 8990 8991 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8989 def webpage_view @webpage_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 9009 9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 9022 9023 9024 9025 9026 9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 9055 9056 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8996 def update!(**args) @accessible_bidding_strategy = args[:accessible_bidding_strategy] if args.key?(:accessible_bidding_strategy) @ad_group = args[:ad_group] if args.key?(:ad_group) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @ad_group_ad_effective_label = args[:ad_group_ad_effective_label] if args.key?(:ad_group_ad_effective_label) @ad_group_ad_label = args[:ad_group_ad_label] if args.key?(:ad_group_ad_label) @ad_group_asset = args[:ad_group_asset] if args.key?(:ad_group_asset) @ad_group_asset_set = args[:ad_group_asset_set] if args.key?(:ad_group_asset_set) @ad_group_audience_view = args[:ad_group_audience_view] if args.key?(:ad_group_audience_view) @ad_group_bid_modifier = args[:ad_group_bid_modifier] if args.key?(:ad_group_bid_modifier) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @ad_group_criterion_effective_label = args[:ad_group_criterion_effective_label] if args.key?(:ad_group_criterion_effective_label) @ad_group_criterion_label = args[:ad_group_criterion_label] if args.key?(:ad_group_criterion_label) @ad_group_effective_label = args[:ad_group_effective_label] if args.key?(:ad_group_effective_label) @ad_group_label = args[:ad_group_label] if args.key?(:ad_group_label) @age_range_view = args[:age_range_view] if args.key?(:age_range_view) @asset = args[:asset] if args.key?(:asset) @asset_group = args[:asset_group] if args.key?(:asset_group) @asset_group_asset = args[:asset_group_asset] if args.key?(:asset_group_asset) @asset_group_listing_group_filter = args[:asset_group_listing_group_filter] if args.key?(:asset_group_listing_group_filter) @asset_group_signal = args[:asset_group_signal] if args.key?(:asset_group_signal) @asset_group_top_combination_view = args[:asset_group_top_combination_view] if args.key?(:asset_group_top_combination_view) @asset_set = args[:asset_set] if args.key?(:asset_set) @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset) @audience = args[:audience] if args.key?(:audience) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @campaign = args[:campaign] if args.key?(:campaign) @campaign_asset = args[:campaign_asset] if args.key?(:campaign_asset) @campaign_asset_set = args[:campaign_asset_set] if args.key?(:campaign_asset_set) @campaign_audience_view = args[:campaign_audience_view] if args.key?(:campaign_audience_view) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_criterion = args[:campaign_criterion] if args.key?(:campaign_criterion) @campaign_effective_label = args[:campaign_effective_label] if args.key?(:campaign_effective_label) @campaign_label = args[:campaign_label] if args.key?(:campaign_label) @cart_data_sales_view = args[:cart_data_sales_view] if args.key?(:cart_data_sales_view) @conversion = args[:conversion] if args.key?(:conversion) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_custom_variable = args[:conversion_custom_variable] if args.key?(:conversion_custom_variable) @custom_columns = args[:custom_columns] if args.key?(:custom_columns) @customer = args[:customer] if args.key?(:customer) @customer_asset = args[:customer_asset] if args.key?(:customer_asset) @customer_asset_set = args[:customer_asset_set] if args.key?(:customer_asset_set) @customer_client = args[:customer_client] if args.key?(:customer_client) @customer_manager_link = args[:customer_manager_link] if args.key?(:customer_manager_link) @dynamic_search_ads_search_term_view = args[:dynamic_search_ads_search_term_view] if args.key?(:dynamic_search_ads_search_term_view) @gender_view = args[:gender_view] if args.key?(:gender_view) @geo_target_constant = args[:geo_target_constant] if args.key?(:geo_target_constant) @keyword_view = args[:keyword_view] if args.key?(:keyword_view) @label = args[:label] if args.key?(:label) @language_constant = args[:language_constant] if args.key?(:language_constant) @location_view = args[:location_view] if args.key?(:location_view) @metrics = args[:metrics] if args.key?(:metrics) @product_bidding_category_constant = args[:product_bidding_category_constant] if args.key?(:product_bidding_category_constant) @product_group_view = args[:product_group_view] if args.key?(:product_group_view) @segments = args[:segments] if args.key?(:segments) @shopping_performance_view = args[:shopping_performance_view] if args.key?(:shopping_performance_view) @user_list = args[:user_list] if args.key?(:user_list) @user_location_view = args[:user_location_view] if args.key?(:user_location_view) @visit = args[:visit] if args.key?(:visit) @webpage_view = args[:webpage_view] if args.key?(:webpage_view) end |