Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchAds360Row
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A returned row from the query.
Instance Attribute Summary collapse
-
#accessible_bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
Represents a view of BiddingStrategies owned by and shared with the customer.
-
#ad_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
An ad group.
-
#ad_group_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
An ad group ad.
-
#ad_group_ad_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
A relationship between an ad group ad and an effective label.
-
#ad_group_ad_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
-
#ad_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAsset
A link between an ad group and an asset.
-
#ad_group_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set.
-
#ad_group_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
An ad group audience view.
-
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
-
#ad_group_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterion
An ad group criterion.
-
#ad_group_criterion_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
A relationship between an ad group criterion and an effective label.
-
#ad_group_criterion_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel
A relationship between an ad group criterion and a label.
-
#ad_group_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
A relationship between an ad group and an effective label.
-
#ad_group_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupLabel
A relationship between an ad group and a label.
-
#age_range_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAgeRangeView
An age range view.
-
#asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads.
-
#asset_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroup
An asset group.
-
#asset_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group.
-
#asset_group_listing_group_filter ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter
AssetGroupListingGroupFilter represents a listing group filter tree node in an asset group.
-
#asset_group_signal ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
AssetGroupSignal represents a signal in an asset group.
-
#asset_group_top_combination_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView
A view on the usage of asset group asset top combinations.
-
#asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSet
An asset set representing a collection of assets.
-
#asset_set_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesBiddingStrategy
A bidding strategy.
-
#campaign ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
A campaign.
-
#campaign_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAsset
A link between a Campaign and an Asset.
-
#campaign_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set.
-
#campaign_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
A campaign audience view.
-
#campaign_budget ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignBudget
A campaign budget.
-
#campaign_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion
A campaign criterion.
-
#campaign_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel
Represents a relationship between a campaign and an effective label.
-
#campaign_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
-
#cart_data_sales_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCartDataSalesView
Cart data sales view.
-
#conversion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion
A conversion.
-
#conversion_action ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
A conversion action.
-
#conversion_custom_variable ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable
A conversion custom variable.
-
#custom_columns ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The custom columns.
-
#customer ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
A customer.
-
#customer_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAsset
A link between a customer and an asset.
-
#customer_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set.
-
#customer_client ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
A link between the given customer and a client customer.
-
#customer_manager_link ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
Represents customer-manager link relationship.
-
#dynamic_search_ads_search_term_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView
A dynamic search ads search term view.
-
#gender_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
A gender view.
-
#geo_target_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
A geo target constant.
-
#keyword_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesKeywordView
A keyword view.
-
#label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLabel
A label.
-
#language_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLanguageConstant
A language.
-
#location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLocationView
A location view summarizes the performance of campaigns by a Location criterion.
-
#metrics ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMetrics
Metrics data.
-
#product_bidding_category_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant
A Product Bidding Category.
-
#product_group_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductGroupView
A product group view.
-
#segments ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
Segment only fields.
-
#shopping_performance_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesShoppingPerformanceView
Shopping performance view.
-
#user_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
A user list.
-
#user_location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
A user location view.
-
#visit ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesVisit
A visit.
-
#webpage_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesWebpageView
A webpage view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchAds360Row
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchAds360Row.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchAds360Row
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchAds360Row.
8896 8897 8898 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessible_bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAccessibleBiddingStrategy
Represents a view of BiddingStrategies owned by and shared with the customer.
In contrast to BiddingStrategy, this resource includes strategies owned by
managers of the customer and shared with this customer - in addition to
strategies owned by this customer. This resource does not provide metrics and
only exposes a limited subset of the BiddingStrategy attributes.
Corresponds to the JSON property accessibleBiddingStrategy
8544 8545 8546 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8544 def accessible_bidding_strategy @accessible_bidding_strategy end |
#ad_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroup
An ad group.
Corresponds to the JSON property adGroup
8549 8550 8551 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8549 def ad_group @ad_group end |
#ad_group_ad ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAd
An ad group ad.
Corresponds to the JSON property adGroupAd
8554 8555 8556 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8554 def ad_group_ad @ad_group_ad end |
#ad_group_ad_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdEffectiveLabel
A relationship between an ad group ad and an effective label. An effective
label is a label inherited or directly assigned to this ad group ad.
Corresponds to the JSON property adGroupAdEffectiveLabel
8560 8561 8562 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8560 def ad_group_ad_effective_label @ad_group_ad_effective_label end |
#ad_group_ad_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
Corresponds to the JSON property adGroupAdLabel
8565 8566 8567 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8565 def ad_group_ad_label @ad_group_ad_label end |
#ad_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAsset
A link between an ad group and an asset.
Corresponds to the JSON property adGroupAsset
8570 8571 8572 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8570 def ad_group_asset @ad_group_asset end |
#ad_group_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set. Creating
an AdGroupAssetSet links an asset set with an ad group.
Corresponds to the JSON property adGroupAssetSet
8576 8577 8578 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8576 def ad_group_asset_set @ad_group_asset_set end |
#ad_group_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupAudienceView
An ad group audience view. Includes performance data from interests and
remarketing lists for Display Network and YouTube Network ads, and remarketing
lists for search ads (RLSA), aggregated at the audience level.
Corresponds to the JSON property adGroupAudienceView
8583 8584 8585 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8583 def ad_group_audience_view @ad_group_audience_view end |
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
Corresponds to the JSON property adGroupBidModifier
8588 8589 8590 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8588 def ad_group_bid_modifier @ad_group_bid_modifier end |
#ad_group_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterion
An ad group criterion. The ad_group_criterion report only returns criteria
that were explicitly added to the ad group.
Corresponds to the JSON property adGroupCriterion
8594 8595 8596 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8594 def ad_group_criterion @ad_group_criterion end |
#ad_group_criterion_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionEffectiveLabel
A relationship between an ad group criterion and an effective label. An
effective label is a label inherited or directly assigned to this ad group
criterion.
Corresponds to the JSON property adGroupCriterionEffectiveLabel
8601 8602 8603 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8601 def ad_group_criterion_effective_label @ad_group_criterion_effective_label end |
#ad_group_criterion_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupCriterionLabel
A relationship between an ad group criterion and a label.
Corresponds to the JSON property adGroupCriterionLabel
8606 8607 8608 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8606 def ad_group_criterion_label @ad_group_criterion_label end |
#ad_group_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupEffectiveLabel
A relationship between an ad group and an effective label. An effective label
is a label inherited or directly assigned to this ad group.
Corresponds to the JSON property adGroupEffectiveLabel
8612 8613 8614 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8612 def ad_group_effective_label @ad_group_effective_label end |
#ad_group_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAdGroupLabel
A relationship between an ad group and a label.
Corresponds to the JSON property adGroupLabel
8617 8618 8619 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8617 def ad_group_label @ad_group_label end |
#age_range_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAgeRangeView
An age range view.
Corresponds to the JSON property ageRangeView
8622 8623 8624 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8622 def age_range_view @age_range_view end |
#asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads. It can be an
image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and
cannot be removed. To stop an asset from serving, remove the asset from the
entity that is using it.
Corresponds to the JSON property asset
8630 8631 8632 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8630 def asset @asset end |
#asset_group ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroup
An asset group. AssetGroupAsset is used to link an asset to the asset group.
AssetGroupSignal is used to associate a signal to an asset group.
Corresponds to the JSON property assetGroup
8636 8637 8638 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8636 def asset_group @asset_group end |
#asset_group_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group. Adding an
AssetGroupAsset links an asset with an asset group.
Corresponds to the JSON property assetGroupAsset
8642 8643 8644 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8642 def asset_group_asset @asset_group_asset end |
#asset_group_listing_group_filter ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupListingGroupFilter
AssetGroupListingGroupFilter represents a listing group filter tree node in an
asset group.
Corresponds to the JSON property assetGroupListingGroupFilter
8648 8649 8650 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8648 def asset_group_listing_group_filter @asset_group_listing_group_filter end |
#asset_group_signal ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupSignal
AssetGroupSignal represents a signal in an asset group. The existence of a
signal tells the performance max campaign who's most likely to convert.
Performance Max uses the signal to look for new people with similar or
stronger intent to find conversions across Search, Display, Video, and more.
Corresponds to the JSON property assetGroupSignal
8656 8657 8658 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8656 def asset_group_signal @asset_group_signal end |
#asset_group_top_combination_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetGroupTopCombinationView
A view on the usage of asset group asset top combinations.
Corresponds to the JSON property assetGroupTopCombinationView
8661 8662 8663 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8661 def asset_group_top_combination_view @asset_group_top_combination_view end |
#asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSet
An asset set representing a collection of assets. Use AssetSetAsset to link an
asset to the asset set.
Corresponds to the JSON property assetSet
8667 8668 8669 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8667 def asset_set @asset_set end |
#asset_set_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property assetSetAsset
8673 8674 8675 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8673 def asset_set_asset @asset_set_asset end |
#audience ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property audience
8680 8681 8682 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8680 def audience @audience end |
#bidding_strategy ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property biddingStrategy
8685 8686 8687 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8685 def bidding_strategy @bidding_strategy end |
#campaign ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaign
A campaign.
Corresponds to the JSON property campaign
8690 8691 8692 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8690 def campaign @campaign end |
#campaign_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAsset
A link between a Campaign and an Asset.
Corresponds to the JSON property campaignAsset
8695 8696 8697 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8695 def campaign_asset @campaign_asset end |
#campaign_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set. Adding a
CampaignAssetSet links an asset set with a campaign.
Corresponds to the JSON property campaignAssetSet
8701 8702 8703 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8701 def campaign_asset_set @campaign_asset_set end |
#campaign_audience_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignAudienceView
A campaign audience view. Includes performance data from interests and
remarketing lists for Display Network and YouTube Network ads, and remarketing
lists for search ads (RLSA), aggregated by campaign and audience criterion.
This view only includes audiences attached at the campaign level.
Corresponds to the JSON property campaignAudienceView
8709 8710 8711 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8709 def campaign_audience_view @campaign_audience_view end |
#campaign_budget ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignBudget
A campaign budget.
Corresponds to the JSON property campaignBudget
8714 8715 8716 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8714 def campaign_budget @campaign_budget end |
#campaign_criterion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property campaignCriterion
8719 8720 8721 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8719 def campaign_criterion @campaign_criterion end |
#campaign_effective_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignEffectiveLabel
Represents a relationship between a campaign and an effective label. An
effective label is a label inherited or directly assigned to this campaign.
Corresponds to the JSON property campaignEffectiveLabel
8725 8726 8727 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8725 def campaign_effective_label @campaign_effective_label end |
#campaign_label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
Corresponds to the JSON property campaignLabel
8730 8731 8732 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8730 def campaign_label @campaign_label end |
#cart_data_sales_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCartDataSalesView
Cart data sales view. Provides information about the products which were
purchased if conversions with cart data is implemented. Performance metrics
like revenue, gross profit, lead/cross-sell metrics etc. and Merchant Center
attributes such as brand, category etc. are available for products defined in
an inventory feed and sold as a result of Google ads. For purchases attributed
to clicks on Shopping ads, dimensions of both clicked and sold products can be
viewed together.
Corresponds to the JSON property cartDataSalesView
8741 8742 8743 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8741 def cart_data_sales_view @cart_data_sales_view end |
#conversion ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversion
A conversion.
Corresponds to the JSON property conversion
8746 8747 8748 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8746 def conversion @conversion end |
#conversion_action ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionAction
A conversion action.
Corresponds to the JSON property conversionAction
8751 8752 8753 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8751 def conversion_action @conversion_action end |
#conversion_custom_variable ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesConversionCustomVariable
A conversion custom variable. See "About custom Floodlight metrics and
dimensions in the new Search Ads 360" at https://support.google.com/sa360/
answer/13567857
Corresponds to the JSON property conversionCustomVariable
8758 8759 8760 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8758 def conversion_custom_variable @conversion_custom_variable end |
#custom_columns ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonValue>
The custom columns.
Corresponds to the JSON property customColumns
8763 8764 8765 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8763 def custom_columns @custom_columns end |
#customer ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomer
A customer.
Corresponds to the JSON property customer
8768 8769 8770 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8768 def customer @customer end |
#customer_asset ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAsset
A link between a customer and an asset.
Corresponds to the JSON property customerAsset
8773 8774 8775 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8773 def customer_asset @customer_asset end |
#customer_asset_set ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set. Adding a
CustomerAssetSet links an asset set with a customer.
Corresponds to the JSON property customerAssetSet
8779 8780 8781 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8779 def customer_asset_set @customer_asset_set end |
#customer_client ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerClient
A link between the given customer and a client customer. CustomerClients only
exist for manager customers. All direct and indirect client customers are
included, as well as the manager itself.
Corresponds to the JSON property customerClient
8786 8787 8788 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8786 def customer_client @customer_client end |
#customer_manager_link ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesCustomerManagerLink
Represents customer-manager link relationship.
Corresponds to the JSON property customerManagerLink
8791 8792 8793 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8791 def customer_manager_link @customer_manager_link end |
#dynamic_search_ads_search_term_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesDynamicSearchAdsSearchTermView
A dynamic search ads search term view.
Corresponds to the JSON property dynamicSearchAdsSearchTermView
8796 8797 8798 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8796 def dynamic_search_ads_search_term_view @dynamic_search_ads_search_term_view end |
#gender_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGenderView
A gender view. The gender_view resource reflects the effective serving state,
rather than what criteria were added. An ad group without gender criteria by
default shows to all genders, so all genders appear in gender_view with stats.
Corresponds to the JSON property genderView
8803 8804 8805 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8803 def gender_view @gender_view end |
#geo_target_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesGeoTargetConstant
A geo target constant.
Corresponds to the JSON property geoTargetConstant
8808 8809 8810 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8808 def geo_target_constant @geo_target_constant end |
#keyword_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesKeywordView
A keyword view.
Corresponds to the JSON property keywordView
8813 8814 8815 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8813 def keyword_view @keyword_view end |
#label ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLabel
A label.
Corresponds to the JSON property label
8818 8819 8820 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8818 def label @label end |
#language_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLanguageConstant
A language.
Corresponds to the JSON property languageConstant
8823 8824 8825 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8823 def language_constant @language_constant end |
#location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesLocationView
A location view summarizes the performance of campaigns by a Location
criterion.
Corresponds to the JSON property locationView
8829 8830 8831 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8829 def location_view @location_view end |
#metrics ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonMetrics
Metrics data.
Corresponds to the JSON property metrics
8834 8835 8836 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8834 def metrics @metrics end |
#product_bidding_category_constant ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductBiddingCategoryConstant
A Product Bidding Category.
Corresponds to the JSON property productBiddingCategoryConstant
8839 8840 8841 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8839 def product_bidding_category_constant @product_bidding_category_constant end |
#product_group_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesProductGroupView
A product group view.
Corresponds to the JSON property productGroupView
8844 8845 8846 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8844 def product_group_view @product_group_view end |
#segments ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0CommonSegments
Segment only fields.
Corresponds to the JSON property segments
8849 8850 8851 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8849 def segments @segments end |
#shopping_performance_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesShoppingPerformanceView
Shopping performance view. Provides Shopping campaign and Performance Max
campaign statistics aggregated at several product dimension levels. Product
dimension values from Merchant Center such as brand, category, custom
attributes, product condition, and product type will reflect the state of each
dimension as of the date and time when the corresponding event was recorded.
The number of impressions and clicks that shopping_performance_view returns
stats for may be different from campaign reports. shopping_performance_view
shows impressions and clicks on products appearing in ads, while campaign
reports show impressions and clicks on the ads themselves. Depending on the
format, an ad can show from zero to several products, so the numbers may not
match. In Search Ads 360 UI, you can query impressions and clicks of products
appearing in ads by selecting a column from "Product attributes" in the report
editor. For example, selecting the "Brand" column is equivalent to selecting
segments.product_brand.
Corresponds to the JSON property shoppingPerformanceView
8867 8868 8869 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8867 def shopping_performance_view @shopping_performance_view end |
#user_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property userList
8876 8877 8878 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8876 def user_list @user_list end |
#user_location_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesUserLocationView
A user location view. User Location View includes all metrics aggregated at
the country level, one row per country. It reports metrics at the actual
physical location of the user by targeted or not targeted location. If other
segment fields are used, you may get more than one row per country.
Corresponds to the JSON property userLocationView
8884 8885 8886 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8884 def user_location_view @user_location_view end |
#visit ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesVisit
A visit.
Corresponds to the JSON property visit
8889 8890 8891 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8889 def visit @visit end |
#webpage_view ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ResourcesWebpageView
A webpage view.
Corresponds to the JSON property webpageView
8894 8895 8896 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8894 def webpage_view @webpage_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 8944 8945 8946 8947 8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 8901 def update!(**args) @accessible_bidding_strategy = args[:accessible_bidding_strategy] if args.key?(:accessible_bidding_strategy) @ad_group = args[:ad_group] if args.key?(:ad_group) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @ad_group_ad_effective_label = args[:ad_group_ad_effective_label] if args.key?(:ad_group_ad_effective_label) @ad_group_ad_label = args[:ad_group_ad_label] if args.key?(:ad_group_ad_label) @ad_group_asset = args[:ad_group_asset] if args.key?(:ad_group_asset) @ad_group_asset_set = args[:ad_group_asset_set] if args.key?(:ad_group_asset_set) @ad_group_audience_view = args[:ad_group_audience_view] if args.key?(:ad_group_audience_view) @ad_group_bid_modifier = args[:ad_group_bid_modifier] if args.key?(:ad_group_bid_modifier) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @ad_group_criterion_effective_label = args[:ad_group_criterion_effective_label] if args.key?(:ad_group_criterion_effective_label) @ad_group_criterion_label = args[:ad_group_criterion_label] if args.key?(:ad_group_criterion_label) @ad_group_effective_label = args[:ad_group_effective_label] if args.key?(:ad_group_effective_label) @ad_group_label = args[:ad_group_label] if args.key?(:ad_group_label) @age_range_view = args[:age_range_view] if args.key?(:age_range_view) @asset = args[:asset] if args.key?(:asset) @asset_group = args[:asset_group] if args.key?(:asset_group) @asset_group_asset = args[:asset_group_asset] if args.key?(:asset_group_asset) @asset_group_listing_group_filter = args[:asset_group_listing_group_filter] if args.key?(:asset_group_listing_group_filter) @asset_group_signal = args[:asset_group_signal] if args.key?(:asset_group_signal) @asset_group_top_combination_view = args[:asset_group_top_combination_view] if args.key?(:asset_group_top_combination_view) @asset_set = args[:asset_set] if args.key?(:asset_set) @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset) @audience = args[:audience] if args.key?(:audience) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @campaign = args[:campaign] if args.key?(:campaign) @campaign_asset = args[:campaign_asset] if args.key?(:campaign_asset) @campaign_asset_set = args[:campaign_asset_set] if args.key?(:campaign_asset_set) @campaign_audience_view = args[:campaign_audience_view] if args.key?(:campaign_audience_view) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_criterion = args[:campaign_criterion] if args.key?(:campaign_criterion) @campaign_effective_label = args[:campaign_effective_label] if args.key?(:campaign_effective_label) @campaign_label = args[:campaign_label] if args.key?(:campaign_label) @cart_data_sales_view = args[:cart_data_sales_view] if args.key?(:cart_data_sales_view) @conversion = args[:conversion] if args.key?(:conversion) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_custom_variable = args[:conversion_custom_variable] if args.key?(:conversion_custom_variable) @custom_columns = args[:custom_columns] if args.key?(:custom_columns) @customer = args[:customer] if args.key?(:customer) @customer_asset = args[:customer_asset] if args.key?(:customer_asset) @customer_asset_set = args[:customer_asset_set] if args.key?(:customer_asset_set) @customer_client = args[:customer_client] if args.key?(:customer_client) @customer_manager_link = args[:customer_manager_link] if args.key?(:customer_manager_link) @dynamic_search_ads_search_term_view = args[:dynamic_search_ads_search_term_view] if args.key?(:dynamic_search_ads_search_term_view) @gender_view = args[:gender_view] if args.key?(:gender_view) @geo_target_constant = args[:geo_target_constant] if args.key?(:geo_target_constant) @keyword_view = args[:keyword_view] if args.key?(:keyword_view) @label = args[:label] if args.key?(:label) @language_constant = args[:language_constant] if args.key?(:language_constant) @location_view = args[:location_view] if args.key?(:location_view) @metrics = args[:metrics] if args.key?(:metrics) @product_bidding_category_constant = args[:product_bidding_category_constant] if args.key?(:product_bidding_category_constant) @product_group_view = args[:product_group_view] if args.key?(:product_group_view) @segments = args[:segments] if args.key?(:segments) @shopping_performance_view = args[:shopping_performance_view] if args.key?(:shopping_performance_view) @user_list = args[:user_list] if args.key?(:user_list) @user_location_view = args[:user_location_view] if args.key?(:user_location_view) @visit = args[:visit] if args.key?(:visit) @webpage_view = args[:webpage_view] if args.key?(:webpage_view) end |