Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Request message for SearchAds360Service.Search.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#query ⇒ String
Required.
-
#return_total_results_count ⇒ Boolean
(also: #return_total_results_count?)
If true, the total number of results that match the query ignoring the LIMIT clause will be included in the response.
-
#summary_row_setting ⇒ String
Determines whether a summary row will be returned.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
constructor
A new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ServicesSearchSearchAds360Request
Returns a new instance of GoogleAdsSearchads360V0ServicesSearchSearchAds360Request.
9075 9076 9077 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page. When too large a page is
requested, the server may decide to further limit the number of returned
resources.
Corresponds to the JSON property pageSize
9041 9042 9043 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9041 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results
will be returned. Use the value obtained from next_page_token in the
previous response in order to request the next page of results.
Corresponds to the JSON property pageToken
9048 9049 9050 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9048 def page_token @page_token end |
#query ⇒ String
Required. The query string.
Corresponds to the JSON property query
9053 9054 9055 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9053 def query @query end |
#return_total_results_count ⇒ Boolean Also known as: return_total_results_count?
If true, the total number of results that match the query ignoring the LIMIT
clause will be included in the response. Default is false.
Corresponds to the JSON property returnTotalResultsCount
9059 9060 9061 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9059 def return_total_results_count @return_total_results_count end |
#summary_row_setting ⇒ String
Determines whether a summary row will be returned. By default, summary row is
not returned. If requested, the summary row will be sent in a response by
itself after all other query results are returned.
Corresponds to the JSON property summaryRowSetting
9067 9068 9069 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9067 def summary_row_setting @summary_row_setting end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed.
Corresponds to the JSON property validateOnly
9072 9073 9074 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9072 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9080 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) @return_total_results_count = args[:return_total_results_count] if args.key?(:return_total_results_count) @summary_row_setting = args[:summary_row_setting] if args.key?(:summary_row_setting) @validate_only = args[:validate_only] if args.key?(:validate_only) end |