Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Describes the effect on serving that a policy topic entry will have.
Instance Attribute Summary collapse
-
#certificate_domain_mismatch_in_country_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#certificate_missing_in_country_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#country_constraint_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#reseller_constraint ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintResellerConstraint
Indicates that a policy topic was constrained due to disapproval of the website for reseller purposes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraint
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraint
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraint.
9374 9375 9376 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9374 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_domain_mismatch_in_country_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property certificateDomainMismatchInCountryList
9356 9357 9358 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9356 def certificate_domain_mismatch_in_country_list @certificate_domain_mismatch_in_country_list end |
#certificate_missing_in_country_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property certificateMissingInCountryList
9361 9362 9363 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9361 def certificate_missing_in_country_list @certificate_missing_in_country_list end |
#country_constraint_list ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property countryConstraintList
9366 9367 9368 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9366 def country_constraint_list @country_constraint_list end |
#reseller_constraint ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintResellerConstraint
Indicates that a policy topic was constrained due to disapproval of the
website for reseller purposes.
Corresponds to the JSON property resellerConstraint
9372 9373 9374 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9372 def reseller_constraint @reseller_constraint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9379 9380 9381 9382 9383 9384 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9379 def update!(**args) @certificate_domain_mismatch_in_country_list = args[:certificate_domain_mismatch_in_country_list] if args.key?(:certificate_domain_mismatch_in_country_list) @certificate_missing_in_country_list = args[:certificate_missing_in_country_list] if args.key?(:certificate_missing_in_country_list) @country_constraint_list = args[:country_constraint_list] if args.key?(:country_constraint_list) @reseller_constraint = args[:reseller_constraint] if args.key?(:reseller_constraint) end |