Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Indicates that a resource's ability to serve in a particular country is constrained.
Instance Attribute Summary collapse
-
#country_criterion ⇒ String
Geo target constant resource name of the country in which serving is constrained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint.
9176 9177 9178 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_criterion ⇒ String
Geo target constant resource name of the country in which serving is
constrained.
Corresponds to the JSON property countryCriterion
9174 9175 9176 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9174 def country_criterion @country_criterion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9181 9182 9183 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9181 def update!(**args) @country_criterion = args[:country_criterion] if args.key?(:country_criterion) end |