Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEntry
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Policy finding attached to a resource (for example, alcohol policy associated with a site that sells alcohol). Each PolicyTopicEntry has a topic that indicates the specific ads policy the entry is about and a type to indicate the effect that the entry will have on serving. It may optionally have one or more evidences that indicate the reason for the finding. It may also optionally have one or more constraints that provide details about how serving may be restricted.
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraint>
Indicates how serving of this resource may be affected (for example, not serving in a country).
-
#evidences ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidence>
Additional information that explains policy finding (for example, the brand name for a trademark finding).
-
#topic ⇒ String
Policy topic this finding refers to.
-
#type ⇒ String
Describes the negative or positive effect this policy will have on serving.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEntry
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEntry
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEntry.
9422 9423 9424 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicConstraint>
Indicates how serving of this resource may be affected (for example, not
serving in a country).
Corresponds to the JSON property constraints
9401 9402 9403 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9401 def constraints @constraints end |
#evidences ⇒ Array<Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidence>
Additional information that explains policy finding (for example, the brand
name for a trademark finding).
Corresponds to the JSON property evidences
9407 9408 9409 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9407 def evidences @evidences end |
#topic ⇒ String
Policy topic this finding refers to. For example, "ALCOHOL", "
TRADEMARKS_IN_AD_TEXT", or "DESTINATION_NOT_WORKING". The set of possible
policy topics is not fixed for a particular API version and may change at any
time.
Corresponds to the JSON property topic
9415 9416 9417 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9415 def topic @topic end |
#type ⇒ String
Describes the negative or positive effect this policy will have on serving.
Corresponds to the JSON property type
9420 9421 9422 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9420 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9427 9428 9429 9430 9431 9432 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9427 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @evidences = args[:evidences] if args.key?(:evidences) @topic = args[:topic] if args.key?(:topic) @type = args[:type] if args.key?(:type) end |