Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A list of fragments of text that violated a policy.
Instance Attribute Summary collapse
-
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList.
9317 9318 9319 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Corresponds to the JSON property texts
9315 9316 9317 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9315 def texts @texts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9322 9323 9324 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9322 def update!(**args) @texts = args[:texts] if args.key?(:texts) end |