Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

A list of websites that caused a policy finding. Used for ONE_WEBSITE_PER_AD_GROUP policy topic, for example. In case there are more than five websites, only the top five (those that appear in resources the most) will be listed here.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList.



9339
9340
9341
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#websitesArray<String>

Websites that caused the policy finding. Corresponds to the JSON property websites

Returns:

  • (Array<String>)


9337
9338
9339
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9337

def websites
  @websites
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9344
9345
9346
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9344

def update!(**args)
  @websites = args[:websites] if args.key?(:websites)
end