Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyViolationKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Key of the violation. The key is used for referring to a violation when filing an exemption request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyViolationKey

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyViolationKey.



9507
9508
9509
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_nameString

Unique ID of the violated policy. Corresponds to the JSON property policyName

Returns:

  • (String)


9497
9498
9499
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9497

def policy_name
  @policy_name
end

#violating_textString

The text that violates the policy if specified. Otherwise, refers to the policy in general (for example, when requesting to be exempt from the whole policy). If not specified for criterion exemptions, the whole policy is implied. Must be specified for ad exemptions. Corresponds to the JSON property violatingText

Returns:

  • (String)


9505
9506
9507
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9505

def violating_text
  @violating_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9512
9513
9514
9515
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9512

def update!(**args)
  @policy_name = args[:policy_name] if args.key?(:policy_name)
  @violating_text = args[:violating_text] if args.key?(:violating_text)
end