Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Error details for a budget below per-day minimum error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.



9631
9632
9633
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_per_day_minimum_microsFixnum

The minimum budget required by the campaign per day, in micros of the advertiser currency. Applies to both daily and custom budgets. Corresponds to the JSON property budgetPerDayMinimumMicros

Returns:

  • (Fixnum)


9595
9596
9597
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9595

def budget_per_day_minimum_micros
  @budget_per_day_minimum_micros
end

#currency_codeString

The advertiser's currency, represented as a three-letter ISO 4217 currency code (such as "USD"). Corresponds to the JSON property currencyCode

Returns:

  • (String)


9601
9602
9603
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9601

def currency_code
  @currency_code
end

#failed_budget_amount_microsFixnum

The budget amount value that was rejected as too low, in micros of the advertiser currency. Only set if this error is caused by the amount field value. Corresponds to the JSON property failedBudgetAmountMicros

Returns:

  • (Fixnum)


9608
9609
9610
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9608

def failed_budget_amount_micros
  @failed_budget_amount_micros
end

#failed_budget_total_amount_microsFixnum

The budget total_amount value that was rejected as too low, in micros of the advertiser currency. Only set if this error is caused by the total_amount field value. Corresponds to the JSON property failedBudgetTotalAmountMicros

Returns:

  • (Fixnum)


9615
9616
9617
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9615

def failed_budget_total_amount_micros
  @failed_budget_total_amount_micros
end

#minimum_budget_amount_microsFixnum

The minimum value for the budget's amount field required by the campaign, in micros of the advertiser currency. Only set if this error is caused by the amount field value. Corresponds to the JSON property minimumBudgetAmountMicros

Returns:

  • (Fixnum)


9622
9623
9624
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9622

def minimum_budget_amount_micros
  @minimum_budget_amount_micros
end

#minimum_budget_total_amount_microsFixnum

The minimum value for the budget's total_amount field required by the campaign given its configured start and end time, in micros of the advertiser currency. Only set if this error is caused by the total_amount field value. Corresponds to the JSON property minimumBudgetTotalAmountMicros

Returns:

  • (Fixnum)


9629
9630
9631
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9629

def minimum_budget_total_amount_micros
  @minimum_budget_total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9636
9637
9638
9639
9640
9641
9642
9643
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9636

def update!(**args)
  @budget_per_day_minimum_micros = args[:budget_per_day_minimum_micros] if args.key?(:budget_per_day_minimum_micros)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @failed_budget_amount_micros = args[:failed_budget_amount_micros] if args.key?(:failed_budget_amount_micros)
  @failed_budget_total_amount_micros = args[:failed_budget_total_amount_micros] if args.key?(:failed_budget_total_amount_micros)
  @minimum_budget_amount_micros = args[:minimum_budget_amount_micros] if args.key?(:minimum_budget_amount_micros)
  @minimum_budget_total_amount_micros = args[:minimum_budget_total_amount_micros] if args.key?(:minimum_budget_total_amount_micros)
end