Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Additional error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorDetails.



10698
10699
10700
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_per_day_minimum_error_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Error details for a budget below per-day minimum error. Corresponds to the JSON property budgetPerDayMinimumErrorDetails



10668
10669
10670
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10668

def budget_per_day_minimum_error_details
  @budget_per_day_minimum_error_details
end

#policy_finding_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsPolicyFindingDetails

Error returned as part of a mutate response. This error indicates one or more policy findings in the fields of a resource. Corresponds to the JSON property policyFindingDetails



10674
10675
10676
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10674

def policy_finding_details
  @policy_finding_details
end

#policy_violation_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Error returned as part of a mutate response. This error indicates single policy violation by some text in one of the fields. Corresponds to the JSON property policyViolationDetails



10680
10681
10682
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10680

def policy_violation_details
  @policy_violation_details
end

#quota_error_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails

Additional quota error details when there is QuotaError. Corresponds to the JSON property quotaErrorDetails



10685
10686
10687
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10685

def quota_error_details
  @quota_error_details
end

#resource_count_detailsGoogle::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsResourceCountDetails

Error details returned when an resource count limit was exceeded. Corresponds to the JSON property resourceCountDetails



10690
10691
10692
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10690

def resource_count_details
  @resource_count_details
end

#unpublished_error_codeString

The error code that should have been returned, but wasn't. This is used when the error code is not published in the client specified version. Corresponds to the JSON property unpublishedErrorCode

Returns:

  • (String)


10696
10697
10698
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10696

def unpublished_error_code
  @unpublished_error_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10703
10704
10705
10706
10707
10708
10709
10710
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10703

def update!(**args)
  @budget_per_day_minimum_error_details = args[:budget_per_day_minimum_error_details] if args.key?(:budget_per_day_minimum_error_details)
  @policy_finding_details = args[:policy_finding_details] if args.key?(:policy_finding_details)
  @policy_violation_details = args[:policy_violation_details] if args.key?(:policy_violation_details)
  @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details)
  @resource_count_details = args[:resource_count_details] if args.key?(:resource_count_details)
  @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code)
end