Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
A part of a field path.
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of a field or a oneof Corresponds to the JSON property
fieldName. -
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed Corresponds to the JSON property
index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
constructor
A new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.
9576 9577 9578 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
The name of a field or a oneof
Corresponds to the JSON property fieldName
9569 9570 9571 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9569 def field_name @field_name end |
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed
Corresponds to the JSON property index
9574 9575 9576 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9574 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9581 9582 9583 9584 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 9581 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @index = args[:index] if args.key?(:index) end |