Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb
Overview
Error returned as part of a mutate response. This error indicates single policy violation by some text in one of the fields.
Instance Attribute Summary collapse
-
#external_policy_description ⇒ String
Human readable description of policy violation.
-
#external_policy_name ⇒ String
Human readable name of the policy.
-
#is_exemptible ⇒ Boolean
(also: #is_exemptible?)
Whether user can file an exemption request for this violation.
-
#key ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyViolationKey
Key of the violation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
constructor
A new instance of GoogleAdsSearchads360V23ErrorsPolicyViolationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
Returns a new instance of GoogleAdsSearchads360V23ErrorsPolicyViolationDetails.
10876 10877 10878 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_policy_description ⇒ String
Human readable description of policy violation.
Corresponds to the JSON property externalPolicyDescription
10857 10858 10859 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10857 def external_policy_description @external_policy_description end |
#external_policy_name ⇒ String
Human readable name of the policy.
Corresponds to the JSON property externalPolicyName
10862 10863 10864 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10862 def external_policy_name @external_policy_name end |
#is_exemptible ⇒ Boolean Also known as: is_exemptible?
Whether user can file an exemption request for this violation.
Corresponds to the JSON property isExemptible
10867 10868 10869 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10867 def is_exemptible @is_exemptible end |
#key ⇒ Google::Apis::Searchads360V0::GoogleAdsSearchads360V23CommonPolicyViolationKey
Key of the violation. The key is used for referring to a violation when filing
an exemption request.
Corresponds to the JSON property key
10874 10875 10876 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10874 def key @key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10881 10882 10883 10884 10885 10886 |
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10881 def update!(**args) @external_policy_description = args[:external_policy_description] if args.key?(:external_policy_description) @external_policy_name = args[:external_policy_name] if args.key?(:external_policy_name) @is_exemptible = args[:is_exemptible] if args.key?(:is_exemptible) @key = args[:key] if args.key?(:key) end |