Class: Google::Apis::Searchads360V0::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v0/classes.rb,
lib/google/apis/searchads360_v0/representations.rb,
lib/google/apis/searchads360_v0/representations.rb

Overview

Additional information about the batch job. This message is also used as metadata returned in batch job Long Running Operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata

Returns a new instance of GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata.



10986
10987
10988
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_date_timeString

Output only. The time when this batch job was completed. Formatted as yyyy-MM- dd HH:mm:ss. Example: "2018-03-05 09:16:00" Corresponds to the JSON property completionDateTime

Returns:

  • (String)


10948
10949
10950
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10948

def completion_date_time
  @completion_date_time
end

#creation_date_timeString

Output only. The time when this batch job was created. Formatted as yyyy-mm-dd hh:mm:ss. Example: "2018-03-05 09:15:00" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


10954
10955
10956
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10954

def creation_date_time
  @creation_date_time
end

#estimated_completion_ratioFloat

Output only. The fraction (between 0.0 and 1.0) of mutates that have been processed. This is empty if the job hasn't started running yet. Corresponds to the JSON property estimatedCompletionRatio

Returns:

  • (Float)


10960
10961
10962
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10960

def estimated_completion_ratio
  @estimated_completion_ratio
end

#executed_operation_countFixnum

Output only. The number of mutate operations executed by the batch job. Present only if the job has started running. Corresponds to the JSON property executedOperationCount

Returns:

  • (Fixnum)


10966
10967
10968
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10966

def executed_operation_count
  @executed_operation_count
end

#execution_limit_secondsFixnum

Immutable. The approximate upper bound for how long a batch job can be executed, in seconds. If the job runs more than the given upper bound, the job will be canceled. Corresponds to the JSON property executionLimitSeconds

Returns:

  • (Fixnum)


10973
10974
10975
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10973

def execution_limit_seconds
  @execution_limit_seconds
end

#operation_countFixnum

Output only. The number of mutate operations in the batch job. Corresponds to the JSON property operationCount

Returns:

  • (Fixnum)


10978
10979
10980
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10978

def operation_count
  @operation_count
end

#start_date_timeString

Output only. The time when this batch job started running. Formatted as yyyy- mm-dd hh:mm:ss. Example: "2018-03-05 09:15:30" Corresponds to the JSON property startDateTime

Returns:

  • (String)


10984
10985
10986
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10984

def start_date_time
  @start_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10991
10992
10993
10994
10995
10996
10997
10998
10999
# File 'lib/google/apis/searchads360_v0/classes.rb', line 10991

def update!(**args)
  @completion_date_time = args[:completion_date_time] if args.key?(:completion_date_time)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @estimated_completion_ratio = args[:estimated_completion_ratio] if args.key?(:estimated_completion_ratio)
  @executed_operation_count = args[:executed_operation_count] if args.key?(:executed_operation_count)
  @execution_limit_seconds = args[:execution_limit_seconds] if args.key?(:execution_limit_seconds)
  @operation_count = args[:operation_count] if args.key?(:operation_count)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
end